@@ -18,8 +18,8 @@
 #
 
 require "chef-config/config"
-require "ohai/exception"
-require "ohai/plugin_config"
+require_relative "exception"
+require_relative "plugin_config"
 
 module Ohai
   Config = ChefConfig::Config
@@ -33,9 +33,14 @@ module Ohai
       default :hints_path, [ ChefConfig::Config.platform_specific_path("/etc/chef/ohai/hints") ]
       default :log_level, :auto
       default :log_location, STDERR
-      default :plugin, Ohai::PluginConfig.new { |h, k| h[k] = Ohai::PluginConfig.new }
+      default :plugin, ( Ohai::PluginConfig.new { |h, k| h[k] = Ohai::PluginConfig.new } )
       default :plugin_path, [ File.expand_path(File.join(File.dirname(__FILE__), "plugins")), ChefConfig::Config.platform_specific_path("/etc/chef/ohai/plugins") ]
       default :critical_plugins, []
+      # causes all optional plugins to be run.
+      default :run_all_plugins, false
+      # optional plugins are the set of plugins that are marked optional but you wish to run.
+      default(:optional_plugins, []).writes_value { |arr| arr.map(&:to_sym) }
+      default :shellout_timeout, 30
     end
   end
 
