@@ -18,37 +18,38 @@
 # limitations under the License.
 #
 
-require "ohai/mixin/os"
-require "ohai/mixin/command"
-require "ohai/mixin/seconds_to_human"
-require "ohai/hints"
-require "ohai/util/file_helper"
+require_relative "../mixin/os"
+require_relative "../mixin/command"
+require_relative "../mixin/seconds_to_human"
+require_relative "../hints"
+require_relative "../util/file_helper"
 
 module Ohai
 
   # For plugin namespacing
   module NamedPlugin
+
+    # Is the plugin a Symbol starting with a capital letter that has no underscores
+    #
+    # @param name [String] the plugin name
+    # @return [Boolean]
     def self.valid_name?(name)
       name.is_a?(Symbol) && name.to_s.match(/^[^A-Z]|_/).nil?
     end
 
-    # dealing with ruby 1.8
-    if Module.method(:const_defined?).arity == 1
-      def self.strict_const_defined?(const)
-        const_defined?(const)
-      end
-    else
-      def self.strict_const_defined?(const)
-        const_defined?(const, false)
-      end
+    # @return [Boolean]
+    def self.strict_const_defined?(const)
+      const_defined?(const, false)
     end
   end
 
+  # @param name [String]
   def self.plugin(name, &block)
     raise Ohai::Exceptions::InvalidPluginName, "#{name} is not a valid plugin name. A valid plugin name is a symbol which begins with a capital letter and contains no underscores" unless NamedPlugin.valid_name?(name)
 
     plugin = nil
 
+    # avoid already initialized constant warnings if already defined
     if NamedPlugin.strict_const_defined?(name)
       plugin = NamedPlugin.const_get(name)
       plugin.class_eval(&block)
@@ -61,6 +62,8 @@ module Ohai
   end
 
   # Cross platform /dev/null to support testability
+  #
+  # @return [String]
   def self.dev_null
     if RUBY_PLATFORM =~ /mswin|mingw|windows/
       "NUL"
@@ -86,9 +89,11 @@ module Ohai
 
       attr_reader :data
       attr_reader :failed
+      attr_reader :logger
 
-      def initialize(data)
+      def initialize(data, logger)
         @data = data
+        @logger = logger.with_child({ subsystem: "plugin", plugin: name })
         @has_run = false
         @failed = false
       end
@@ -97,7 +102,7 @@ module Ohai
         @has_run = true
 
         if Ohai.config[:disabled_plugins].include?(name)
-          Ohai::Log.debug("Skipping disabled plugin #{name}")
+          logger.trace("Skipping disabled plugin #{name}")
         else
           run_plugin
         end
@@ -126,7 +131,7 @@ module Ohai
       end
 
       def has_key?(name)
-        @data.has_key?(name)
+        @data.key?(name)
       end
 
       def attribute?(name, *keys)
@@ -138,8 +143,9 @@ module Ohai
       end
 
       def from(cmd)
-        _status, stdout, _stderr = run_command(:command => cmd)
+        _status, stdout, _stderr = run_command(command: cmd)
         return "" if stdout.nil? || stdout.empty?
+
         stdout.strip
       end
 
@@ -148,8 +154,9 @@ module Ohai
       # the value.
       def from_with_regex(cmd, *regex_list)
         regex_list.flatten.each do |regex|
-          _status, stdout, _stderr = run_command(:command => cmd)
+          _status, stdout, _stderr = run_command(command: cmd)
           return "" if stdout.nil? || stdout.empty?
+
           stdout.chomp!.strip
           md = stdout.match(regex)
           return md[1]
@@ -161,9 +168,9 @@ module Ohai
         # Will raise a TypeError if we hit a subattribute that is not a
         # Hash, Mash, or Array.
         keys = [name] + attrs
-        attribute = keys[0..-2].inject(@data) do |attrs, key|
-          attrs[key] ||= Mash.new
-          attrs[key]
+        attribute = keys[0..-2].inject(@data) do |atts, key|
+          atts[key] ||= Mash.new
+          atts[key]
         end
 
         # Set the subattribute to the value.
@@ -188,8 +195,8 @@ module Ohai
         raise e
       rescue => e
         @failed = true
-        Ohai::Log.debug("Plugin #{name} threw #{e.inspect}")
-        e.backtrace.each { |line| Ohai::Log.debug( line ) }
+        logger.trace("Plugin #{name} threw #{e.inspect}")
+        e.backtrace.each { |line| logger.trace( line ) }
       end
 
       def method_missing(name, *args)
@@ -205,6 +212,7 @@ module Ohai
           unless attrs.nil? || attrs.is_a?(Array) || attrs.is_a?(Hash)
             raise TypeError.new("Expected Hash but got #{attrs.class}.")
           end
+
           attrs[key]
         end
       rescue NoMethodError
