@@ -20,24 +20,35 @@
 module Ohai
   module DSL
     class Plugin
+      # The class for the "Version 7" plugin format we introduced in Ohai 7. This is the 2nd
+      # generation of Ohai plugin and the previous generation (V6) was removed in Ohai 14
       class VersionVII < Plugin
         attr_reader :version
         attr_reader :source
 
-        def initialize(data)
-          super(data)
+        def initialize(data, logger)
+          super(data, logger)
           @source = self.class.sources
           @version = :version7
         end
 
+        # the plugin name we use through Ohai (Foo) vs. the class name (Ohai::NamedPlugin::Foo)
+        #
+        # @return [String]
         def name
           self.class.name.split("Ohai::NamedPlugin::")[1].to_sym
         end
 
+        # return that we're a v7 plugin
+        #
+        # @return [Symbol]
         def self.version
           :version7
         end
 
+        # the source of the plugin on disk. This is an array since a plugin may exist for multiple platforms and this would include each of those platform specific file paths
+        #
+        # @return [Array]
         def self.sources
           @source_list ||= []
         end
@@ -50,32 +61,59 @@ module Ohai
           @depends_attrs ||= []
         end
 
+        # A block per platform for actually performing data collection constructed
+        # by the collect_data method
+        #
+        # @return [Mash]
         def self.data_collector
           @data_collector ||= Mash.new
         end
 
+        # set the attributes provided by the plugin
+        #
+        # @param attrs [Array]
         def self.provides(*attrs)
           attrs.each do |attr|
             provides_attrs << attr unless provides_attrs.include?(attr)
           end
         end
 
+        # set the attributes depended on by the plugin
+        #
+        # @param attrs [Array]
         def self.depends(*attrs)
           attrs.each do |attr|
             depends_attrs << attr unless depends_attrs.include?(attr)
           end
         end
 
+        # set the plugin optional state
+        #
+        # @param opt [Boolean]
+        def self.optional(opt = true)
+          @optional = opt
+        end
+
+        # check if the plugin is optional
+        #
+        # @return [Boolean]
+        def self.optional?
+          !!@optional
+        end
+
+        # define data collection methodology per platform
+        #
+        # @param platform [Symbol] the platform to collect data for
+        # @param other_platforms [Array] additional platforms to collect data for
+        # @param block [block] the actual code to collect data for the specified platforms
         def self.collect_data(platform = :default, *other_platforms, &block)
           [platform, other_platforms].flatten.each do |plat|
-            if data_collector.has_key?(plat)
-              raise Ohai::Exceptions::IllegalPluginDefinition, "collect_data already defined on platform #{plat}"
-            else
-              data_collector[plat] = block
-            end
+            Ohai::Log.warn("collect_data already defined on platform '#{plat}' for #{self}, last plugin seen will be used") if data_collector.key?(plat)
+            data_collector[plat] = block
           end
         end
 
+        # @return [Array]
         def dependencies
           self.class.depends_attrs
         end
@@ -84,28 +122,34 @@ module Ohai
           collector = self.class.data_collector
           platform = collect_os
 
-          if collector.has_key?(platform)
+          if collector.key?(platform)
             instance_eval(&collector[platform])
-          elsif collector.has_key?(:default)
+          elsif collector.key?(:default)
             instance_eval(&collector[:default])
           else
-            Ohai::Log.debug("Plugin #{name}: No data to collect. Skipping...")
+            logger.trace("Plugin #{name}: No data to collect. Skipping...")
           end
         end
 
+        def optional?
+          self.class.optional?
+        end
+
         def provides(*paths)
-          Ohai::Log.warn("[UNSUPPORTED OPERATION] \'provides\' is no longer supported in a \'collect_data\' context. Please specify \'provides\' before collecting plugin data. Ignoring command \'provides #{paths.join(", ")}")
+          logger.warn("[UNSUPPORTED OPERATION] \'provides\' is no longer supported in a \'collect_data\' context. Please specify \'provides\' before collecting plugin data. Ignoring command \'provides #{paths.join(", ")}")
         end
 
         def require_plugin(*args)
-          Ohai::Log.warn("[UNSUPPORTED OPERATION] \'require_plugin\' is no longer supported. Please use \'depends\' instead.\nIgnoring plugin(s) #{args.join(", ")}")
+          logger.warn("[UNSUPPORTED OPERATION] \'require_plugin\' is no longer supported. Please use \'depends\' instead.\nIgnoring plugin(s) #{args.join(", ")}")
         end
 
         def configuration(option, *options)
           return nil if plugin_config.nil? || !plugin_config.key?(option)
+
           value = plugin_config[option]
           options.each do |opt|
             return nil unless value.key?(opt)
+
             value = value[opt]
           end
           value
@@ -127,12 +171,12 @@ module Ohai
           # ["", "Memory"] => ["Memory"]
           # ["", "Network", "", "Listeners"] => ["Network", "Listeners"]
           # ["SSH", "Host", "", "Key"] => ["SSH", "Host", "Key"]
-          parts.delete_if { |part| part.empty? }
+          parts.delete_if(&:empty?)
           # ["DMI"] => :dmi
           # ["Memory"] => :memory
           # ["Network", "Listeners"] => :network_listeners
           # ["SSH", "Host", "Key"] => :ssh_host_key
-          snake_case_name = parts.map { |part| part.downcase }.join("_").to_sym
+          snake_case_name = parts.map(&:downcase).join("_").to_sym
 
           # Plugin names in config hashes are auto-vivified, so we check with
           # key? to avoid falsely instantiating a configuration hash.
