@@ -19,13 +19,15 @@
 require "mixlib/log"
 
 module Ohai
+  # the Ohai Logger which is just Mixlib::Log defaulting to STDERR and :info level
+  # unless otherwise configured via CLI or config
   class Log
     extend Mixlib::Log
 
-    # this class loading initalization is so that we don't lose early logger
+    # this class loading initialization is so that we don't lose early logger
     # messages when run from the CLI?
     init(STDERR)
-    level = :info
+    level = :info # rubocop:disable Lint/UselessAssignment
 
   end
 end
