@@ -17,9 +17,9 @@
 # limitations under the License.
 #
 
-require "ohai/exception"
-require "ohai/log"
-require "mixlib/shellout"
+require_relative "../exception"
+require_relative "../log"
+require "mixlib/shellout" unless defined?(Mixlib::ShellOut::DEFAULT_READ_TIMEOUT)
 
 module Ohai
   module Mixin
@@ -28,8 +28,8 @@ module Ohai
       # accept a command and any of the mixlib-shellout options
       def shell_out(cmd, **options)
         options = options.dup
-        # unless specified by the caller timeout after 30 seconds
-        options[:timeout] ||= 30
+        # unless specified by the caller timeout after configured timeout (default 30 seconds)
+        options[:timeout] ||= Ohai::Config.ohai[:shellout_timeout]
         unless RUBY_PLATFORM =~ /mswin|mingw32|windows/
           options[:env] = options.key?(:env) ? options[:env].dup : {}
           options[:env]["PATH"] ||= ((ENV["PATH"] || "").split(":") + %w{/usr/local/sbin /usr/local/bin /usr/sbin /usr/bin /sbin /bin}).join(":")
@@ -37,13 +37,13 @@ module Ohai
         so = Mixlib::ShellOut.new(cmd, options)
         begin
           so.run_command
-          Ohai::Log.debug("Plugin #{name}: ran '#{cmd}' and returned #{so.exitstatus}")
+          logger.trace("Plugin #{name}: ran '#{cmd}' and returned #{so.exitstatus}")
           so
         rescue Errno::ENOENT => e
-          Ohai::Log.debug("Plugin #{name}: ran '#{cmd}' and failed #{e.inspect}")
+          logger.trace("Plugin #{name}: ran '#{cmd}' and failed #{e.inspect}")
           raise Ohai::Exceptions::Exec, e
         rescue Mixlib::ShellOut::CommandTimeout => e
-          Ohai::Log.debug("Plugin #{name}: ran '#{cmd}' and timed out after #{options[:timeout]} seconds")
+          logger.trace("Plugin #{name}: ran '#{cmd}' and timed out after #{options[:timeout]} seconds")
           raise Ohai::Exceptions::Exec, e
         end
       end
