@@ -23,14 +23,15 @@ module Ohai
   module Mixin
     module OS
 
+      # Using ruby configuration determine the OS we're running on
+      #
+      # @return [String] the OS
       def collect_os
         case ::RbConfig::CONFIG["host_os"]
         when /aix(.+)$/
           "aix"
         when /darwin(.+)$/
           "darwin"
-        when /hpux(.+)$/
-          "hpux"
         when /linux/
           "linux"
         when /freebsd(.+)$/
