@@ -22,8 +22,9 @@ class String
   # underscore will also change ’::’ to ’/’ to convert namespaces to paths.
   # This should implement the same functionality as underscore method in
   # ActiveSupport::CoreExtensions::String::Inflections
+  # @return [String]
   def wmi_underscore
-    gsub(/::/, "/").gsub(/([A-Z]+)([A-Z][a-z])/, '\1_\2').
-      gsub(/([a-z\d])([A-Z])/, '\1_\2').tr("-", "_").downcase
+    gsub(/::/, "/").gsub(/([A-Z]+)([A-Z][a-z])/, '\1_\2')
+      .gsub(/([a-z\d])([A-Z])/, '\1_\2').tr("-", "_").downcase
   end
 end
