@@ -37,8 +37,8 @@ Ohai.plugin(:Kernel) do
     #          6390000    20000          63a0000      ba8 /usr/lib/drivers/if_en
     # f1000000c0318000    20000 f1000000c0320000    17138 /usr/lib/drivers/random
     so.stdout.lines do |line|
-      if line =~ /\s*([0-9a-f]+)\s+([0-9a-f]+)\s+([0-9a-f]+)\s+([0-9a-f]+)\s+([a-zA-Z0-9\/\._]+)/
-        modules[$5] = { :text => { :address => $1, :size => $2 }, :data => { :address => $3, :size => $4 } }
+      if line =~ %r{\s*([0-9a-f]+)\s+([0-9a-f]+)\s+([0-9a-f]+)\s+([0-9a-f]+)\s+([a-zA-Z0-9/\._]+)}
+        modules[$5] = { text: { address: $1, size: $2 }, data: { address: $3, size: $4 } }
       end
     end
 
