@@ -58,30 +58,33 @@ Ohai.plugin(:Virtualization) do
             case title
             when "network"
               next if line =~ /^Interface|^---/
+
               splat = line.strip.split
               key   = splat[0].downcase
               value = {
-                        "address"   => splat[1],
-                        "netmask"   => splat[2],
+                        "address" => splat[1],
+                        "netmask" => splat[2],
                         "broadcast" => splat[3],
                       }
               wpars[wpar_name][title][key] = value
             when "user-specified routes"
               next if line =~ /^Type|^---/
+
               splat = line.strip.split
               key   = splat[2].downcase
               value = {
                         "destination" => splat[0],
-                        "gateway"     => splat[1],
+                        "gateway" => splat[1],
                       }
               wpars[wpar_name][title][key] = value
             when "file systems"
               next if line =~ /^MountPoint|^---/
+
               splat = line.strip.split
               key = splat[1].downcase
               value = {
                         "mountpoint" => splat[0],
-                        "device"     => splat[1],
+                        "device" => splat[1],
                         "vfs" => splat[2],
                         "options" => splat[3].split(","),
                       }
@@ -99,6 +102,7 @@ Ohai.plugin(:Virtualization) do
               wpars[wpar_name][title]["Privileges"] += privileges.split(",")
             when "device exports"
               next if line =~ /^Name|^---/
+
               splat = line.strip.split
               key = splat[0].downcase
               value = {
@@ -140,7 +144,7 @@ Ohai.plugin(:Virtualization) do
           breadcrumb.each do |node|
             evalstr << "[\'#{node}\']"
           end
-          wpars[wpar_name][breadcrumb[-1]] = eval evalstr
+          wpars[wpar_name][breadcrumb[-1]] = eval evalstr # rubocop: disable Security/Eval
         end
       end
       virtualization[:wpars] = wpars unless wpars.empty?
