@@ -15,8 +15,8 @@
 #
 
 Ohai.plugin(:Azure) do
-  require "ohai/mixin/azure_metadata"
-  require "ohai/mixin/http_helper"
+  require_relative "../mixin/azure_metadata"
+  require_relative "../mixin/http_helper"
 
   include Ohai::Mixin::AzureMetadata
   include Ohai::Mixin::HttpHelper
@@ -30,16 +30,16 @@ Ohai.plugin(:Azure) do
     # project for details
     azure_metadata_from_hints = hint?("azure")
     if azure_metadata_from_hints
-      Ohai::Log.debug("Plugin Azure: Azure hint is present. Parsing any hint data.")
+      logger.trace("Plugin Azure: Azure hint is present. Parsing any hint data.")
       azure Mash.new
       azure_metadata_from_hints.each { |k, v| azure[k] = v }
       azure["metadata"] = parse_metadata
     elsif has_waagent? || has_dhcp_option_245?
-      Ohai::Log.debug("Plugin Azure: No hints present, but system appears to be on Azure.")
+      logger.trace("Plugin Azure: No hints present, but system appears to be on Azure.")
       azure Mash.new
       azure["metadata"] = parse_metadata
     else
-      Ohai::Log.debug("Plugin Azure: No hints present and doesn't appear to be on Azure.")
+      logger.trace("Plugin Azure: No hints present and doesn't appear to be on Azure.")
       false
     end
   end
@@ -48,7 +48,7 @@ Ohai.plugin(:Azure) do
   # http://blog.mszcool.com/index.php/2015/04/detecting-if-a-virtual-machine-runs-in-microsoft-azure-linux-windows-to-protect-your-software-when-distributed-via-the-azure-marketplace/
   def has_waagent?
     if File.exist?("/usr/sbin/waagent") || Dir.exist?('C:\WindowsAzure')
-      Ohai::Log.debug("Plugin Azure: Found waagent used by Azure.")
+      logger.trace("Plugin Azure: Found waagent used by Azure.")
       true
     end
   end
@@ -58,7 +58,7 @@ Ohai.plugin(:Azure) do
     if File.exist?("/var/lib/dhcp/dhclient.eth0.leases")
       File.open("/var/lib/dhcp/dhclient.eth0.leases").each do |line|
         if line =~ /unknown-245/
-          Ohai::Log.debug("Plugin Azure: Found unknown-245 DHCP option used by Azure.")
+          logger.trace("Plugin Azure: Found unknown-245 DHCP option used by Azure.")
           has_245 = true
           break
         end
@@ -68,9 +68,13 @@ Ohai.plugin(:Azure) do
   end
 
   # create the basic structure we'll store our data in
-  def initialize_metadata_mash
+  def initialize_metadata_mash_compute
     metadata = Mash.new
     metadata["compute"] = Mash.new
+    metadata
+  end
+
+  def initialize_metadata_mash_network(metadata)
     metadata["network"] = Mash.new
     metadata["network"]["interfaces"] = Mash.new
     %w{public_ipv4 local_ipv4 public_ipv6 local_ipv6}.each do |type|
@@ -93,27 +97,32 @@ Ohai.plugin(:Azure) do
 
     endpoint_data = fetch_metadata
     return nil if endpoint_data.nil?
-    metadata = initialize_metadata_mash
+
+    metadata = initialize_metadata_mash_compute
 
     # blindly add everything in compute to our data structure
     endpoint_data["compute"].each do |k, v|
       metadata["compute"][k] = v
     end
 
-    # parse out per interface interface IP data
-    endpoint_data["network"]["interface"].each do |int|
-      metadata["network"]["interfaces"][int["macAddress"]] = Mash.new
-      metadata["network"]["interfaces"][int["macAddress"]]["mac"] = int["macAddress"]
-      metadata["network"]["interfaces"][int["macAddress"]]["public_ipv6"] = fetch_ip_data(int, "ipv6", "publicIpAddress")
-      metadata["network"]["interfaces"][int["macAddress"]]["public_ipv4"] = fetch_ip_data(int, "ipv4", "publicIpAddress")
-      metadata["network"]["interfaces"][int["macAddress"]]["local_ipv6"] = fetch_ip_data(int, "ipv6", "privateIpAddress")
-      metadata["network"]["interfaces"][int["macAddress"]]["local_ipv4"] = fetch_ip_data(int, "ipv4", "privateIpAddress")
-    end
+    # receiving network output is not guaranteed
+    unless endpoint_data["network"].nil?
+      metadata = initialize_metadata_mash_network(metadata)
+      # parse out per interface interface IP data
+      endpoint_data["network"]["interface"].each do |int|
+        metadata["network"]["interfaces"][int["macAddress"]] = Mash.new
+        metadata["network"]["interfaces"][int["macAddress"]]["mac"] = int["macAddress"]
+        metadata["network"]["interfaces"][int["macAddress"]]["public_ipv6"] = fetch_ip_data(int, "ipv6", "publicIpAddress")
+        metadata["network"]["interfaces"][int["macAddress"]]["public_ipv4"] = fetch_ip_data(int, "ipv4", "publicIpAddress")
+        metadata["network"]["interfaces"][int["macAddress"]]["local_ipv6"] = fetch_ip_data(int, "ipv6", "privateIpAddress")
+        metadata["network"]["interfaces"][int["macAddress"]]["local_ipv4"] = fetch_ip_data(int, "ipv4", "privateIpAddress")
+      end
 
-    # aggregate the total IP data
-    %w{public_ipv4 local_ipv4 public_ipv6 local_ipv6}.each do |type|
-      metadata["network"]["interfaces"].each_value do |val|
-        metadata["network"][type].concat val[type] unless val[type].empty?
+      # aggregate the total IP data
+      %w{public_ipv4 local_ipv4 public_ipv6 local_ipv6}.each do |type|
+        metadata["network"]["interfaces"].each_value do |val|
+          metadata["network"][type].concat val[type] unless val[type].empty?
+        end
       end
     end
 
