@@ -1,7 +1,7 @@
 #
 # Author:: Bryan McLellan (btm@loftninjas.org)
 # Copyright:: Copyright (c) 2009 Bryan McLellan
-# Copyright:: Copyright (c) 2015-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2015-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,16 +17,16 @@
 # limitations under the License.
 #
 
-require "ohai/mixin/dmi_decode"
-
 Ohai.plugin(:Virtualization) do
-  include Ohai::Mixin::DmiDecode
   provides "virtualization"
+  depends "dmi"
+  require_relative "../../mixin/dmi_decode"
+  include Ohai::Mixin::DmiDecode
 
   collect_data(:freebsd, :openbsd, :netbsd, :dragonflybsd) do
 
     virtualization Mash.new unless virtualization
-    virtualization[:systems] = Mash.new unless virtualization[:systems]
+    virtualization[:systems] ||= Mash.new
 
     # detect when in a jail or when a jail is actively running (not in stopped state)
     so = shell_out("sysctl -n security.jail.jailed")
@@ -34,7 +34,7 @@ Ohai.plugin(:Virtualization) do
       virtualization[:system] = "jail"
       virtualization[:role] = "guest"
       virtualization[:systems][:jail] = "guest"
-      Ohai::Log.debug("Plugin Virtualization: Guest running in FreeBSD jail detected")
+      logger.trace("Plugin Virtualization: Guest running in FreeBSD jail detected")
     end
 
     # run jls to get a list of running jails
@@ -45,23 +45,23 @@ Ohai.plugin(:Virtualization) do
       virtualization[:system] = "jail"
       virtualization[:role] = "host"
       virtualization[:systems][:jail] = "host"
-      Ohai::Log.debug("Plugin Virtualization: Host running FreeBSD jails detected")
+      logger.trace("Plugin Virtualization: Host running FreeBSD jails detected")
     end
 
     # detect from modules
-    so = shell_out("#{Ohai.abs_path('/sbin/kldstat')}")
+    so = shell_out((Ohai.abs_path("/sbin/kldstat")).to_s)
     so.stdout.lines do |line|
       case line
       when /vboxdrv/
         virtualization[:system] = "vbox"
         virtualization[:role] = "host"
         virtualization[:systems][:vbox] = "host"
-        Ohai::Log.debug("Plugin Virtualization: Guest running on VirtualBox detected")
+        logger.trace("Plugin Virtualization: Guest running on VirtualBox detected")
       when /vboxguest/
         virtualization[:system] = "vbox"
         virtualization[:role] = "guest"
         virtualization[:systems][:vbox] = "guest"
-        Ohai::Log.debug("Plugin Virtualization: Host running VirtualBox detected")
+        logger.trace("Plugin Virtualization: Host running VirtualBox detected")
       end
     end
 
@@ -70,55 +70,51 @@ Ohai.plugin(:Virtualization) do
       virtualization[:system] = "bhyve"
       virtualization[:role] = "host"
       virtualization[:systems][:bhyve] = "host"
-      Ohai::Log.debug("Plugin Virtualization: Host running bhyve detected")
+      logger.trace("Plugin Virtualization: Host running bhyve detected")
     end
 
     # Detect KVM/QEMU paravirt guests from cpu, report as KVM
     # hw.model: QEMU Virtual CPU version 0.9.1
     so = shell_out("sysctl -n hw.model")
-    if so.stdout.split($/)[0] =~ /QEMU Virtual CPU|Common KVM processor|Common 32-bit KVM processor/
+    if so.stdout =~ /QEMU Virtual CPU|KVM processor/
       virtualization[:system] = "kvm"
       virtualization[:role] = "guest"
       virtualization[:systems][:kvm] = "guest"
-      Ohai::Log.debug("Plugin Virtualization: Guest running on KVM detected")
+      logger.trace("Plugin Virtualization: Guest running on KVM detected")
     end
 
     # gather hypervisor of guests from sysctl kern.vm_guest
     # there are a limited number of hypervisors detected here, BUT it doesn't
     # require dmidecode to be installed and dmidecode isn't in freebsd out of the box
     so = shell_out("sysctl -n kern.vm_guest")
-    case so.stdout
-    when /vmware/
-      virtualization[:system] = "vmware"
+    hypervisor = case so.stdout
+                 when /vmware/
+                   "vmware"
+                 when /hv/
+                   "hyperv"
+                 when /xen/
+                   "xen"
+                 when /kvm/
+                   so = shell_out("sysctl -n kern.hostuuid")
+                   so.stdout =~ /^ec2/ ? "amazonec2" : "kvm"
+                 when /bhyve/
+                   "bhyve"
+                 end
+
+    if hypervisor
+      virtualization[:system] = hypervisor
       virtualization[:role] = "guest"
-      virtualization[:systems][:vmware] = "guest"
-      Ohai::Log.debug("Plugin Virtualization: Guest running on VMware detected")
-    when /hv/
-      virtualization[:system] = "hyperv"
-      virtualization[:role] = "guest"
-      virtualization[:systems][:hyperv] = "guest"
-      Ohai::Log.debug("Plugin Virtualization: Guest running on Hyper-V detected")
-    when /xen/
-      virtualization[:system] = "xen"
-      virtualization[:role] = "guest"
-      virtualization[:systems][:xen] = "guest"
-      Ohai::Log.debug("Plugin Virtualization: Guest running on Xen detected")
-    when /bhyve/
-      virtualization[:system] = "bhyve"
-      virtualization[:role] = "guest"
-      virtualization[:systems][:bhyve] = "guest"
-      Ohai::Log.debug("Plugin Virtualization: Guest running on bhyve detected")
+      virtualization[:systems][hypervisor.to_sym] = "guest"
+      logger.trace("Plugin Virtualization: Guest running on #{hypervisor} detected")
     end
 
-    # parse dmidecode to discover various virtualization guests
-    if File.exist?("/usr/local/sbin/dmidecode") || File.exist?("/usr/pkg/sbin/dmidecode")
-      guest = guest_from_dmi(shell_out("dmidecode").stdout)
-      if guest
-        virtualization[:system] = guest
-        virtualization[:role] = "guest"
-        virtualization[:systems][guest.to_sym] = "guest"
-        Ohai::Log.debug("Plugin Virtualization: Guest running on #{guest} detected")
-      end
+    # parse dmi to discover various virtualization guests
+    guest = guest_from_dmi_data(get_attribute(:dmi, :system, :manufacturer), get_attribute(:dmi, :system, :product), get_attribute(:dmi, :system, :version))
+    if guest
+      logger.trace("Plugin Virtualization: DMI data indicates #{guest} guest")
+      virtualization[:system] = guest
+      virtualization[:role] = "guest"
+      virtualization[:systems][guest.to_sym] = "guest"
     end
   end
 end
