@@ -15,7 +15,6 @@
 # limitations under the License.
 
 Ohai.plugin(:Cloud) do
-  provides "cloud_v2"
   provides "cloud"
 
   depends "ec2"
@@ -26,6 +25,7 @@ Ohai.plugin(:Cloud) do
   depends "openstack"
   depends "azure"
   depends "digital_ocean"
+  depends "softlayer"
 
   # Class to help enforce the interface exposed to node[:cloud] (OHAI-542)
   #
@@ -53,14 +53,15 @@ Ohai.plugin(:Cloud) do
 
     def add_ipv4_addr(ip, accessibility)
       return if ip.nil? # just skip if ip is nil
+
       ipaddr = validate_ip_addr(ip, :ipv4)
 
       case accessibility
       when :public
-        @cloud[:public_ipv4_addrs] ||= Array.new
+        @cloud[:public_ipv4_addrs] ||= []
         @cloud[:public_ipv4_addrs] << ipaddr.to_s
       when :private
-        @cloud[:local_ipv4_addrs] ||= Array.new
+        @cloud[:local_ipv4_addrs] ||= []
         @cloud[:local_ipv4_addrs] << ipaddr.to_s
       else
         raise "ERROR: invalid accessibility param of '#{accessibility}'. must be :public or :private."
@@ -69,15 +70,17 @@ Ohai.plugin(:Cloud) do
 
     def add_ipv6_addr(ip, accessibility)
       return if ip.nil? # just skip if ip is nil
+
       ipaddr = validate_ip_addr(ip, :ipv6)
 
       raise "ERROR: invalid ipv6 address of '#{ip}' detected. " unless ipaddr.ipv6?
+
       case accessibility
       when :public
-        @cloud[:public_ipv6_addrs] ||= Array.new
+        @cloud[:public_ipv6_addrs] ||= []
         @cloud[:public_ipv6_addrs] << ipaddr.to_s
       when :private
-        @cloud[:local_ipv6_addrs] ||= Array.new
+        @cloud[:local_ipv6_addrs] ||= []
         @cloud[:local_ipv6_addrs] << ipaddr.to_s
       else
         raise "ERROR: invalid accessibility param of '#{accessibility}'. must be :public or :private."
@@ -124,7 +127,7 @@ Ohai.plugin(:Cloud) do
 
   def get_gce_values
     public_ips = gce["instance"]["networkInterfaces"].collect do |interface|
-      if interface.has_key?("accessConfigs")
+      if interface.key?("accessConfigs")
         interface["accessConfigs"].collect { |ac| ac["externalIp"] unless ac["externalIp"] == "" }
       end
     end.flatten.compact
@@ -295,6 +298,27 @@ Ohai.plugin(:Cloud) do
     @cloud_attr_obj.provider = "digital_ocean"
   end
 
+  # ----------------------------------------
+  # softlayer
+  # ----------------------------------------
+
+  # Is current cloud softlayer?
+  #
+  # === Return
+  # true:: If softlayer Hash is defined
+  # false:: Otherwise
+  def on_softlayer?
+    softlayer != nil
+  end
+
+  # Fill cloud hash with softlayer values
+  def get_softlayer_values
+    @cloud_attr_obj.add_ipv4_addr(softlayer["public_ipv4"], :public)
+    @cloud_attr_obj.add_ipv4_addr(softlayer["local_ipv4"], :private)
+    @cloud_attr_obj.public_hostname = softlayer["public_fqdn"]
+    @cloud_attr_obj.provider = "softlayer"
+  end
+
   collect_data do
     require "ipaddr"
 
@@ -308,9 +332,8 @@ Ohai.plugin(:Cloud) do
     get_openstack_values if on_openstack?
     get_azure_values if on_azure?
     get_digital_ocean_values if on_digital_ocean?
+    get_softlayer_values if on_softlayer?
 
-    # set node[:cloud] and node[:cloud_v2] hash here
-    cloud_v2 @cloud_attr_obj.cloud_mash
     cloud @cloud_attr_obj.cloud_mash
   end
 end
