@@ -23,24 +23,18 @@ Ohai.plugin(:Hardware) do
     sp_cmd = "system_profiler #{datatype} -xml"
     # Hardware queries
     sp_std = shell_out(sp_cmd)
-    sp_hash = Plist.parse_xml(sp_std.stdout)
+    Plist.parse_xml(sp_std.stdout)
   end
 
   collect_data(:darwin) do
     unless hardware
       hardware Mash.new
     else
-      Ohai::Log.debug("Plugin Hardware: namespace already exists")
+      logger.trace("Plugin Hardware: namespace already exists")
       next
     end
 
-    begin
-      require "plist"
-    rescue LoadError => e
-      # In case the plist gem isn't present, skip this plugin.
-      Ohai::Log.debug("Plugin Hardware: Can't load gem: #{e}. Cannot continue.")
-      next
-    end
+    require "plist"
 
     hw_hash = system_profiler("SPHardwareDataType")
     hw_hash[0]["_items"][0].delete("_name")
@@ -71,7 +65,7 @@ Ohai.plugin(:Hardware) do
       drive[:name] = drive_entry["_name"]
       drive[:bsd_name] = drive_entry["bsd_name"]
       drive[:capacity] = drive_entry["size_in_bytes"]
-      if drive_entry.has_key?("com.apple.corestorage.pv")
+      if drive_entry.key?("com.apple.corestorage.pv")
         drive[:drive_type] = drive_entry["com.apple.corestorage.pv"][0]["medium_type"]
         drive[:smart_status] = drive_entry["com.apple.corestorage.pv"][0]["smart_status"]
         drive[:partitions] = drive_entry["com.apple.corestorage.pv"].count
