@@ -17,19 +17,23 @@
 #
 
 Ohai.plugin(:Network) do
+  require_relative "../../mixin/network_helper"
+
   provides "network", "network/interfaces"
   provides "counters/network", "counters/network/interfaces"
 
+  include Ohai::Mixin::NetworkHelper
+
   def parse_media(media_string)
-    media = Hash.new
+    media = {}
     line_array = media_string.split(" ")
 
     0.upto(line_array.length - 1) do |i|
       unless line_array[i].eql?("none")
 
         if line_array[i + 1] =~ /^\<([a-zA-Z\-\,]+)\>$/
-          media[line_array[i]] = Hash.new unless media.has_key?(line_array[i])
-          if media[line_array[i]].has_key?("options")
+          media[line_array[i]] = {} unless media.key?(line_array[i])
+          if media[line_array[i]].key?("options")
             $1.split(",").each do |opt|
               media[line_array[i]]["options"] << opt unless media[line_array[i]]["options"].include?(opt)
             end
@@ -38,7 +42,7 @@ Ohai.plugin(:Network) do
           end
         else
           if line_array[i].eql?("autoselect")
-            media["autoselect"] = Hash.new unless media.has_key?("autoselect")
+            media["autoselect"] = {} unless media.key?("autoselect")
             media["autoselect"]["options"] = []
           end
         end
@@ -56,6 +60,7 @@ Ohai.plugin(:Network) do
     return "IPIP" if ifname.eql?("gif")
     return "6to4" if ifname.eql?("stf")
     return "dot1q" if ifname.eql?("vlan")
+
     "Unknown"
   end
 
@@ -63,6 +68,7 @@ Ohai.plugin(:Network) do
     return "Node" if scope.eql?("::1")
     return "Link" if scope =~ /^fe80\:/
     return "Site" if scope =~ /^fec0\:/
+
     "Global"
   end
 
@@ -74,8 +80,9 @@ Ohai.plugin(:Network) do
     return ifname unless ifaces[ifname].nil?
     # oh well, time to go hunting!
     return ifname.chop if ifname =~ /\*$/
-    ifaces.keys.each do |ifc|
-      ifaces[ifc][:addresses].keys.each do |addr|
+
+    ifaces.each_key do |ifc|
+      ifaces[ifc][:addresses].each_key do |addr|
         return ifc if addr.eql? mac
       end
     end
@@ -84,12 +91,10 @@ Ohai.plugin(:Network) do
   end
 
   collect_data(:darwin) do
-    require "scanf"
-
     network Mash.new unless network
-    network[:interfaces] = Mash.new unless network[:interfaces]
+    network[:interfaces] ||= Mash.new
     counters Mash.new unless counters
-    counters[:network] = Mash.new unless counters[:network]
+    counters[:network] ||= Mash.new
 
     so = shell_out("route -n get default")
     so.stdout.lines do |line|
@@ -109,12 +114,13 @@ Ohai.plugin(:Network) do
     so.stdout.lines do |line|
       if line =~ /^([0-9a-zA-Z\.\:\-]+): \S+ mtu (\d+)$/
         cint = $1
-        iface[cint] = Mash.new unless iface[cint]; iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        iface[cint] ||= Mash.new
+        iface[cint][:addresses] ||= Mash.new
         iface[cint][:mtu] = $2
         if line =~ /\sflags\=\d+\<((UP|BROADCAST|DEBUG|SMART|SIMPLEX|LOOPBACK|POINTOPOINT|NOTRAILERS|RUNNING|NOARP|PROMISC|ALLMULTI|SLAVE|MASTER|MULTICAST|DYNAMIC|,)+)\>\s/
           flags = $1.split(",")
         else
-          flags = Array.new
+          flags = []
         end
         iface[cint][:flags] = flags.flatten
         if cint =~ /^(\w+)(\d+.*)/
@@ -124,37 +130,37 @@ Ohai.plugin(:Network) do
         end
       end
       if line =~ /^\s+ether ([0-9a-f\:]+)/
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        iface[cint][:addresses] ||= Mash.new
         iface[cint][:addresses][$1] = { "family" => "lladdr" }
         iface[cint][:encapsulation] = "Ethernet"
       end
       if line =~ /^\s+lladdr ([0-9a-f\:]+)\s/
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        iface[cint][:addresses] ||= Mash.new
         iface[cint][:addresses][$1] = { "family" => "lladdr" }
       end
       if line =~ /\s+inet (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) netmask 0x(([0-9a-f]){1,8})\s*$/
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
-        iface[cint][:addresses][$1] = { "family" => "inet", "netmask" => $2.scanf("%2x" * 4) * "." }
+        iface[cint][:addresses] ||= Mash.new
+        iface[cint][:addresses][$1] = { "family" => "inet", "netmask" => hex_to_dec_netmask($2) }
       end
       if line =~ /\s+inet (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) netmask 0x(([0-9a-f]){1,8}) broadcast (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
-        iface[cint][:addresses][$1] = { "family" => "inet", "netmask" => $2.scanf("%2x" * 4) * ".", "broadcast" => $4 }
+        iface[cint][:addresses] ||= Mash.new
+        iface[cint][:addresses][$1] = { "family" => "inet", "netmask" => hex_to_dec_netmask($2) , "broadcast" => $4 }
       end
       if line =~ /\s+inet6 ([a-f0-9\:]+)(\s*|(\%[a-z0-9]+)\s*) prefixlen (\d+)\s*/
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        iface[cint][:addresses] ||= Mash.new
         iface[cint][:addresses][$1] = { "family" => "inet6", "prefixlen" => $4 , "scope" => scope_lookup($1) }
       end
       if line =~ /\s+inet6 ([a-f0-9\:]+)(\s*|(\%[a-z0-9]+)\s*) prefixlen (\d+) scopeid 0x([a-f0-9]+)/
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        iface[cint][:addresses] ||= Mash.new
         iface[cint][:addresses][$1] = { "family" => "inet6", "prefixlen" => $4 , "scope" => scope_lookup($1) }
       end
       if line =~ /^\s+media: ((\w+)|(\w+ [a-zA-Z0-9\-\<\>]+)) status: (\w+)/
-        iface[cint][:media] = Mash.new unless iface[cint][:media]
+        iface[cint][:media] ||= Mash.new
         iface[cint][:media][:selected] = parse_media($1)
         iface[cint][:status] = $4
       end
       if line =~ /^\s+supported media: (.*)/
-        iface[cint][:media] = Mash.new unless iface[cint][:media]
+        iface[cint][:media] ||= Mash.new
         iface[cint][:media][:supported] = parse_media($1)
       end
     end
@@ -164,7 +170,8 @@ Ohai.plugin(:Network) do
       if line =~ /^\S+ \((\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\) at ([a-fA-F0-9\:]+) on ([a-zA-Z0-9\.\:\-]+).*\[(\w+)\]/
         # MAC addr really should be normalized to include all the zeroes.
         next if iface[$3].nil? # this should never happen
-        iface[$3][:arp] = Mash.new unless iface[$3][:arp]
+
+        iface[$3][:arp] ||= Mash.new
         iface[$3][:arp][$1] = $2
       end
     end
@@ -188,9 +195,10 @@ Ohai.plugin(:Network) do
           line =~ /^([a-zA-Z0-9\.\:\-\*]+)\s+\d+\s+\<[a-zA-Z0-9\#]+\>(\s+)(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)/
         ifname = locate_interface(iface, $1, $2)
         next if iface[ifname].nil? # this shouldn't happen, but just in case
-        net_counters[ifname] = Mash.new unless net_counters[ifname]
-        net_counters[ifname] = { :rx => { :bytes => $5, :packets => $3, :errors => $4, :drop => 0, :overrun => 0, :frame => 0, :compressed => 0, :multicast => 0 },
-                                 :tx => { :bytes => $8, :packets => $6, :errors => $7, :drop => 0, :overrun => 0, :collisions => $9, :carrier => 0, :compressed => 0 },
+
+        net_counters[ifname] ||= Mash.new
+        net_counters[ifname] = { rx: { bytes: $5, packets: $3, errors: $4, drop: 0, overrun: 0, frame: 0, compressed: 0, multicast: 0 },
+                                 tx: { bytes: $8, packets: $6, errors: $7, drop: 0, overrun: 0, collisions: $9, carrier: 0, compressed: 0 },
         }
       end
     end
