@@ -20,6 +20,7 @@
 
 Ohai.plugin(:Virtualization) do
   provides "virtualization"
+  depends "hardware"
 
   def vboxmanage_exists?
     which("VBoxManage")
@@ -37,9 +38,19 @@ Ohai.plugin(:Virtualization) do
     ::File.exist?("/Applications/VMware\ Fusion.app/")
   end
 
+  def docker_exists?
+    which("docker")
+  end
+
   collect_data(:darwin) do
     virtualization Mash.new unless virtualization
-    virtualization[:systems] = Mash.new unless virtualization[:systems]
+    virtualization[:systems] ||= Mash.new
+
+    if docker_exists?
+      virtualization[:system] = "docker"
+      virtualization[:role] = "host"
+      virtualization[:systems][:docker] = "host"
+    end
 
     if vboxmanage_exists?
       virtualization[:system] = "vbox"
@@ -47,12 +58,24 @@ Ohai.plugin(:Virtualization) do
       virtualization[:systems][:vbox] = "host"
     end
 
+    if hardware[:boot_rom_version].match?(/VirtualBox/i)
+      virtualization[:system] = "vbox"
+      virtualization[:role] = "guest"
+      virtualization[:systems][:vbox] = "guest"
+    end
+
     if fusion_exists?
       virtualization[:system] = "vmware"
       virtualization[:role] = "host"
       virtualization[:systems][:vmware] = "host"
     end
 
+    if hardware[:boot_rom_version].match?(/VMW/i)
+      virtualization[:system] = "vmware"
+      virtualization[:role] = "guest"
+      virtualization[:systems][:vmware] = "guest"
+    end
+
     if prlctl_exists?
       virtualization[:system] = "parallels"
       virtualization[:role] = "host"
