@@ -22,7 +22,7 @@ Ohai.plugin(:DMI) do
   # dmidecode does not return data without access to /dev/mem (or its equivalent)
 
   collect_data do
-    require "ohai/common/dmi"
+    require_relative "../common/dmi"
     dmi Mash.new
 
     # all output lines should fall within one of these patterns
@@ -47,8 +47,8 @@ Ohai.plugin(:DMI) do
     begin
       so = shell_out("dmidecode")
       # ==== EXAMPLE RECORD: ====
-      #Handle 0x0000, DMI type 0, 24 bytes
-      #BIOS Information
+      # Handle 0x0000, DMI type 0, 24 bytes
+      # BIOS Information
       #        Vendor: American Megatrends Inc.
       #        Version: 080012
       # ... similar lines trimmed
@@ -58,61 +58,61 @@ Ohai.plugin(:DMI) do
       # ... similar lines trimmed
       so.stdout.lines do |line|
         next if blank_line.match(line)
-        line = line.encode(line.encoding, :universal_newline => true)
 
-        if dmidecode_version = dmidecode_version_line.match(line)
+        line = line.encode(line.encoding, universal_newline: true)
+
+        if ( dmidecode_version = dmidecode_version_line.match(line) )
           dmi[:dmidecode_version] = dmidecode_version[1]
 
-        elsif smbios_version = smbios_version_line.match(line)
+        elsif ( smbios_version = smbios_version_line.match(line) )
           dmi[:smbios_version] = smbios_version[1]
 
-        elsif structures = structures_line.match(line)
+        elsif ( structures = structures_line.match(line) )
           dmi[:structures] = Mash.new
           dmi[:structures][:count] = structures[1]
           dmi[:structures][:size] = structures[2]
 
-        elsif table_location = table_location_line.match(line)
+        elsif ( table_location = table_location_line.match(line) )
           dmi[:table_location] = table_location[1]
 
-        elsif handle = handle_line.match(line)
-          # Don't overcapture for now (OHAI-260)
-          unless Ohai::Common::DMI::ID_TO_CAPTURE.include?(handle[2].to_i)
+        elsif ( handle = handle_line.match(line) )
+          unless Ohai::Common::DMI.whitelisted_ids.include?(handle[2].to_i)
             dmi_record = nil
             next
           end
 
-          dmi_record = { :type => Ohai::Common::DMI.id_lookup(handle[2]) }
+          dmi_record = { type: Ohai::Common::DMI.id_lookup(handle[2]) }
 
-          dmi[dmi_record[:type]] = Mash.new unless dmi.has_key?(dmi_record[:type])
-          dmi[dmi_record[:type]][:all_records] = [] unless dmi[dmi_record[:type]].has_key?(:all_records)
+          dmi[dmi_record[:type]] ||= Mash.new
+          dmi[dmi_record[:type]][:all_records] ||= []
           dmi_record[:position] = dmi[dmi_record[:type]][:all_records].length
           dmi[dmi_record[:type]][:all_records].push(Mash.new)
           dmi[dmi_record[:type]][:all_records][dmi_record[:position]][:record_id] = handle[1]
           dmi[dmi_record[:type]][:all_records][dmi_record[:position]][:size] = handle[2]
           field = nil
 
-        elsif type = type_line.match(line)
+        elsif ( type = type_line.match(line) )
           if dmi_record .nil?
-            Ohai::Log.debug("Plugin DMI: unexpected data line found before header; discarding:\n#{line}")
+            logger.trace("Plugin DMI: unexpected data line found before header; discarding:\n#{line}")
             next
           end
           dmi[dmi_record[:type]][:all_records][dmi_record[:position]][:application_identifier] = type[1]
 
-        elsif data = data_line.match(line)
+        elsif ( data = data_line.match(line) )
           if dmi_record .nil?
-            Ohai::Log.debug("Plugin DMI: unexpected data line found before header; discarding:\n#{line}")
+            logger.trace("Plugin DMI: unexpected data line found before header; discarding:\n#{line}")
             next
           end
           dmi[dmi_record[:type]][:all_records][dmi_record[:position]][data[1]] = data[2]
           field = data[1]
 
-        elsif extended_data = extended_data_line.match(line)
+        elsif ( extended_data = extended_data_line.match(line) )
           if dmi_record .nil?
-            Ohai::Log.debug("Plugin DMI: unexpected extended data line found before header; discarding:\n#{line}")
+            logger.trace("Plugin DMI: unexpected extended data line found before header; discarding:\n#{line}")
             next
           end
           if field .nil?
-            Ohai::Log.debug("Plugin DMI: unexpected extended data line found outside data section; discarding:\n#{line}")
+            logger.trace("Plugin DMI: unexpected extended data line found outside data section; discarding:\n#{line}")
             next
           end
           # overwrite "raw" value with a new Mash
@@ -120,14 +120,14 @@ Ohai.plugin(:DMI) do
           dmi[dmi_record[:type]][:all_records][dmi_record[:position]][field][extended_data[1]] = nil
 
         else
-          Ohai::Log.debug("Plugin DMI: unrecognized output line; discarding:\n#{line}")
+          logger.trace("Plugin DMI: unrecognized output line; discarding:\n#{line}")
 
         end
       end
 
       Ohai::Common::DMI.convenience_keys(dmi)
     rescue Ohai::Exceptions::Exec
-      Ohai::Log.debug('Plugin DMI: Could not shell_out "dmidecode". Skipping data')
+      logger.trace('Plugin DMI: Could not shell_out "dmidecode". Skipping data')
     end
   end
 end
