@@ -18,17 +18,17 @@ Ohai.plugin(:Go) do
   depends "languages"
 
   collect_data do
-    begin
-      so = shell_out("go version")
-      # Sample output:
-      # go version go1.6.1 darwin/amd64
-      if so.exitstatus == 0 && so.stdout =~ /go(\S+)/
-        go = Mash.new
-        go[:version] = $1
-        languages[:go] = go
-      end
-    rescue Ohai::Exceptions::Exec
-      Ohai::Log.debug('Plugin Go: Could not shell_out "go version". Skipping plugin')
+
+    so = shell_out("go version")
+    # Sample output:
+    # go version go1.6.1 darwin/amd64
+    if so.exitstatus == 0 && so.stdout =~ /go(\S+)/
+      go = Mash.new
+      go[:version] = $1
+      languages[:go] = go
     end
+  rescue Ohai::Exceptions::Exec
+    logger.trace('Plugin Go: Could not shell_out "go version". Skipping plugin')
+
   end
 end
