@@ -21,18 +21,18 @@ Ohai.plugin(:Groovy) do
   depends "languages"
 
   collect_data do
-    begin
-      so = shell_out("groovy -v")
-      # Sample output:
-      # Groovy Version: 2.4.6 JVM: 1.8.0_60 Vendor: Oracle Corporation OS: Mac OS X
-      if so.exitstatus == 0 && so.stdout =~ /Groovy Version: (\S+).*JVM: (\S+)/
-        groovy = Mash.new
-        groovy[:version] = $1
-        groovy[:jvm] = $2
-        languages[:groovy] = groovy
-      end
-    rescue Ohai::Exceptions::Exec
-      Ohai::Log.debug('Plugin Groovy: Could not shell_out "groovy -v". Skipping plugin')
+
+    so = shell_out("groovy -v")
+    # Sample output:
+    # Groovy Version: 2.4.6 JVM: 1.8.0_60 Vendor: Oracle Corporation OS: Mac OS X
+    if so.exitstatus == 0 && so.stdout =~ /Groovy Version: (\S+).*JVM: (\S+)/
+      groovy = Mash.new
+      groovy[:version] = $1
+      groovy[:jvm] = $2
+      languages[:groovy] = groovy
     end
+  rescue Ohai::Exceptions::Exec
+    logger.trace('Plugin Groovy: Could not shell_out "groovy -v". Skipping plugin')
+
   end
 end
