@@ -6,7 +6,7 @@
 # Author:: Doug MacEachern (<dougm@vmware.com>)
 # Author:: James Gartrell (<jgartrel@gmail.com>)
 # Author:: Isa Farnik (<isa@chef.io>)
-# Copyright:: Copyright (c) 2008-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2008-2018, Chef Software Inc.
 # Copyright:: Copyright (c) 2009 Bryan McLellan
 # Copyright:: Copyright (c) 2009 Daniel DeLeo
 # Copyright:: Copyright (c) 2010 VMware, Inc.
@@ -26,7 +26,7 @@
 #
 
 Ohai.plugin(:Hostname) do
-  require "socket"
+  require "socket" unless defined?(Socket)
   require "ipaddr"
 
   provides "domain", "hostname", "fqdn", "machinename"
@@ -74,7 +74,7 @@ Ohai.plugin(:Hostname) do
     end
   end
 
-  collect_data(:hpux, :default) do
+  collect_data(:default) do
     machinename from_cmd("hostname")
     fqdn resolve_fqdn
     collect_hostname
@@ -103,19 +103,20 @@ Ohai.plugin(:Hostname) do
       # Sometimes... very rarely, but sometimes, 'hostname --fqdn' falsely
       # returns a blank string. WTF.
       if ourfqdn.nil? || ourfqdn.empty?
-        Ohai::Log.debug("Plugin Hostname: hostname returned an empty string, retrying once.")
+        logger.trace("Plugin Hostname: hostname returned an empty string, retrying once.")
         ourfqdn = resolve_fqdn
       end
 
       if ourfqdn.nil? || ourfqdn.empty?
-        Ohai::Log.debug("Plugin Hostname: hostname returned an empty string twice and will" +
+        logger.trace("Plugin Hostname: hostname returned an empty string twice and will" +
                         "not be set.")
       else
         fqdn ourfqdn
       end
     rescue
-      Ohai::Log.debug(
-        "Plugin Hostname: hostname returned an error, probably no domain set")
+      logger.trace(
+        "Plugin Hostname: hostname returned an error, probably no domain set"
+      )
     end
     domain collect_domain
   end
@@ -135,19 +136,19 @@ Ohai.plugin(:Hostname) do
       # Sometimes... very rarely, but sometimes, 'hostname --fqdn' falsely
       # returns a blank string. WTF.
       if ourfqdn.nil? || ourfqdn.empty?
-        Ohai::Log.debug("Plugin Hostname: hostname --fqdn returned an empty string, retrying " +
+        logger.trace("Plugin Hostname: hostname --fqdn returned an empty string, retrying " +
                         "once.")
         ourfqdn = from_cmd("hostname --fqdn")
       end
 
       if ourfqdn.nil? || ourfqdn.empty?
-        Ohai::Log.debug("Plugin Hostname: hostname --fqdn returned an empty string twice and " +
+        logger.trace("Plugin Hostname: hostname --fqdn returned an empty string twice and " +
                         "will not be set.")
       else
         fqdn ourfqdn
       end
     rescue
-      Ohai::Log.debug("Plugin Hostname: hostname --fqdn returned an error, probably no domain set")
+      logger.trace("Plugin Hostname: hostname --fqdn returned an error, probably no domain set")
     end
     domain collect_domain
   end
@@ -161,21 +162,28 @@ Ohai.plugin(:Hostname) do
 
   collect_data(:windows) do
     require "wmi-lite/wmi"
-    require "socket"
+    require "socket" unless defined?(Socket)
 
     wmi = WmiLite::Wmi.new
     host = wmi.first_of("Win32_ComputerSystem")
 
-    hostname "#{host['dnshostname']}"
-    machinename "#{host['name']}"
+    hostname host["dnshostname"].to_s
+    machinename host["name"].to_s
 
     info = Socket.gethostbyname(Socket.gethostname)
     if info.first =~ /.+?\.(.*)/
       fqdn info.first
     else
-      #host is not in dns. optionally use:
-      #C:\WINDOWS\system32\drivers\etc\hosts
-      fqdn Socket.gethostbyaddr(info.last).first
+      # host is not in dns. optionally use:
+      # C:\WINDOWS\system32\drivers\etc\hosts
+      info[3..info.length].reverse_each do |addr|
+        hostent = Socket.gethostbyaddr(addr)
+        if hostent.first =~ /.+?\.(.*)/
+          fqdn hostent.first
+          break
+        end
+      end
+      fqdn info.first unless fqdn
     end
     domain collect_domain
   end
