@@ -24,7 +24,7 @@ Ohai.plugin(:Linode) do
   #
   # Returns true or false
   def has_linode_kernel?
-    if kernel_data = kernel
+    if ( kernel_data = kernel )
       kernel_data[:release].split("-").last =~ /linode/
     end
   end
@@ -43,7 +43,7 @@ Ohai.plugin(:Linode) do
   #
   # Alters linode mash with new interface based on name parameter
   def get_ip_address(name, eth)
-    if eth_iface = network[:interfaces][eth]
+    if ( eth_iface = network[:interfaces][eth] )
       eth_iface[:addresses].each do |key, info|
         linode[name] = key if info["family"] == "inet"
       end
@@ -53,13 +53,13 @@ Ohai.plugin(:Linode) do
   collect_data do
     # Setup linode mash if it is a linode system
     if looks_like_linode?
-      Ohai::Log.debug("Plugin Linode: looks_like_linode? == true")
+      logger.trace("Plugin Linode: looks_like_linode? == true")
       linode Mash.new
       get_ip_address(:public_ip, :eth0)
       get_ip_address(:private_ip, "eth0:1")
-      hint?("linode").each { |k, v| linode[k] = v } if hint?("linode").kind_of?(Hash)
+      hint?("linode").each { |k, v| linode[k] = v } if hint?("linode").is_a?(Hash)
     else
-      Ohai::Log.debug("Plugin Linode: looks_like_linode? == false")
+      logger.trace("Plugin Linode: looks_like_linode? == false")
     end
   end
 end
