@@ -1,6 +1,6 @@
 #
 # Author:: Matt Wrock (<matt@mattwrock.com>)
-# Copyright:: Copyright (c) 2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2016-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -28,10 +28,10 @@ Ohai.plugin(:Fips) do
   collect_data(:linux) do
     fips Mash.new
 
-    begin
-      enabled = File.read("/proc/sys/crypto/fips_enabled").chomp
-      fips["kernel"] = { "enabled" => enabled == "0" ? false : true }
-    rescue Errno::ENOENT
+    require "openssl" unless defined?(OpenSSL)
+    if defined?(OpenSSL.fips_mode) && OpenSSL.fips_mode && !$FIPS_TEST_MODE
+      fips["kernel"] = { "enabled" => true }
+    else
       fips["kernel"] = { "enabled" => false }
     end
   end
