@@ -22,7 +22,7 @@ Ohai.plugin(:LSB) do
   collect_data(:linux) do
     lsb Mash.new
 
-    if File.exists?("/usr/bin/lsb_release")
+    if File.exist?("/usr/bin/lsb_release")
       # From package redhat-lsb on Fedora/Redhat, lsb-release on Debian/Ubuntu
       so = shell_out("lsb_release -a")
       so.stdout.lines do |line|
@@ -39,7 +39,7 @@ Ohai.plugin(:LSB) do
           lsb[:id] = line
         end
       end
-    elsif File.exists?("/etc/lsb-release")
+    elsif File.exist?("/etc/lsb-release")
       # Old, non-standard Debian support
       File.open("/etc/lsb-release").each do |line|
         case line
@@ -54,7 +54,7 @@ Ohai.plugin(:LSB) do
         end
       end
     else
-      Ohai::Log.debug("Plugin LSB: Skipping LSB, cannot find /etc/lsb-release or /usr/bin/lsb_release")
+      logger.trace("Plugin LSB: Skipping LSB, cannot find /etc/lsb-release or /usr/bin/lsb_release")
     end
   end
 end
