@@ -23,6 +23,7 @@ Ohai.plugin(:Memory) do
     memory Mash.new
     memory[:swap] = Mash.new
     memory[:hugepages] = Mash.new
+    memory[:directmap] = Mash.new
 
     File.open("/proc/meminfo").each do |line|
       case line
@@ -85,15 +86,19 @@ Ohai.plugin(:Memory) do
       when /^SwapFree:\s+(\d+) (.+)$/
         memory[:swap][:free] = "#{$1}#{$2}"
       when /^HugePages_Total:\s+(\d+)$/
-        memory[:hugepages][:total] = "#{$1}"
+        memory[:hugepages][:total] = $1.to_s
       when /^HugePages_Free:\s+(\d+)$/
-        memory[:hugepages][:free] = "#{$1}"
+        memory[:hugepages][:free] = $1.to_s
       when /^HugePages_Rsvd:\s+(\d+)$/
-        memory[:hugepages][:reserved] = "#{$1}"
+        memory[:hugepages][:reserved] = $1.to_s
       when /^HugePages_Surp:\s+(\d+)$/
-        memory[:hugepages][:surplus] = "#{$1}"
+        memory[:hugepages][:surplus] = $1.to_s
       when /^Hugepagesize:\s+(\d+) (.+)$/
         memory[:hugepage_size] = "#{$1}#{$2}"
+      when /^Hugetlb:\s+(\d+) (.+)$/
+        memory[:hugetlb] = "#{$1}#{$2}"
+      when /^DirectMap([0-9]+[a-zA-Z]):\s+(\d+) (.+)$/
+        memory[:directmap][$1.to_sym] = "#{$2}#{$3}"
       end
     end
   end
