@@ -30,6 +30,7 @@ Ohai.plugin(:Network) do
     return "IPIP" if encap.eql?("IPIP Tunnel")
     return "6to4" if encap.eql?("IPv6-in-IPv4")
     return "Ethernet" if encap.eql?("ether")
+
     encap
   end
 
@@ -55,10 +56,10 @@ Ohai.plugin(:Network) do
       if line =~ /^([a-f0-9\:\.]+)\s+dev\s+([^\s]+)\s+lladdr\s+([a-fA-F0-9\:]+)/
         interface = iface[$2]
         unless interface
-          Ohai::Log.warn("neighbor list has entries for unknown interface #{interface}")
+          logger.warn("neighbor list has entries for unknown interface #{interface}")
           next
         end
-        interface[neigh_attr] = Mash.new unless interface[neigh_attr]
+        interface[neigh_attr] ||= Mash.new
         interface[neigh_attr][$1] = $3.downcase
       end
     end
@@ -76,7 +77,7 @@ Ohai.plugin(:Network) do
     so = shell_out("ip -o -f #{family[:name]} route show table #{default_route_table}")
     so.stdout.lines do |line|
       line.strip!
-      Ohai::Log.debug("Plugin Network: Parsing #{line}")
+      logger.trace("Plugin Network: Parsing #{line}")
       if line =~ /\\/
         parts = line.split('\\')
         route_dest = parts.shift.strip
@@ -91,18 +92,18 @@ Ohai.plugin(:Network) do
         if route_ending =~ /\bdev\s+([^\s]+)\b/
           route_int = $1
         else
-          Ohai::Log.debug("Plugin Network: Skipping route entry without a device: '#{line}'")
+          logger.trace("Plugin Network: Skipping route entry without a device: '#{line}'")
           next
         end
         route_int = "venet0:0" if is_openvz? && !is_openvz_host? && route_int == "venet0" && iface["venet0:0"]
 
         unless iface[route_int]
-          Ohai::Log.debug("Plugin Network: Skipping previously unseen interface from 'ip route show': #{route_int}")
+          logger.trace("Plugin Network: Skipping previously unseen interface from 'ip route show': #{route_int}")
           next
         end
 
-        route_entry = Mash.new(:destination => route_dest,
-                               :family => family[:name])
+        route_entry = Mash.new(destination: route_dest,
+                               family: family[:name])
         %w{via scope metric proto src}.each do |k|
           # http://rubular.com/r/pwTNp65VFf
           route_entry[k] = $1 if route_ending =~ /\b#{k}\s+([^\s]+)/
@@ -113,14 +114,14 @@ Ohai.plugin(:Network) do
         # unless the interface has no addresses of this type at all
         if route_entry[:src]
           addr = iface[route_int][:addresses]
-          unless addr.nil? || addr.has_key?(route_entry[:src]) ||
+          unless addr.nil? || addr.key?(route_entry[:src]) ||
               addr.values.all? { |a| a["family"] != family[:name] }
-            Ohai::Log.debug("Plugin Network: Skipping route entry whose src does not match the interface IP")
+            logger.trace("Plugin Network: Skipping route entry whose src does not match the interface IP")
             next
           end
         end
 
-        iface[route_int][:routes] = Array.new unless iface[route_int][:routes]
+        iface[route_int][:routes] = [] unless iface[route_int][:routes]
         iface[route_int][:routes] << route_entry
       end
     end
@@ -140,7 +141,7 @@ Ohai.plugin(:Network) do
     iface.collect do |i, iv|
       if iv[:routes]
         iv[:routes].collect do |r|
-          r.merge(:dev => i) if r[:family] == family[:name]
+          r.merge(dev: i) if r[:family] == family[:name]
         end.compact
       end
     end.compact.flatten
@@ -149,16 +150,19 @@ Ohai.plugin(:Network) do
   # determine layer 1 details for the interface using ethtool
   def ethernet_layer_one(iface)
     return iface unless ethtool_binary_path
+
     keys = %w{ Speed Duplex Port Transceiver Auto-negotiation MDI-X }
     iface.each_key do |tmp_int|
       next unless iface[tmp_int][:encapsulation] == "Ethernet"
+
       so = shell_out("#{ethtool_binary_path} #{tmp_int}")
       so.stdout.lines do |line|
         line.chomp!
-        Ohai::Log.debug("Plugin Network: Parsing ethtool output: #{line}")
+        logger.trace("Plugin Network: Parsing ethtool output: #{line}")
         line.lstrip!
         k, v = line.split(": ")
         next unless keys.include? k
+
         k.downcase!.tr!("-", "_")
         if k == "speed"
           k = "link_speed" # This is not necessarily the maximum speed the NIC supports
@@ -173,15 +177,18 @@ Ohai.plugin(:Network) do
   # determine ring parameters for the interface using ethtool
   def ethernet_ring_parameters(iface)
     return iface unless ethtool_binary_path
+
     iface.each_key do |tmp_int|
       next unless iface[tmp_int][:encapsulation] == "Ethernet"
+
       so = shell_out("#{ethtool_binary_path} -g #{tmp_int}")
-      Ohai::Log.debug("Plugin Network: Parsing ethtool output: #{so.stdout}")
+      logger.trace("Plugin Network: Parsing ethtool output: #{so.stdout}")
       type = nil
       iface[tmp_int]["ring_params"] = {}
       so.stdout.lines.each do |line|
         next if line.start_with?("Ring parameters for")
         next if line.strip.nil?
+
         if line =~ /Pre-set maximums/
           type = "max"
           next
@@ -192,7 +199,7 @@ Ohai.plugin(:Network) do
         end
         key, val = line.split(/:\s+/)
         if type && val
-          ring_key = "#{type}_#{key.downcase.tr(' ', '_')}"
+          ring_key = "#{type}_#{key.downcase.tr(" ", "_")}"
           iface[tmp_int]["ring_params"][ring_key] = val.to_i
         end
       end
@@ -208,8 +215,8 @@ Ohai.plugin(:Network) do
     so.stdout.lines do |line|
       if line =~ IPROUTE_INT_REGEX
         tmp_int = $2
-        iface[tmp_int] = Mash.new unless iface[tmp_int]
-        net_counters[tmp_int] = Mash.new unless net_counters[tmp_int]
+        iface[tmp_int] ||= Mash.new
+        net_counters[tmp_int] ||= Mash.new
       end
 
       if line =~ /^\s+(ip6tnl|ipip)/
@@ -239,7 +246,7 @@ Ohai.plugin(:Network) do
 
       if line =~ /(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)/
         int = on_rx ? :rx : :tx
-        net_counters[tmp_int][int] = Mash.new unless net_counters[tmp_int][int]
+        net_counters[tmp_int][int] ||= Mash.new
         net_counters[tmp_int][int][:bytes] = $1
         net_counters[tmp_int][int][:packets] = $2
         net_counters[tmp_int][int][:errors] = $3
@@ -255,7 +262,7 @@ Ohai.plugin(:Network) do
       end
 
       if line =~ /qlen (\d+)/
-        net_counters[tmp_int][:tx] = Mash.new unless net_counters[tmp_int][:tx]
+        net_counters[tmp_int][:tx] ||= Mash.new
         net_counters[tmp_int][:tx][:queuelen] = $1
       end
 
@@ -266,7 +273,7 @@ Ohai.plugin(:Network) do
         else
           tmp_id = $1
         end
-        iface[tmp_int][:vlan] = Mash.new unless iface[tmp_int][:vlan]
+        iface[tmp_int][:vlan] ||= Mash.new
         iface[tmp_int][:vlan][:id] = tmp_id
         iface[tmp_int][:vlan][:protocol] = tmp_prot if tmp_prot
 
@@ -276,7 +283,8 @@ Ohai.plugin(:Network) do
         end
       end
 
-      if line =~ /state (\w+)/
+      # https://rubular.com/r/JRp6lNANmpcLV5
+      if line =~ /\sstate (\w+)/
         iface[tmp_int]["state"] = $1.downcase
       end
     end
@@ -317,17 +325,17 @@ Ohai.plugin(:Network) do
   end
 
   def parse_ip_addr_link_line(cint, iface, line)
-    if line =~ /link\/(\w+) ([\da-f\:]+) /
+    if line =~ %r{link/(\w+) ([\da-f\:]+) }
       iface[cint][:encapsulation] = linux_encaps_lookup($1)
       unless $2 == "00:00:00:00:00:00"
-        iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        iface[cint][:addresses] ||= Mash.new
         iface[cint][:addresses][$2.upcase] = { "family" => "lladdr" }
       end
     end
   end
 
   def parse_ip_addr_inet_line(cint, iface, line)
-    if line =~ /inet (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})(\/(\d{1,2}))?/
+    if line =~ %r{inet (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})(/(\d{1,2}))?}
       tmp_addr, tmp_prefix = $1, $3
       tmp_prefix ||= "32"
       original_int = nil
@@ -340,8 +348,8 @@ Ohai.plugin(:Network) do
         cint = alias_int
       end
 
-      iface[cint] = Mash.new unless iface[cint] # Create the fake alias interface if needed
-      iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+      iface[cint] ||= Mash.new # Create the fake alias interface if needed
+      iface[cint][:addresses] ||= Mash.new
       iface[cint][:addresses][tmp_addr] = { "family" => "inet", "prefixlen" => tmp_prefix }
       iface[cint][:addresses][tmp_addr][:netmask] = IPAddr.new("255.255.255.255").mask(tmp_prefix.to_i).to_s
 
@@ -364,8 +372,8 @@ Ohai.plugin(:Network) do
   end
 
   def parse_ip_addr_inet6_line(cint, iface, line)
-    if line =~ /inet6 ([a-f0-9\:]+)\/(\d+) scope (\w+)( .*)?/
-      iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+    if line =~ %r{inet6 ([a-f0-9\:]+)/(\d+) scope (\w+)( .*)?}
+      iface[cint][:addresses] ||= Mash.new
       tmp_addr = $1
       tags = $4 || ""
       tags = tags.split(" ")
@@ -388,18 +396,20 @@ Ohai.plugin(:Network) do
   def choose_default_route(routes)
     routes.select do |r|
       r[:destination] == "default"
-    end.sort do |x, y|
+    end.min do |x, y|
       (x[:metric].nil? ? 0 : x[:metric].to_i) <=> (y[:metric].nil? ? 0 : y[:metric].to_i)
-    end.first
+    end
   end
 
   def interface_has_no_addresses_in_family?(iface, family)
     return true if iface[:addresses].nil?
+
     iface[:addresses].values.all? { |addr| addr["family"] != family }
   end
 
   def interface_have_address?(iface, address)
     return false if iface[:addresses].nil?
+
     iface[:addresses].key?(address)
   end
 
@@ -424,7 +434,7 @@ Ohai.plugin(:Network) do
   # ipv4/ipv6 routes are different enough that having a single algorithm to select the favored route for both creates unnecessary complexity
   # this method attempts to deduce the route that is most important to the user, which is later used to deduce the favored values for {ip,mac,ip6}address
   # we only consider routes that are default routes, or those routes that get us to the gateway for a default route
-  def favored_default_route(routes, iface, default_route, family)
+  def favored_default_route_linux(routes, iface, default_route, family)
     routes.select do |r|
       if family[:name] == "inet"
         # the route must have a source address
@@ -447,7 +457,7 @@ Ohai.plugin(:Network) do
           iface[r[:dev]][:state] == "up" &&
           route_is_valid_default_route?(r, default_route)
       end
-    end.sort_by do |r|
+    end.min_by do |r|
       # sorting the selected routes:
       # - getting default routes first
       # - then sort by metric
@@ -463,7 +473,7 @@ Ohai.plugin(:Network) do
          0
        end,
       ]
-    end.first
+    end
   end
 
   # Both the network plugin and this plugin (linux/network) are run on linux. This plugin runs first.
@@ -476,9 +486,9 @@ Ohai.plugin(:Network) do
     net_counters = Mash.new
 
     network Mash.new unless network
-    network[:interfaces] = Mash.new unless network[:interfaces]
+    network[:interfaces] ||= Mash.new
     counters Mash.new unless counters
-    counters[:network] = Mash.new unless counters[:network]
+    counters[:network] ||= Mash.new
 
     # ohai.plugin[:network][:default_route_table] = 'default'
     if configuration(:default_route_table).nil? || configuration(:default_route_table).empty?
@@ -486,28 +496,28 @@ Ohai.plugin(:Network) do
     else
       default_route_table = configuration(:default_route_table)
     end
-    Ohai::Log.debug("Plugin Network: default route table is '#{default_route_table}'")
+    logger.trace("Plugin Network: default route table is '#{default_route_table}'")
 
     # Match the lead line for an interface from iproute2
     # 3: eth0.11@eth0: <BROADCAST,MULTICAST,UP,LOWER_UP> mtu 1500 qdisc noqueue state UP
     # The '@eth0:' portion doesn't exist on primary interfaces and thus is optional in the regex
-    IPROUTE_INT_REGEX = /^(\d+): ([0-9a-zA-Z@:\.\-_]*?)(@[0-9a-zA-Z]+|):\s/ unless defined? IPROUTE_INT_REGEX
+    IPROUTE_INT_REGEX ||= /^(\d+): ([0-9a-zA-Z@:\.\-_]*?)(@[0-9a-zA-Z]+|):\s/.freeze
 
     if which("ip")
       # families to get default routes from
       families = [{
-                    :name => "inet",
-                    :default_route => "0.0.0.0/0",
-                    :default_prefix => :default,
-                    :neighbour_attribute => :arp,
+                    name: "inet",
+                    default_route: "0.0.0.0/0",
+                    default_prefix: :default,
+                    neighbour_attribute: :arp,
                   }]
 
       if ipv6_enabled?
         families << {
-                      :name => "inet6",
-                      :default_route => "::/0",
-                      :default_prefix => :default_inet6,
-                      :neighbour_attribute => :neighbour_inet6,
+                      name: "inet6",
+                      default_route: "::/0",
+                      default_prefix: :default_inet6,
+                      neighbour_attribute: :neighbour_inet6,
                     }
       end
 
@@ -533,17 +543,17 @@ Ohai.plugin(:Network) do
                            else
                              "default_#{family[:name]}_interface"
                            end
-          Ohai::Log.debug("Plugin Network: Unable to determine '#{attribute_name}' as no default routes were found for that interface family")
+          logger.trace("Plugin Network: Unable to determine '#{attribute_name}' as no default routes were found for that interface family")
         else
           network["#{default_prefix}_interface"] = default_route[:dev]
-          Ohai::Log.debug("Plugin Network: #{default_prefix}_interface set to #{default_route[:dev]}")
+          logger.trace("Plugin Network: #{default_prefix}_interface set to #{default_route[:dev]}")
 
           # setting gateway to 0.0.0.0 or :: if the default route is a link level one
           network["#{default_prefix}_gateway"] = default_route[:via] ? default_route[:via] : family[:default_route].chomp("/0")
-          Ohai::Log.debug("Plugin Network: #{default_prefix}_gateway set to #{network["#{default_prefix}_gateway"]}")
+          logger.trace("Plugin Network: #{default_prefix}_gateway set to #{network["#{default_prefix}_gateway"]}")
 
           # deduce the default route the user most likely cares about to pick {ip,mac,ip6}address below
-          favored_route = favored_default_route(routes, iface, default_route, family)
+          favored_route = favored_default_route_linux(routes, iface, default_route, family)
 
           # FIXME: This entire block should go away, and the network plugin should be the sole source of {ip,ip6,mac}address
 
@@ -553,20 +563,20 @@ Ohai.plugin(:Network) do
             if family[:name] == "inet"
               ipaddress favored_route[:src]
               m = get_mac_for_interface(iface, favored_route[:dev])
-              Ohai::Log.debug("Plugin Network: Overwriting macaddress #{macaddress} with #{m} from interface #{favored_route[:dev]}") if macaddress
+              logger.trace("Plugin Network: Overwriting macaddress #{macaddress} with #{m} from interface #{favored_route[:dev]}") if macaddress
               macaddress m
             elsif family[:name] == "inet6"
               # this rarely does anything since we rarely have src for ipv6, so this usually falls back on the network plugin
               ip6address favored_route[:src]
               if macaddress
-                Ohai::Log.debug("Plugin Network: Not setting macaddress from ipv6 interface #{favored_route[:dev]} because macaddress is already set")
+                logger.trace("Plugin Network: Not setting macaddress from ipv6 interface #{favored_route[:dev]} because macaddress is already set")
               else
                 macaddress get_mac_for_interface(iface, favored_route[:dev])
               end
             end
           else
-            Ohai::Log.debug("Plugin Network: Unable to deduce the favored default route for family '#{family[:name]}' despite finding a default route, and is not setting ipaddress/ip6address/macaddress. the network plugin may provide fallbacks.")
-            Ohai::Log.debug("Plugin Network: This potential default route was excluded: #{default_route}")
+            logger.trace("Plugin Network: Unable to deduce the favored default route for family '#{family[:name]}' despite finding a default route, and is not setting ipaddress/ip6address/macaddress. the network plugin may provide fallbacks.")
+            logger.trace("Plugin Network: This potential default route was excluded: #{default_route}")
           end
         end
       end # end families.each
@@ -576,7 +586,7 @@ Ohai.plugin(:Network) do
         route_result = so.stdout.split($/).grep( /^0.0.0.0/ )[0].split( /[ \t]+/ )
         network[:default_gateway], network[:default_interface] = route_result.values_at(1, 7)
       rescue Ohai::Exceptions::Exec
-        Ohai::Log.debug("Plugin Network: Unable to determine default interface")
+        logger.trace("Plugin Network: Unable to determine default interface")
       end
 
       so = shell_out("ifconfig -a")
@@ -597,16 +607,16 @@ Ohai.plugin(:Network) do
           iface[cint][:encapsulation] = linux_encaps_lookup($1)
         end
         if line =~ /HWaddr (.+?)\s/
-          iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+          iface[cint][:addresses] ||= Mash.new
           iface[cint][:addresses][$1] = { "family" => "lladdr" }
         end
         if line =~ /inet addr:(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/
-          iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+          iface[cint][:addresses] ||= Mash.new
           iface[cint][:addresses][$1] = { "family" => "inet" }
           tmp_addr = $1
         end
-        if line =~ /inet6 addr: ([a-f0-9\:]+)\/(\d+) Scope:(\w+)/
-          iface[cint][:addresses] = Mash.new unless iface[cint][:addresses]
+        if line =~ %r{inet6 addr: ([a-f0-9\:]+)/(\d+) Scope:(\w+)}
+          iface[cint][:addresses] ||= Mash.new
           iface[cint][:addresses][$1] = { "family" => "inet6", "prefixlen" => $2, "scope" => ($3.eql?("Host") ? "Node" : $3) }
         end
         if line =~ /Bcast:(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/
@@ -626,7 +636,7 @@ Ohai.plugin(:Network) do
           iface[cint][:peer] = $1
         end
         if line =~ /RX packets:(\d+) errors:(\d+) dropped:(\d+) overruns:(\d+) frame:(\d+)/
-          net_counters[cint] = Mash.new unless net_counters[cint]
+          net_counters[cint] ||= Mash.new
           net_counters[cint][:rx] = { "packets" => $1, "errors" => $2, "drop" => $3, "overrun" => $4, "frame" => $5 }
         end
         if line =~ /TX packets:(\d+) errors:(\d+) dropped:(\d+) overruns:(\d+) carrier:(\d+)/
@@ -650,7 +660,8 @@ Ohai.plugin(:Network) do
       so.stdout.lines do |line|
         if line =~ /^\S+ \((\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\) at ([a-fA-F0-9\:]+) \[(\w+)\] on ([0-9a-zA-Z\.\:\-]+)/
           next unless iface[$4] # this should never happen
-          iface[$4][:arp] = Mash.new unless iface[$4][:arp]
+
+          iface[$4][:arp] ||= Mash.new
           iface[$4][:arp][$1] = $2.downcase
         end
       end
