@@ -20,12 +20,34 @@ Ohai.plugin(:Platform) do
   provides "platform", "platform_version", "platform_family"
   depends "lsb"
 
+  # the platform mappings between the 'ID' field in /etc/os-release and the value
+  # ohai uses. If you're adding a new platform here and you want to change the name
+  # you'll want to add it here and then add a spec for the platform_id_remap method
+  PLATFORM_MAPPINGS ||= {
+      "rhel" => "redhat",
+      "amzn" => "amazon",
+      "ol" => "oracle",
+      "sles" => "suse",
+      "sles_sap" => "suse",
+      "opensuse-leap" => "opensuseleap",
+      "xenenterprise" => "xenserver",
+      "cumulus-linux" => "cumulus",
+      "archarm" => "arch",
+    }.freeze
+
+  # @deprecated
   def get_redhatish_platform(contents)
     contents[/^Red Hat/i] ? "redhat" : contents[/(\w+)/i, 1].downcase
   end
 
+  # See https://rubular.com/r/78c1yXYa7zDhdV for example matches
+  #
+  # @param contents [String] the contents of /etc/redhat-release
+  #
+  # @returns [String] the version string
+  #
   def get_redhatish_version(contents)
-    contents[/Rawhide/i] ? contents[/((\d+) \(Rawhide\))/i, 1].downcase : contents[/release ([\d\.]+)/, 1]
+    contents[/(release)? ([\d\.]+)/, 2]
   end
 
   #
@@ -37,6 +59,7 @@ Ohai.plugin(:Platform) do
   #
   def read_os_release_info(file)
     return nil unless File.exist?(file)
+
     File.read(file).split.inject({}) do |map, line|
       key, value = line.split("=")
       map[key] = value.gsub(/\A"|"\Z/, "") if value
@@ -72,56 +95,50 @@ Ohai.plugin(:Platform) do
     File.exist?("/etc/os-release") && os_release_info["CISCO_RELEASE_INFO"]
   end
 
-  #
-  # Determines the platform version for Cumulus Linux systems
-  #
-  # @returns [String] cumulus Linux version from /etc/cumulus/etc.replace/os-release
-  #
-  def cumulus_version
-    release_contents = File.read("/etc/cumulus/etc.replace/os-release")
-    release_contents.match(/VERSION_ID=(.*)/)[1]
-  rescue NoMethodError, Errno::ENOENT, Errno::EACCES # rescue regex failure, file missing, or permission denied
-    Ohai::Log.warn("Detected Cumulus Linux, but /etc/cumulus/etc/replace/os-release could not be parsed to determine platform_version")
-    nil
-  end
-
   #
   # Determines the platform version for F5 Big-IP systems
   #
+  # @deprecated
+  #
   # @returns [String] bigip Linux version from /etc/f5-release
   #
   def bigip_version
     release_contents = File.read("/etc/f5-release")
     release_contents.match(/BIG-IP release (\S*)/)[1] # http://rubular.com/r/O8nlrBVqSb
   rescue NoMethodError, Errno::ENOENT, Errno::EACCES # rescue regex failure, file missing, or permission denied
-    Ohai::Log.warn("Detected F5 Big-IP, but /etc/f5-release could not be parsed to determine platform_version")
+    logger.warn("Detected F5 Big-IP, but /etc/f5-release could not be parsed to determine platform_version")
     nil
   end
 
+  # our platform names don't match os-release. given a time machine they would but ohai
+  # came before the os-release file. This method remaps the os-release names to
+  # the ohai names
   #
-  # Determines the platform version for Debian based systems
+  # @param id [String] the platform ID from /etc/os-release
   #
-  # @returns [String] version of the platform
+  # @returns [String] the platform name to use in Ohai
   #
-  def debian_platform_version
-    if platform == "cumulus"
-      cumulus_version
-    else # not cumulus
-      File.read("/etc/debian_version").chomp
-    end
+  def platform_id_remap(id)
+    # this catches the centos guest shell in the nexus switch which identifies itself as centos
+    return "nexus_centos" if id == "centos" && os_release_file_is_cisco?
+
+    # remap based on the hash of platforms
+    PLATFORM_MAPPINGS[id] || id
   end
 
   #
   # Determines the platform_family based on the platform
   #
+  # @param plat [String] the platform name
+  #
   # @returns [String] platform_family value
   #
-  def determine_platform_family
-    case platform
-    when /debian/, /ubuntu/, /linuxmint/, /raspbian/, /cumulus/
+  def platform_family_from_platform(plat)
+    case plat
+    when /debian/, /ubuntu/, /linuxmint/, /raspbian/, /cumulus/, /kali/
       # apt-get+dpkg almost certainly goes here
       "debian"
-    when /oracle/, /centos/, /redhat/, /scientific/, /enterpriseenterprise/, /xenserver/, /cloudlinux/, /ibm_powerkvm/, /parallels/, /nexus_centos/, /clearos/, /bigip/ # Note that 'enterpriseenterprise' is oracle's LSB "distributor ID"
+    when /oracle/, /centos/, /redhat/, /scientific/, /enterpriseenterprise/, /xcp/, /xenserver/, /cloudlinux/, /ibm_powerkvm/, /parallels/, /nexus_centos/, /clearos/, /bigip/ # Note that 'enterpriseenterprise' is oracle's LSB "distributor ID"
       # NOTE: "rhel" should be reserved exclusively for recompiled rhel versions that are nearly perfectly compatible down to the platform_version.
       # The operating systems that are "rhel" should all be as compatible as rhel7 = centos7 = oracle7 = scientific7 (98%-ish core RPM version compatibility
       # and the version numbers MUST track the upstream). The appropriate EPEL version repo should work nearly perfectly.  Some variation like the
@@ -131,7 +148,7 @@ Ohai.plugin(:Platform) do
       "rhel"
     when /amazon/
       "amazon"
-    when /suse/
+    when /suse/, /sles/, /opensuse/, /opensuseleap/, /sled/
       "suse"
     when /fedora/, /pidora/, /arista_eos/
       # In the broadest sense:  RPM-based, fedora-derived distributions which are not strictly re-compiled RHEL (if it uses RPMs, and smells more like redhat and less like
@@ -143,7 +160,7 @@ Ohai.plugin(:Platform) do
       "gentoo"
     when /slackware/
       "slackware"
-    when /arch/
+    when /arch/, /manjaro/, /antergos/
       "arch"
     when /exherbo/
       "exherbo"
@@ -151,10 +168,18 @@ Ohai.plugin(:Platform) do
       "alpine"
     when /clearlinux/
       "clearlinux"
+    when /mangeia/
+      "mandriva"
     end
   end
 
-  collect_data(:linux) do
+  # modern linux distros include a /etc/os-release file, which we now rely on for
+  # OS detection. For older distros that do not include that file we fall back to
+  # our pre-Ohai 15 detection logic, which is the method below. No new functionality
+  # should be added to this logic.
+  #
+  # @deprecated
+  def legacy_platform_detection
     # platform [ and platform_version ? ] should be lower case to avoid dealing with RedHat/Redhat/redhat matching
     if File.exist?("/etc/oracle-release")
       contents = File.read("/etc/oracle-release").chomp
@@ -173,32 +198,21 @@ Ohai.plugin(:Platform) do
       if lsb[:id] =~ /Ubuntu/i
         platform "ubuntu"
         platform_version lsb[:release]
-      elsif lsb[:id] =~ /LinuxMint/i
-        platform "linuxmint"
-        platform_version lsb[:release]
       else
-        if File.exist?("/usr/bin/raspi-config")
-          platform "raspbian"
-        elsif Dir.exist?("/etc/cumulus")
-          platform "cumulus"
-        else
-          platform "debian"
-        end
-        platform_version debian_platform_version
+        platform "debian"
+        platform_version File.read("/etc/debian_version").chomp
       end
     elsif File.exist?("/etc/parallels-release")
       contents = File.read("/etc/parallels-release").chomp
       platform get_redhatish_platform(contents)
       platform_version contents.match(/(\d\.\d\.\d)/)[0]
+    elsif File.exist?("/etc/Eos-release")
+      platform "arista_eos"
+      platform_version File.read("/etc/Eos-release").strip.split[-1]
     elsif File.exist?("/etc/redhat-release")
-      if os_release_file_is_cisco? # Cisco guestshell
-        platform "nexus_centos"
-        platform_version os_release_info["VERSION"]
-      else
-        contents = File.read("/etc/redhat-release").chomp
-        platform get_redhatish_platform(contents)
-        platform_version get_redhatish_version(contents)
-      end
+      contents = File.read("/etc/redhat-release").chomp
+      platform get_redhatish_platform(contents)
+      platform_version get_redhatish_version(contents)
     elsif File.exist?("/etc/system-release")
       contents = File.read("/etc/system-release").chomp
       platform get_redhatish_platform(contents)
@@ -218,13 +232,9 @@ Ohai.plugin(:Platform) do
       else
         platform "suse"
       end
-    elsif File.exist?("/etc/Eos-release")
-      platform "arista_eos"
-      platform_version File.read("/etc/Eos-release").strip.split[-1]
-      platform_family "fedora"
     elsif os_release_file_is_cisco?
       raise "unknown Cisco /etc/os-release or /etc/cisco-release ID_LIKE field" if
-        os_release_info["ID_LIKE"].nil? || ! os_release_info["ID_LIKE"].include?("wrlinux")
+        os_release_info["ID_LIKE"].nil? || !os_release_info["ID_LIKE"].include?("wrlinux")
 
       case os_release_info["ID"]
       when "nexus"
@@ -235,33 +245,18 @@ Ohai.plugin(:Platform) do
         raise "unknown Cisco /etc/os-release or /etc/cisco-release ID field"
       end
 
-      platform_family "wrlinux"
       platform_version os_release_info["VERSION"]
-    elsif File.exist?("/etc/gentoo-release")
-      platform "gentoo"
-      # the gentoo release version is the base version used to bootstrap
-      # a node and doesn't have a lot of meaning in a rolling release distro
-      # kernel release will be used - ex. 3.18.7-gentoo
-      platform_version `uname -r`.strip
     elsif File.exist?("/etc/slackware-version")
       platform "slackware"
       platform_version File.read("/etc/slackware-version").scan(/(\d+|\.+)/).join
-    elsif File.exist?("/etc/arch-release")
-      platform "arch"
-      # no way to determine platform_version in a rolling release distribution
-      # kernel release will be used - ex. 2.6.32-ARCH
-      platform_version `uname -r`.strip
     elsif File.exist?("/etc/exherbo-release")
       platform "exherbo"
       # no way to determine platform_version in a rolling release distribution
       # kernel release will be used - ex. 3.13
-      platform_version `uname -r`.strip
-    elsif File.exist?("/etc/alpine-release")
-      platform "alpine"
-      platform_version File.read("/etc/alpine-release").strip
+      platform_version shell_out("/bin/uname -r").stdout.strip
     elsif File.exist?("/usr/lib/os-release")
       contents = File.read("/usr/lib/os-release")
-      if /Clear Linux/ =~ contents
+      if /clear-linux-os/ =~ contents # Clear Linux https://clearlinux.org/
         platform "clearlinux"
         platform_version contents[/VERSION_ID=(\d+)/, 1]
       end
@@ -277,11 +272,41 @@ Ohai.plugin(:Platform) do
     elsif lsb[:id] =~ /XenServer/i
       platform "xenserver"
       platform_version lsb[:release]
+    elsif lsb[:id] =~ /XCP/i
+      platform "xcp"
+      platform_version lsb[:release]
     elsif lsb[:id] # LSB can provide odd data that changes between releases, so we currently fall back on it rather than dealing with its subtleties
       platform lsb[:id].downcase
       platform_version lsb[:release]
     end
+  end
 
-    platform_family determine_platform_family
+  # Grab the version from the VERSION_ID field and use the kernel release if that's not
+  # available. It should be there for everything, but rolling releases like arch / gentoo
+  # where we've traditionally used the kernel as the version
+  # @return String the OS version
+  def determine_os_version
+    # centos only includes the major version in os-release for some reason
+    if os_release_info["ID"] == "centos"
+      get_redhatish_version(File.read("/etc/redhat-release").chomp)
+    else
+      os_release_info["VERSION_ID"] || shell_out("/bin/uname -r").stdout.strip
+    end
+  end
+
+  collect_data(:linux) do
+    if ::File.exist?("/etc/os-release")
+      logger.trace("Plugin platform: Using /etc/os-release for platform detection")
+
+      # fixup os-release names to ohai platform names
+      platform platform_id_remap(os_release_info["ID"])
+
+      platform_version determine_os_version
+    else # we're on an old Linux distro
+      legacy_platform_detection
+    end
+
+    # unless we set it in a specific way with the platform logic above set based on platform data
+    platform_family platform_family_from_platform(platform) if platform_family.nil?
   end
 end
