@@ -18,6 +18,7 @@
 
 Ohai.plugin(:Sessions) do
   provides "sessions/by_session", "sessions/by_user"
+  optional true
 
   collect_data(:linux) do
     loginctl_path = which("loginctl")
@@ -27,8 +28,8 @@ Ohai.plugin(:Sessions) do
       loginctl = shell_out(cmd)
 
       sessions Mash.new unless sessions
-      sessions[:by_session] = Mash.new unless sessions[:by_session]
-      sessions[:by_user] = Mash.new unless sessions[:by_user]
+      sessions[:by_session] ||= Mash.new
+      sessions[:by_user] ||= Mash.new
 
       loginctl.stdout.split("\n").each do |line|
         session, uid, user, seat = line.split
@@ -46,7 +47,7 @@ Ohai.plugin(:Sessions) do
         end
       end
     else
-      Ohai::Log.debug("Plugin Sessions: Could not find loginctl. Skipping plugin.")
+      logger.trace("Plugin Sessions: Could not find loginctl. Skipping plugin.")
     end
   end
 end
