@@ -19,9 +19,6 @@
 Ohai.plugin(:SystemdPaths) do
   provides "systemd_paths"
 
-  require "ohai/util/file_helper"
-  include Ohai::Util::FileHelper
-
   collect_data(:linux) do
     systemd_path_path = which("systemd-path")
     if systemd_path_path
