@@ -1,6 +1,6 @@
 #
 # Author:: Matt Wrock (<matt@mattwrock.com>)
-# Copyright:: Copyright (c) 2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2016-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,24 +26,12 @@ Ohai.plugin(:Fips) do
   provides "fips"
 
   collect_data(:windows) do
-    require "win32/registry"
     fips Mash.new
 
-    # from http://msdn.microsoft.com/en-us/library/windows/desktop/aa384129(v=vs.85).aspx
-    if ::RbConfig::CONFIG["target_cpu"] == "i386"
-      reg_type = Win32::Registry::KEY_READ | 0x100
-    elsif ::RbConfig::CONFIG["target_cpu"] == "x86_64"
-      reg_type = Win32::Registry::KEY_READ | 0x200
+    require "openssl" unless defined?(OpenSSL)
+    if defined?(OpenSSL.fips_mode) && OpenSSL.fips_mode && !$FIPS_TEST_MODE
+      fips["kernel"] = { "enabled" => true }
     else
-      reg_type = Win32::Registry::KEY_READ
-    end
-
-    begin
-      Win32::Registry::HKEY_LOCAL_MACHINE.open('System\CurrentControlSet\Control\Lsa\FIPSAlgorithmPolicy', reg_type) do |policy|
-        enabled = policy["Enabled"]
-        fips["kernel"] = { "enabled" => enabled == 0 ? false : true }
-      end
-    rescue Win32::Registry::Error
       fips["kernel"] = { "enabled" => false }
     end
   end
