@@ -1,6 +1,6 @@
 #
 # Author:: Claire McQuin (<claire@chef.io>)
-# Copyright:: Copyright (c) 2013-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2013-2019, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you
@@ -17,57 +17,63 @@
 # limitations under the License
 #
 
-require "ohai/dsl"
+require_relative "dsl"
 require "benchmark"
 
 module Ohai
   class Runner
 
-    attr_reader :failed_plugins
+    attr_reader :failed_plugins, :logger
     # safe_run: set to true if this runner will run plugins in
     # safe-mode. default false.
     def initialize(controller, safe_run = false)
       @provides_map = controller.provides_map
       @safe_run = safe_run
       @failed_plugins = []
+      @logger = controller.logger.with_child
+      @logger.metadata = { subsystem: "runner" }
     end
 
     # Runs plugins and any un-run dependencies.
     # If force is set to true, then this plugin and its dependencies
     # will be run even if they have been run before.
+    #
+    # @param [Ohai::DSL::Plugin] plugin
+    #
+    # @return void
+    #
     def run_plugin(plugin)
-      elapsed = Benchmark.measure do
-        unless plugin.kind_of?(Ohai::DSL::Plugin)
+      elapsed = Benchmark.realtime do
+        unless plugin.is_a?(Ohai::DSL::Plugin)
           raise Ohai::Exceptions::InvalidPlugin, "Invalid plugin #{plugin} (must be an Ohai::DSL::Plugin or subclass)"
         end
 
         begin
-          case plugin.version
-          when :version7
+          if plugin.version == :version7
             run_v7_plugin(plugin)
-          when :version6
-            run_v6_plugin(plugin)
           else
             raise Ohai::Exceptions::InvalidPlugin, "Invalid plugin version #{plugin.version} for plugin #{plugin}"
           end
-        rescue Ohai::Exceptions::Error
+        rescue Ohai::Exceptions::Error # rubocop: disable Lint/ShadowedException
           raise
         rescue SystemExit # abort or exit from plug-in should exit Ohai with failure code
           raise
-        rescue Exception, Errno::ENOENT => e
-          Ohai::Log.debug("Plugin #{plugin.name} threw exception #{e.inspect} #{e.backtrace.join("\n")}")
+        rescue Exception => e
+          logger.trace("Plugin #{plugin.name} threw exception #{e.inspect} #{e.backtrace.join("\n")}")
         end
       end
-      Ohai::Log.debug("Plugin #{plugin.name} took #{elapsed.total} seconds to run.")
-    end
-
-    def run_v6_plugin(plugin)
-      return true if plugin.has_run?
-
-      @safe_run ? plugin.safe_run : plugin.run
+      logger.trace("Plugin #{plugin.name} took #{elapsed} seconds to run.")
     end
 
+    # @param [Ohai::DSL::Plugin] plugin
+    #
+    # @return void
+    #
     def run_v7_plugin(plugin)
+      return true if plugin.optional? &&
+        !Ohai.config[:run_all_plugins] &&
+        !Ohai.config[:optional_plugins].include?(plugin.name)
+
       visited = [ plugin ]
       until visited.empty?
         next_plugin = visited.pop
@@ -97,6 +103,10 @@ module Ohai
       end
     end
 
+    # @param [Array] attributes
+    #
+    # @return [Array]
+    #
     def fetch_plugins(attributes)
       @provides_map.find_closest_providers_for(attributes)
     end
