@@ -1,6 +1,6 @@
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright (c) 2008-2017, Chef Software Inc.
+# Copyright:: Copyright (c) 2008-2019, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,31 +16,34 @@
 # limitations under the License.
 #
 
-require "ohai/loader"
-require "ohai/log"
-require "ohai/mash"
-require "ohai/runner"
-require "ohai/dsl"
-require "ohai/mixin/command"
-require "ohai/mixin/os"
-require "ohai/mixin/string"
-require "ohai/mixin/constant_helper"
-require "ohai/provides_map"
-require "ohai/hints"
-require "mixlib/shellout"
-require "ohai/config"
+require_relative "version"
+require_relative "loader"
+require_relative "log"
+require_relative "mash"
+require_relative "runner"
+require_relative "dsl"
+require_relative "mixin/command"
+require_relative "mixin/os"
+require_relative "mixin/string"
+require_relative "mixin/constant_helper"
+require_relative "provides_map"
+require_relative "hints"
+require "mixlib/shellout" unless defined?(Mixlib::ShellOut::DEFAULT_READ_TIMEOUT)
+require_relative "config"
+require "ffi_yajl" unless defined?(FFI_Yajl)
 
 module Ohai
+  # The class used by Ohai::Application and Chef to actually collect data
   class System
     include Ohai::Mixin::ConstantHelper
 
     attr_accessor :data
     attr_reader :config
     attr_reader :provides_map
-    attr_reader :v6_dependency_solver
+    attr_reader :logger
 
     # the cli flag is used to determine if we're being constructed by
-    # something like chef-client (which doesn't not set this flag) and
+    # something like chef-client (which doesn't set this flag) and
     # which sets up its own loggers, or if we're coming from Ohai::Application
     # and therefore need to configure Ohai's own logger.
     def initialize(config = {})
@@ -48,13 +51,18 @@ module Ohai
       @plugin_path = ""
       @config = config
       @failed_plugins = []
+      @logger = config[:logger] || Ohai::Log.with_child
+      @logger.metadata = { system: "ohai", version: Ohai::VERSION }
       reset_system
     end
 
+    # clears the current collected data, clears the provides map for plugins,
+    # refreshes hints, and reconfigures ohai. In short this gets Ohai into a first run state
+    #
+    # @return [void]
     def reset_system
       @data = Mash.new
       @provides_map = ProvidesMap.new
-      @v6_dependency_solver = Hash.new
 
       configure_ohai
       configure_logging if @cli
@@ -72,6 +80,12 @@ module Ohai
       @data[key]
     end
 
+    # Resets the system and loads then runs the plugins. This is the primary method called
+    # to run the system.
+    #
+    # @param [Array<String>] attribute_filter the attributes to run. All will be run if not specified
+    #
+    # @return [void]
     def all_plugins(attribute_filter = nil)
       # Reset the system when all_plugins is called since this function
       # can be run multiple times in order to pick up any changes in the
@@ -82,37 +96,33 @@ module Ohai
       run_plugins(true, attribute_filter)
     end
 
+    # load all plugins by calling Ohai::Loader.load_all
+    #
+    # @see Ohai::Loader.load_all
     def load_plugins
       @loader.load_all
     end
 
+    # run all plugins or those that match the attribute filter is provided
+    #
+    # @param safe [Boolean]
+    # @param [Array<String>] attribute_filter the attributes to run. All will be run if not specified
+    #
+    # @return [Mash]
     def run_plugins(safe = false, attribute_filter = nil)
-      # First run all the version 6 plugins
-      @v6_dependency_solver.values.each do |v6plugin|
-        @runner.run_plugin(v6plugin)
-      end
-
-      # Users who are migrating from ohai 6 may give one or more Ohai 6 plugin
-      # names as the +attribute_filter+. In this case we return early because
-      # the v7 plugin provides map will not have an entry for this plugin.
-      if attribute_filter && Array(attribute_filter).all? { |filter_item| have_v6_plugin?(filter_item) }
-        return true
-      end
-
-      # Then run all the version 7 plugins
       begin
         @provides_map.all_plugins(attribute_filter).each do |plugin|
           @runner.run_plugin(plugin)
         end
       rescue Ohai::Exceptions::AttributeNotFound, Ohai::Exceptions::DependencyCycle => e
-        Ohai::Log.error("Encountered error while running plugins: #{e.inspect}")
+        logger.error("Encountered error while running plugins: #{e.inspect}")
         raise
       end
       critical_failed = Ohai::Config.ohai[:critical_plugins] & @runner.failed_plugins
       unless critical_failed.empty?
         msg = "The following Ohai plugins marked as critical failed: #{critical_failed}"
         if @cli
-          Ohai::Log.error(msg)
+          logger.error(msg)
           exit(true)
         else
           raise Ohai::Exceptions::CriticalPluginFailure, "#{msg}. Failing Chef run."
@@ -123,83 +133,19 @@ module Ohai
       freeze_strings!
     end
 
+    # @param [String] plugin_path
+    #
+    # @return [void]
+    #
     def run_additional_plugins(plugin_path)
       @loader.load_additional(plugin_path).each do |plugin|
-        Ohai::Log.debug "Running plugin #{plugin}"
+        logger.trace "Running plugin #{plugin}"
         @runner.run_plugin(plugin)
       end
 
       freeze_strings!
     end
 
-    def have_v6_plugin?(name)
-      @v6_dependency_solver.values.any? { |v6plugin| v6plugin.name == name }
-    end
-
-    def pathify_v6_plugin(plugin_name)
-      path_components = plugin_name.split("::")
-      File.join(path_components) + ".rb"
-    end
-
-    #
-    # Below APIs are from V6.
-    # Make sure that you are not breaking backwards compatibility
-    # if you are changing any of the APIs below.
-    #
-    def require_plugin(plugin_ref, force = false)
-      plugins = [ ]
-      # This method is only callable by version 6 plugins.
-      # First we check if there exists a v6 plugin that fulfills the dependency.
-      if @v6_dependency_solver.has_key? pathify_v6_plugin(plugin_ref)
-        # Note that: partial_path looks like Plugin::Name
-        # keys for @v6_dependency_solver are in form 'plugin/name.rb'
-        plugins << @v6_dependency_solver[pathify_v6_plugin(plugin_ref)]
-      else
-        # While looking up V7 plugins we need to convert the plugin_ref to an attribute.
-        attribute = plugin_ref.gsub("::", "/")
-        begin
-          plugins = @provides_map.find_providers_for([attribute])
-        rescue Ohai::Exceptions::AttributeNotFound
-          Ohai::Log.debug("Can not find any v7 plugin that provides #{attribute}")
-          plugins = [ ]
-        end
-      end
-
-      if plugins.empty?
-        raise Ohai::Exceptions::DependencyNotFound, "Can not find a plugin for dependency #{plugin_ref}"
-      else
-        plugins.each do |plugin|
-          begin
-            @runner.run_plugin(plugin)
-          rescue SystemExit, Interrupt
-            raise
-          rescue Ohai::Exceptions::DependencyCycle, Ohai::Exceptions::AttributeNotFound => e
-            Ohai::Log.error("Encountered error while running plugins: #{e.inspect}")
-            raise
-          rescue Exception, Errno::ENOENT => e
-            Ohai::Log.debug("Plugin #{plugin.name} threw exception #{e.inspect} #{e.backtrace.join("\n")}")
-          end
-        end
-      end
-    end
-
-    # Re-runs plugins that provide the attributes specified by
-    # +attribute_filter+. If +attribute_filter+ is not given, re-runs all
-    # plugins.
-    #
-    # Note that dependencies will not be re-run, so you must specify all of the
-    # attributes you want refreshed in the +attribute_filter+
-    #
-    # This method takes a naive approach to v6 plugins: it simply re-runs all
-    # of them whenever called.
-    def refresh_plugins(attribute_filter = nil)
-      Ohai::Hints.refresh_hints
-      @provides_map.all_plugins(attribute_filter).each do |plugin|
-        plugin.reset!
-      end
-      run_plugins(true, attribute_filter)
-    end
-
     #
     # Serialize this object as a hash
     #
@@ -220,6 +166,7 @@ module Ohai
         data = data[part]
       end
       raise ArgumentError, "I cannot find an attribute named #{a}!" if data.nil?
+
       case data
       when Hash, Mash, Array, Integer
         json_pretty_print(data)
@@ -239,12 +186,17 @@ module Ohai
     def configure_ohai
       Ohai.config.merge!(@config)
 
-      if Ohai.config[:directory] &&
-          !Ohai.config[:plugin_path].include?(Ohai.config[:directory])
-        Ohai.config[:plugin_path] << Ohai.config[:directory]
+      # add any additional CLI passed directories to the plugin path excluding duplicates
+      unless Ohai.config[:directory].nil?
+        # make sure the directory config is an array since it could be a string set in client.rb
+        Array(Ohai.config[:directory]).each do |dir|
+          next if Ohai.config[:plugin_path].include?(dir)
+
+          Ohai.config[:plugin_path] << dir
+        end
       end
 
-      Ohai::Log.debug("Running Ohai with the following configuration: #{Ohai.config.configuration}")
+      logger.debug("Running Ohai with the following configuration: #{Ohai.config.configuration}")
     end
 
     def configure_logging
