@@ -15,7 +15,7 @@
 # limitations under the License.
 #
 
-require_relative "../spec_helper"
+require "spec_helper"
 
 RSpec.describe "Ohai::Loader" do
   let(:loader) { Ohai::Loader.new(Ohai::System.new) }
@@ -25,27 +25,27 @@ RSpec.describe "Ohai::Loader" do
       let(:plugin_directory) { Dir.mktmpdir("plugins") }
       let(:plugin_path) { plugin_directory.tr("/", "\\") }
 
-      before(:each) do
+      before do
         Ohai.config[:plugin_path] = plugin_path
 
-        plugin_content = <<-EOF
-Ohai.plugin(:Foo) do
-  provides 'foo'
-end
-EOF
+        plugin_content = <<~EOF
+          Ohai.plugin(:Foo) do
+            provides 'foo'
+          end
+        EOF
         File.open(File.join(plugin_directory, "foo.rb"), "w+") do |f|
           f.write(plugin_content)
         end
       end
 
-      after(:each) do
+      after do
         FileUtils.rm_rf(plugin_directory)
       end
 
       it "loads all the plugins" do
         loader.load_all
         loaded_plugins = loader.instance_variable_get(:@v7_plugin_classes)
-        loaded_plugins_names = loaded_plugins.map { |plugin| plugin.name }
+        loaded_plugins_names = loaded_plugins.map(&:name)
         expect(loaded_plugins_names).to eq(["Ohai::NamedPlugin::Foo"])
       end
     end
