@@ -18,15 +18,15 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "root_group plugin" do
   let(:plugin) { get_plugin("root_group") }
 
   describe "windows platform", :windows_only do
-    let (:wmi) { wmi = WmiLite::Wmi.new }
+    let(:wmi) { WmiLite::Wmi.new }
 
-    it 'should return the system\'s administrators (root) group' do
+    it "returns the system's administrators (root) group" do
       # Notethat the Win32_Group WMI provider can be slow if your
       # system is domain-joined and has hundreds of thousands of
       # groups in Active Directory -- not a typical test scenario, but
