@@ -16,11 +16,11 @@
 # limitations under the License.
 #
 
-require_relative "spec_helper.rb"
+require "spec_helper"
 
 describe Ohai do
 
-  it "should have a version constant defined" do
+  it "has a version constant defined" do
     expect(Ohai::VERSION).to be_a_kind_of(String)
   end
 
