@@ -17,10 +17,10 @@
 # limitations under the License
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 shared_examples "Ohai::DSL::Plugin" do
-  context "#initialize" do
+  describe "#initialize" do
     it "sets has_run? to false" do
       expect(plugin.has_run?).to be false
     end
@@ -30,7 +30,7 @@ shared_examples "Ohai::DSL::Plugin" do
     end
   end
 
-  context "#run" do
+  describe "#run" do
     before do
       allow(plugin).to receive(:run_plugin).and_return(true)
       allow(plugin).to receive(:name).and_return(:TestPlugin)
@@ -62,8 +62,8 @@ shared_examples "Ohai::DSL::Plugin" do
         plugin.run
       end
 
-      it "logs a message to debug" do
-        expect(Ohai::Log).to receive(:debug).with(/Skipping disabled plugin TestPlugin/)
+      it "logs a message to trace" do
+        expect(plugin.logger).to receive(:trace).with(/Skipping disabled plugin TestPlugin/)
         plugin.run
       end
 
@@ -155,7 +155,7 @@ shared_examples "Ohai::DSL::Plugin" do
   end
 
   context "when getting attributes" do
-    before(:each) do
+    before do
       plugin.set_attribute(:tea, "is soothing")
     end
 
@@ -170,7 +170,7 @@ shared_examples "Ohai::DSL::Plugin" do
     end
 
     describe "a top-level attribute" do
-      before(:each) do
+      before do
         plugin.set_attribute(:tea, "is soothing")
       end
 
@@ -196,15 +196,15 @@ shared_examples "Ohai::DSL::Plugin" do
     end
 
     describe "a nested attribute" do
-      before(:each) do
+      before do
         plugin.set_attribute(:the_monarch, { arch_rival: "dr_venture" })
       end
 
       describe "as a list" do
         describe "of strings" do
           it "returns true when the attribute exists" do
-            expect(plugin.get_attribute("the_monarch", "arch_rival")).
-              to eql("dr_venture")
+            expect(plugin.get_attribute("the_monarch", "arch_rival"))
+              .to eql("dr_venture")
           end
 
           describe "when the attribute does not exist" do
@@ -220,7 +220,7 @@ shared_examples "Ohai::DSL::Plugin" do
               it "returns nil" do
                 expect(
                   plugin.get_attribute("the_monarch", "henchmen",
-                                       "corky_knightrider")
+                    "corky_knightrider")
                 ).to be nil
               end
             end
@@ -229,9 +229,9 @@ shared_examples "Ohai::DSL::Plugin" do
               it "raises a TypeError" do
                 expect do
                   plugin.get_attribute("the_monarch", "arch_rival",
-                                       "dr_venture", "since")
+                    "dr_venture", "since")
                 end.to raise_error(TypeError,
-                                 "Expected Hash but got String.")
+                  "Expected Hash but got String.")
               end
             end
           end
@@ -239,8 +239,8 @@ shared_examples "Ohai::DSL::Plugin" do
 
         describe "of symbols" do
           it "returns true when the attribute exists" do
-            expect(plugin.get_attribute(:the_monarch, :arch_rival)).
-              to eql("dr_venture")
+            expect(plugin.get_attribute(:the_monarch, :arch_rival))
+              .to eql("dr_venture")
           end
 
           describe "when the attribute does not exist" do
@@ -254,7 +254,7 @@ shared_examples "Ohai::DSL::Plugin" do
               it "returns nil" do
                 expect(
                   plugin.get_attribute(:the_monarch, :henchmen,
-                                       :corky_knightrider)
+                    :corky_knightrider)
                 ).to be nil
               end
             end
@@ -263,9 +263,9 @@ shared_examples "Ohai::DSL::Plugin" do
               it "raises a TypeError" do
                 expect do
                   plugin.get_attribute(:the_monarch, :arch_rival,
-                                       :dr_venture, :since)
+                    :dr_venture, :since)
                 end.to raise_error(TypeError,
-                                 "Expected Hash but got String.")
+                  "Expected Hash but got String.")
               end
             end
           end
@@ -282,12 +282,12 @@ shared_examples "Ohai::DSL::Plugin" do
     describe "a top-level attribute" do
       describe "as a string" do
         it "returns false when the attribute does not exist" do
-          expect(plugin.attribute?("alice in chains")).to eql(false)
+          expect(plugin.attribute?("alice in chains")).to be(false)
         end
 
         it "returns true if an attribute exists with the given name" do
           plugin.metallica("death magnetic")
-          expect(plugin.attribute?("metallica")).to eql(true)
+          expect(plugin.attribute?("metallica")).to be(true)
         end
       end
 
@@ -304,7 +304,7 @@ shared_examples "Ohai::DSL::Plugin" do
     end
 
     describe "a nested attribute" do
-      before(:each) do
+      before do
         plugin.set_attribute(:the_monarch, { arch_rival: "dr_venture" })
       end
 
@@ -327,7 +327,7 @@ shared_examples "Ohai::DSL::Plugin" do
               it "returns false" do
                 expect(
                   plugin.attribute?("the_monarch", "henchmen",
-                                    "corky_knightrider")
+                    "corky_knightrider")
                 ).to be false
               end
             end
@@ -336,9 +336,9 @@ shared_examples "Ohai::DSL::Plugin" do
               it "raises a TypeError" do
                 expect do
                   plugin.attribute?("the_monarch", "arch_rival",
-                                    "dr_venture", "since")
+                    "dr_venture", "since")
                 end.to raise_error(TypeError,
-                                 "Expected Hash but got String.")
+                  "Expected Hash but got String.")
               end
             end
           end
@@ -360,7 +360,7 @@ shared_examples "Ohai::DSL::Plugin" do
               it "returns false" do
                 expect(
                   plugin.attribute?(:the_monarch, :henchmen,
-                                    :corky_knightrider)
+                    :corky_knightrider)
                 ).to be false
               end
             end
@@ -369,9 +369,9 @@ shared_examples "Ohai::DSL::Plugin" do
               it "raises a TypeError" do
                 expect do
                   plugin.attribute?(:the_monarch, :arch_rival,
-                                    :dr_venture, :since)
+                    :dr_venture, :since)
                 end.to raise_error(TypeError,
-                                 "Expected Hash but got String.")
+                  "Expected Hash but got String.")
               end
             end
           end
@@ -382,9 +382,11 @@ shared_examples "Ohai::DSL::Plugin" do
 end
 
 describe Ohai::DSL::Plugin::VersionVII do
+  let(:logger) { Ohai::Log }
+
   it "does not modify the plugin name when the plugin is named correctly" do
-    plugin = Ohai.plugin(:FunkyVALIDpluginName) {}.new({})
-    expect(plugin.name).to eql(:FunkyVALIDpluginName)
+    plugin = Ohai.plugin(:FunkyVALIDpluginName) {}.new({}, logger)
+    expect(plugin.name).to be(:FunkyVALIDpluginName)
   end
 
   describe "when the plugin is named incorrectly" do
@@ -410,7 +412,7 @@ describe Ohai::DSL::Plugin::VersionVII do
   describe "#version" do
     it "saves the plugin version as :version7" do
       plugin = Ohai.plugin(:Test) {}
-      expect(plugin.version).to eql(:version7)
+      expect(plugin.version).to be(:version7)
     end
   end
 
@@ -435,13 +437,13 @@ describe Ohai::DSL::Plugin::VersionVII do
     end
 
     it "collects attributes across multiple plugin files" do
-      plugin = Ohai.plugin(:Test) { provides("one") }
+      plugin = Ohai.plugin(:Test) { provides("one") } # rubocop: disable Lint/UselessAssignment
       plugin = Ohai.plugin(:Test) { provides("two", "three") }
       expect(plugin.provides_attrs).to eql(%w{one two three})
     end
 
     it "collects unique attributes" do
-      plugin = Ohai.plugin(:Test) { provides("one") }
+      plugin = Ohai.plugin(:Test) { provides("one") } # rubocop: disable Lint/UselessAssignment
       plugin = Ohai.plugin(:Test) { provides("one", "two") }
       expect(plugin.provides_attrs).to eql(%w{one two})
     end
@@ -468,13 +470,13 @@ describe Ohai::DSL::Plugin::VersionVII do
     end
 
     it "collects dependencies across multiple plugin files" do
-      plugin = Ohai.plugin(:Test) { depends("one") }
+      plugin = Ohai.plugin(:Test) { depends("one") } # rubocop: disable Lint/UselessAssignment
       plugin = Ohai.plugin(:Test) { depends("two", "three") }
       expect(plugin.depends_attrs).to eql(%w{one two three})
     end
 
     it "collects unique attributes" do
-      plugin = Ohai.plugin(:Test) { depends("one") }
+      plugin = Ohai.plugin(:Test) { depends("one") } # rubocop: disable Lint/UselessAssignment
       plugin = Ohai.plugin(:Test) { depends("one", "two") }
       expect(plugin.depends_attrs).to eql(%w{one two})
     end
@@ -493,7 +495,7 @@ describe Ohai::DSL::Plugin::VersionVII do
 
     it "saves a list of platforms" do
       plugin = Ohai.plugin(:Test) { collect_data(:freebsd, :netbsd, :openbsd) {} }
-      [:freebsd, :netbsd, :openbsd].each do |platform|
+      %i{freebsd netbsd openbsd}.each do |platform|
         expect(plugin.data_collector).to have_key(platform)
       end
     end
@@ -504,7 +506,7 @@ describe Ohai::DSL::Plugin::VersionVII do
         collect_data(:windows) {}
         collect_data(:darwin) {}
       end
-      [:darwin, :default, :windows].each do |platform|
+      %i{darwin default windows}.each do |platform|
         expect(plugin.data_collector).to have_key(platform)
       end
     end
@@ -512,42 +514,41 @@ describe Ohai::DSL::Plugin::VersionVII do
     it "saves platforms across multiple plugins" do
       plugin = Ohai.plugin(:Test) { collect_data {} }
       plugin = Ohai.plugin(:Test) { collect_data(:aix, :sigar) {} }
-      [:aix, :default, :sigar].each do |platform|
+      %i{aix default sigar}.each do |platform|
         expect(plugin.data_collector).to have_key(platform)
       end
     end
 
     it "fails a platform has already been defined in the same plugin" do
-      expect do
-        Ohai.plugin(:Test) do
-          collect_data {}
-          collect_data {}
-        end
-      end.to raise_error(Ohai::Exceptions::IllegalPluginDefinition, /collect_data already defined/)
+      Ohai.plugin(:Test) { collect_data {} }
+      expect(Ohai::Log).to receive(:warn).with(/collect_data already defined on platform/).twice
+      Ohai.plugin(:Test) do
+        collect_data {}
+        collect_data {}
+      end
     end
 
     it "fails if a platform has already been defined in another plugin file" do
       Ohai.plugin(:Test) { collect_data {} }
-      expect do
-        Ohai.plugin(:Test) do
-          collect_data {}
-        end
-      end.to raise_error(Ohai::Exceptions::IllegalPluginDefinition, /collect_data already defined/)
+      expect(Ohai::Log).to receive(:warn).with(/collect_data already defined on platform/)
+      Ohai.plugin(:Test) do
+        collect_data {}
+      end
     end
   end
 
   describe "#provides (deprecated)" do
     it "logs a warning" do
-      plugin = Ohai::DSL::Plugin::VersionVII.new(Mash.new)
-      expect(Ohai::Log).to receive(:warn).with(/\[UNSUPPORTED OPERATION\]/)
+      plugin = Ohai.plugin(:Test).new(Mash.new, logger)
+      expect_any_instance_of(Mixlib::Log::Child).to receive(:warn).with(/\[UNSUPPORTED OPERATION\]/)
       plugin.provides("attribute")
     end
   end
 
   describe "#require_plugin (deprecated)" do
     it "logs a warning" do
-      plugin = Ohai::DSL::Plugin::VersionVII.new(Mash.new)
-      expect(Ohai::Log).to receive(:warn).with(/\[UNSUPPORTED OPERATION\]/)
+      plugin = Ohai.plugin(:Test).new(Mash.new, logger)
+      expect_any_instance_of(Mixlib::Log::Child).to receive(:warn).with(/\[UNSUPPORTED OPERATION\]/)
       plugin.require_plugin("plugin")
     end
   end
@@ -555,7 +556,7 @@ describe Ohai::DSL::Plugin::VersionVII do
   describe "#configuration" do
     let(:plugin) do
       klass = Ohai.plugin(camel_name) {}
-      klass.new({})
+      klass.new({}, logger)
     end
 
     shared_examples_for "plugin config lookup" do
@@ -575,7 +576,7 @@ describe Ohai::DSL::Plugin::VersionVII do
 
       it "does not auto-vivify an un-configured plugin" do
         plugin.configuration(:foo)
-        expect(Ohai.config[:plugin]).to_not have_key(:test)
+        expect(Ohai.config[:plugin]).not_to have_key(:test)
       end
 
       it "returns nil when the option is not configured" do
@@ -591,7 +592,7 @@ describe Ohai::DSL::Plugin::VersionVII do
       include_examples "plugin config lookup"
 
       it "returns the configuration sub-option value" do
-        Ohai.config[:plugin][snake_name][:foo] = { :bar => true }
+        Ohai.config[:plugin][snake_name][:foo] = { bar: true }
         expect(plugin.configuration(:foo, :bar)).to eq(true)
       end
     end
@@ -627,40 +628,7 @@ describe Ohai::DSL::Plugin::VersionVII do
 
   it_behaves_like "Ohai::DSL::Plugin" do
     let(:ohai) { Ohai::System.new }
-    let(:plugin) { Ohai::DSL::Plugin::VersionVII.new(ohai.data) }
+    let(:plugin) { Ohai.plugin(:Test).new(ohai.data, ohai.logger) }
     let(:version) { :version7 }
   end
 end
-
-describe Ohai::DSL::Plugin::VersionVI do
-  describe "#version" do
-    it "saves the plugin version as :version6" do
-      plugin = Class.new(Ohai::DSL::Plugin::VersionVI) {}
-      expect(plugin.version).to eql(:version6)
-    end
-  end
-
-  describe "#provides" do
-    let(:ohai) { Ohai::System.new }
-
-    it "logs a debug message when provides is used" do
-      allow(Ohai::Log).to receive(:debug)
-      expect(Ohai::Log).to receive(:debug).with(/Skipping provides/)
-      plugin = Ohai::DSL::Plugin::VersionVI.new(ohai, "/some/plugin/path.rb", "/some/plugin")
-      plugin.provides("attribute")
-    end
-
-    it "does not update the provides map for version 6 plugins." do
-      plugin = Ohai::DSL::Plugin::VersionVI.new(ohai, "/some/plugin/path.rb", "/some/plugin")
-      plugin.provides("attribute")
-      expect(ohai.provides_map.map).to be_empty
-    end
-
-  end
-
-  it_behaves_like "Ohai::DSL::Plugin" do
-    let(:ohai) { Ohai::System.new }
-    let(:plugin) { Ohai::DSL::Plugin::VersionVI.new(ohai, "/some/plugin/path.rb", "/some/plugin") }
-    let(:version) { :version6 }
-  end
-end
