@@ -17,7 +17,7 @@
 # limitations under the License.
 #
 
-require_relative "../spec_helper.rb"
+require "spec_helper"
 
 describe "Ohai::Hints" do
   # We are using the plugins directory infrastructure to test hints
@@ -42,9 +42,9 @@ describe "Ohai::Hints" do
   end
 
   when_plugins_directory "contains empty and full hints" do
-    with_plugin("cloud.json", <<EOF)
-{"name":"circus"}
-EOF
+    with_plugin("cloud.json", <<~EOF)
+      {"name":"circus"}
+    EOF
 
     with_plugin("cloud_empty.json", <<EOF)
 EOF
