@@ -17,96 +17,34 @@
 # limitations under the License.
 #
 
-require_relative "../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::Loader do
   extend IntegrationSupport
 
-  let(:loader) { Ohai::Loader.new(ohai) }
-  let(:ohai) { double("Ohai::System", :data => Mash.new, :provides_map => provides_map) }
+  let(:loader) { described_class.new(ohai) }
+  let(:ohai) { double("Ohai::System", data: Mash.new, provides_map: provides_map, logger: Ohai::Log) }
   let(:provides_map) { Ohai::ProvidesMap.new }
 
   describe "#initialize" do
     it "returns an Ohai::Loader object" do
-      loader = Ohai::Loader.new(ohai)
-      expect(loader).to be_a_kind_of(Ohai::Loader)
-    end
-  end
-
-  when_plugins_directory "contains both V6 & V7 plugins" do
-    with_plugin("zoo.rb", <<EOF)
-Ohai.plugin(:Zoo) do
-  provides 'seals'
-end
-EOF
-
-    with_plugin("zoo_too.rb", <<EOF)
-Ohai.plugin(:Zoo) do
-  provides 'elephants'
-end
-EOF
-
-    with_plugin("lake.rb", <<EOF)
-provides 'fish'
-EOF
-
-    describe "load_plugin() method" do
-      describe "when loading a v7 plugin" do
-        let(:plugin) { loader.load_plugin(path_to("zoo.rb")) }
-
-        it "saves the plugin according to its attribute" do
-          plugin
-          expect(provides_map.map.keys).to include("seals")
-        end
-
-        it "saves a single plugin source" do
-          expect(plugin.source).to eql([path_to("zoo.rb")])
-        end
-
-        it "saves all plugin sources" do
-          plugin
-          loader.load_plugin(path_to("zoo_too.rb"))
-          expect(plugin.source).to eql([path_to("zoo.rb"), path_to("zoo_too.rb")])
-        end
-      end
-
-      describe "when loading a v6 plugin" do
-        let(:plugin) { loader.load_plugin(path_to("lake.rb"), path_to(".")) }
-
-        before(:each) do
-          expect(Ohai::Log).to receive(:warn).with(/\[DEPRECATION\]/)
-        end
-
-        it "does not add this plugin's provided attributes to the provides map" do
-          plugin
-          expect(provides_map.map).to be_empty
-        end
-
-        it "saves the plugin's source" do
-          expect(plugin.source).to eql(path_to("lake.rb"))
-        end
-      end
-
-      it "logs a warning if a plugin doesn't exist" do
-        expect(Ohai::Log).to receive(:warn).with(/Unable to open or read plugin/)
-        loader.load_plugin(path_to("rainier.rb"), path_to("."))
-        expect(provides_map.map).to be_empty
-      end
+      loader = described_class.new(ohai)
+      expect(loader).to be_a_kind_of(described_class)
     end
   end
 
   when_plugins_directory "is an additional plugin path" do
-    with_plugin("cookbook_a/alpha.rb", <<EOF)
-Ohai.plugin(:Alpha) do
-  provides "alpha"
-end
-EOF
+    with_plugin("cookbook_a/alpha.rb", <<~EOF)
+      Ohai.plugin(:Alpha) do
+        provides "alpha"
+      end
+    EOF
 
-    with_plugin("cookbook_b/beta.rb", <<EOF)
-Ohai.plugin(:Beta) do
-  provides "beta"
-end
-EOF
+    with_plugin("cookbook_b/beta.rb", <<~EOF)
+      Ohai.plugin(:Beta) do
+        provides "beta"
+      end
+    EOF
 
     describe "#load_additional" do
       it "adds the plugins to the map" do
@@ -121,56 +59,56 @@ EOF
   end
 
   when_plugins_directory "contains invalid plugins" do
-    with_plugin("extra_s.rb", <<EOF)
-Ohai.plugins(:ExtraS) do
-  provides "the_letter_s"
-end
-EOF
+    with_plugin("extra_s.rb", <<~EOF)
+      Ohai.plugins(:ExtraS) do
+        provides "the_letter_s"
+      end
+    EOF
 
-    with_plugin("no_method.rb", <<EOF)
-Ohai.plugin(:NoMethod) do
-  really_wants "this_attribute"
-end
-EOF
+    with_plugin("no_method.rb", <<~EOF)
+      Ohai.plugin(:NoMethod) do
+        really_wants "this_attribute"
+      end
+    EOF
 
-    with_plugin("illegal_def.rb", <<EOF)
-Ohai.plugin(:Zoo) do
-  collect_data(:darwin) do
-  end
-  collect_data(:darwin) do
-  end
-end
-EOF
+    with_plugin("illegal_def.rb", <<~EOF)
+      Ohai.plugin(:Zoo) do
+        collect_data(:darwin) do
+        end
+        collect_data(:darwin) do
+        end
+      end
+    EOF
 
-    with_plugin("unexpected_error.rb", <<EOF)
-Ohai.plugin(:Zoo) do
-  raise "You aren't expecting this."
-end
-EOF
+    with_plugin("unexpected_error.rb", <<~EOF)
+      Ohai.plugin(:Zoo) do
+        raise "You aren't expecting this."
+      end
+    EOF
 
-    with_plugin("bad_symbol.rb", <<EOF)
-Ohai.plugin(:1nval!d) do
-  provides "not_a_symbol"
-end
-EOF
+    with_plugin("bad_symbol.rb", <<~EOF)
+      Ohai.plugin(:1nval!d) do
+        provides "not_a_symbol"
+      end
+    EOF
 
-    with_plugin("no_end.rb", <<EOF)
-Ohai.plugin(:NoEnd) do
-  provides "fish_oil"
-  collect_data do
-end
-EOF
+    with_plugin("no_end.rb", <<~EOF)
+      Ohai.plugin(:NoEnd) do
+        provides "fish_oil"
+        collect_data do
+      end
+    EOF
 
-    with_plugin("bad_name.rb", <<EOF)
-Ohai.plugin(:you_give_plugins_a_bad_name) do
-  provides "that/one/song"
-end
-EOF
+    with_plugin("bad_name.rb", <<~EOF)
+      Ohai.plugin(:you_give_plugins_a_bad_name) do
+        provides "that/one/song"
+      end
+    EOF
 
     describe "load_plugin() method" do
       describe "when the plugin uses Ohai.plugin instead of Ohai.plugins" do
         it "logs an unsupported operation warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Method Error: <#{path_to("extra_s.rb")}>:/)
+          expect(loader.logger).to receive(:warn).with(/Plugin Method Error: <#{path_to("extra_s.rb")}>:/)
           loader.load_plugin(path_to("extra_s.rb"))
         end
 
@@ -181,7 +119,7 @@ EOF
 
       describe "when the plugin tries to call an unexisting method" do
         it "shoud log an unsupported operation warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Method Error: <#{path_to("no_method.rb")}>:/)
+          expect(loader.logger).to receive(:warn).with(/Plugin Method Error: <#{path_to("no_method.rb")}>:/)
           loader.load_plugin(path_to("no_method.rb"))
         end
 
@@ -192,7 +130,7 @@ EOF
 
       describe "when the plugin defines collect_data on the same platform more than once" do
         it "shoud log an illegal plugin definition warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Definition Error: <#{path_to("illegal_def.rb")}>:/)
+          expect(Ohai::Log).to receive(:warn).with(/collect_data already defined on platform/)
           loader.load_plugin(path_to("illegal_def.rb"))
         end
 
@@ -203,7 +141,7 @@ EOF
 
       describe "when an unexpected error is encountered" do
         it "logs a warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Error: <#{path_to("unexpected_error.rb")}>:/)
+          expect(loader.logger).to receive(:warn).with(/Plugin Error: <#{path_to("unexpected_error.rb")}>:/)
           loader.load_plugin(path_to("unexpected_error.rb"))
         end
 
@@ -214,7 +152,7 @@ EOF
 
       describe "when the plugin name symbol has bad syntax" do
         it "logs a syntax error warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Syntax Error: <#{path_to("bad_symbol.rb")}>:/)
+          expect(loader.logger).to receive(:warn).with(/Plugin Syntax Error: <#{path_to("bad_symbol.rb")}>:/)
           loader.load_plugin(path_to("bad_symbol.rb"))
         end
 
@@ -225,7 +163,7 @@ EOF
 
       describe "when the plugin forgets an 'end'" do
         it "logs a syntax error warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Syntax Error: <#{path_to("no_end.rb")}>:/)
+          expect(loader.logger).to receive(:warn).with(/Plugin Syntax Error: <#{path_to("no_end.rb")}>:/)
           loader.load_plugin(path_to("no_end.rb"))
         end
 
@@ -236,7 +174,7 @@ EOF
 
       describe "when the plugin has an invalid name" do
         it "logs an invalid plugin name warning" do
-          expect(Ohai::Log).to receive(:warn).with(/Plugin Name Error: <#{path_to("bad_name.rb")}>:/)
+          expect(loader.logger).to receive(:warn).with(/Plugin Name Error: <#{path_to("bad_name.rb")}>:/)
           loader.load_plugin(path_to("bad_name.rb"))
         end
 
@@ -247,9 +185,9 @@ EOF
 
       describe "when plugin directory does not exist" do
         it "logs an invalid plugin path warning" do
-          expect(Ohai::Log).to receive(:info).with(/The plugin path.*does not exist/)
+          expect(Ohai::Log).to receive(:debug).with(/The plugin path.*does not exist/)
           allow(Dir).to receive(:exist?).with("/bogus/dir").and_return(false)
-          Ohai::Loader::PluginFile.find_all_in("/bogus/dir")
+          loader.plugin_files_by_dir("/bogus/dir")
         end
       end
     end
