@@ -16,10 +16,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "AIX hostname plugin" do
-  before(:each) do
+  before do
     @plugin = get_plugin("hostname")
     allow(@plugin).to receive(:collect_os).and_return(:aix)
     allow(@plugin).to receive(:from_cmd).with("hostname -s").and_return("aix_admin")
@@ -27,7 +27,7 @@ describe Ohai::System, "AIX hostname plugin" do
     @plugin.run
   end
 
-  it "should set the machinename" do
+  it "sets the machinename" do
     expect(@plugin[:machinename]).to eql("aix_admin")
   end
 end
