@@ -16,63 +16,63 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "AIX network plugin" do
 
-  before(:each) do
-    @netstat_rn_grep_default = <<-NETSTAT_RN_GREP_DEFAULT
-default            172.31.8.1        UG        2    121789 en0      -      -
-NETSTAT_RN_GREP_DEFAULT
+  before do
+    @netstat_rn_grep_default = <<~NETSTAT_RN_GREP_DEFAULT
+      default            172.31.8.1        UG        2    121789 en0      -      -
+    NETSTAT_RN_GREP_DEFAULT
 
-    @ifconfig = <<-IFCONFIG
-en0: flags=1e080863,480<UP,BROADCAST,NOTRAILERS,RUNNING,SIMPLEX,MULTICAST,GROUPRT,64BIT,CHECKSUM_OFFLOAD(ACTIVE),CHAIN> metric 1
-        inet 172.29.174.58 netmask 0xffffc000 broadcast 172.29.191.255
-        inet 172.29.174.59 broadcast 172.29.191.255
-        inet 172.29.174.60 netmask 0xffffc000 broadcast 172.29.191.255
-        inet6 ::1%1/0
-     tcp_sendspace 262144 tcp_recvspace 262144 rfc1323 1
-en1: flags=1e084863,480<UP,BROADCAST,NOTRAILERS,RUNNING,SIMPLEX,MULTICAST,GROUPRT,64BIT,CHECKSUM_OFFLOAD(ACTIVE),CHAIN>
-        inet 172.31.10.211 netmask 0xfffffc00 broadcast 172.31.11.255
-         tcp_sendspace 262144 tcp_recvspace 262144 rfc1323 1
-lo0: flags=e08084b,c0<UP,BROADCAST,LOOPBACK,RUNNING,SIMPLEX,MULTICAST,GROUPRT,64BIT,LARGESEND,CHAIN>
-        inet 127.0.0.1 netmask 0xff000000 broadcast 127.255.255.255
-        inet6 ::1%1/0
-         tcp_sendspace 131072 tcp_recvspace 131072 rfc1323 1
-IFCONFIG
+    @ifconfig = <<~IFCONFIG
+      en0: flags=1e080863,480<UP,BROADCAST,NOTRAILERS,RUNNING,SIMPLEX,MULTICAST,GROUPRT,64BIT,CHECKSUM_OFFLOAD(ACTIVE),CHAIN> metric 1
+              inet 172.29.174.58 netmask 0xffffc000 broadcast 172.29.191.255
+              inet 172.29.174.59 broadcast 172.29.191.255
+              inet 172.29.174.60 netmask 0xffffc000 broadcast 172.29.191.255
+              inet6 ::1%1/0
+           tcp_sendspace 262144 tcp_recvspace 262144 rfc1323 1
+      en1: flags=1e084863,480<UP,BROADCAST,NOTRAILERS,RUNNING,SIMPLEX,MULTICAST,GROUPRT,64BIT,CHECKSUM_OFFLOAD(ACTIVE),CHAIN>
+              inet 172.31.10.211 netmask 0xfffffc00 broadcast 172.31.11.255
+               tcp_sendspace 262144 tcp_recvspace 262144 rfc1323 1
+      lo0: flags=e08084b,c0<UP,BROADCAST,LOOPBACK,RUNNING,SIMPLEX,MULTICAST,GROUPRT,64BIT,LARGESEND,CHAIN>
+              inet 127.0.0.1 netmask 0xff000000 broadcast 127.255.255.255
+              inet6 ::1%1/0
+               tcp_sendspace 131072 tcp_recvspace 131072 rfc1323 1
+    IFCONFIG
 
-    @netstat_nrf_inet = <<-NETSTAT_NRF_INET
-Destination        Gateway           Flags   Refs     Use  If   Exp  Groups
-Route Tree for Protocol Family 2 (Internet):
-default            172.29.128.13     UG        0    587683 en0      -      -
-172.29.128.0       172.29.174.58     UHSb      0         0 en0      -      -   =>
-172.29.128/18      172.29.174.58     U         7   1035485 en0      -      -
-172.29.191.255     172.29.174.58     UHSb      0         1 en0      -      -
-NETSTAT_NRF_INET
+    @netstat_nrf_inet = <<~NETSTAT_NRF_INET
+      Destination        Gateway           Flags   Refs     Use  If   Exp  Groups
+      Route Tree for Protocol Family 2 (Internet):
+      default            172.29.128.13     UG        0    587683 en0      -      -
+      172.29.128.0       172.29.174.58     UHSb      0         0 en0      -      -   =>
+      172.29.128/18      172.29.174.58     U         7   1035485 en0      -      -
+      172.29.191.255     172.29.174.58     UHSb      0         1 en0      -      -
+    NETSTAT_NRF_INET
 
-    @entstat_err = <<-ENSTAT_ERR
+    @entstat_err = <<~ENSTAT_ERR
 
 
-entstat: 0909-002 Unable to open device en0, errno = 13
-grep: 0652-033 Cannot open Address".
-ENSTAT_ERR
+      entstat: 0909-002 Unable to open device en0, errno = 13
+      grep: 0652-033 Cannot open Address".
+    ENSTAT_ERR
 
-    @aix_arp_an = <<-ARP_AN
-  ? (172.29.131.16) at 6e:87:70:0:40:3 [ethernet] stored in bucket 16
+    @aix_arp_an = <<~ARP_AN
+        ? (172.29.131.16) at 6e:87:70:0:40:3 [ethernet] stored in bucket 16
 
-  ? (10.153.50.202) at 34:40:b5:ab:fb:5a [ethernet] stored in bucket 40
+        ? (10.153.50.202) at 34:40:b5:ab:fb:5a [ethernet] stored in bucket 40
 
-  ? (10.153.1.99) at 52:54:0:8e:f2:fb [ethernet] stored in bucket 58
+        ? (10.153.1.99) at 52:54:0:8e:f2:fb [ethernet] stored in bucket 58
 
-  ? (172.29.132.250) at 34:40:b5:a5:d7:1e [ethernet] stored in bucket 59
+        ? (172.29.132.250) at 34:40:b5:a5:d7:1e [ethernet] stored in bucket 59
 
-  ? (172.29.132.253) at 34:40:b5:a5:d7:2a [ethernet] stored in bucket 62
+        ? (172.29.132.253) at 34:40:b5:a5:d7:2a [ethernet] stored in bucket 62
 
-  ? (172.29.128.13) at 60:73:5c:69:42:44 [ethernet] stored in bucket 139
+        ? (172.29.128.13) at 60:73:5c:69:42:44 [ethernet] stored in bucket 139
 
-bucket:    0     contains:    0 entries
-There are 6 entries in the arp table.
-ARP_AN
+      bucket:    0     contains:    0 entries
+      There are 6 entries in the arp table.
+    ARP_AN
 
     @plugin = get_plugin("aix/network")
     allow(@plugin).to receive(:collect_os).and_return(:aix)
@@ -113,7 +113,7 @@ ARP_AN
         @plugin.run
       end
 
-      it 'for \'macaddress\'' do
+      it "for 'macaddress'" do
         expect(@plugin[:macaddress]).to eq("BE:42:80:00:B0:05")
       end
     end
@@ -232,6 +232,7 @@ ARP_AN
         @plugin.run
         @inet_interface_addresses = @plugin["network"]["interfaces"]["en0"][:addresses]["BE:42:80:00:B0:05"]
       end
+
       it "detects the family" do
         expect(@inet_interface_addresses[:family]).to eq("lladdr")
       end
@@ -286,6 +287,7 @@ ARP_AN
     before do
       @plugin.run
     end
+
     it "supresses the hostname entries" do
       expect(@plugin["network"]["arp"][0][:remote_host]).to eq("?")
     end
@@ -298,13 +300,4 @@ ARP_AN
       expect(@plugin["network"]["arp"][0][:remote_mac]).to eq("6e:87:70:0:40:3")
     end
   end
-
-  describe "hex_to_dec_netmask method" do
-    before do
-      @plugin.run
-    end
-    it "converts a netmask from hexadecimal form to decimal form" do
-      expect(@plugin.hex_to_dec_netmask("0xffff0000")).to eq("255.255.0.0")
-    end
-  end
 end
