@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 require "open-uri"
 
 describe Ohai::System, "plugin azure" do
@@ -53,9 +53,9 @@ describe Ohai::System, "plugin azure" do
 
   before do
     # skips all the metadata logic unless we want to test it
-    allow(plugin).to receive(:can_socket_connect?).
-      with(Ohai::Mixin::AzureMetadata::AZURE_METADATA_ADDR, 80).
-      and_return(false)
+    allow(plugin).to receive(:can_socket_connect?)
+      .with(Ohai::Mixin::AzureMetadata::AZURE_METADATA_ADDR, 80)
+      .and_return(false)
   end
 
   shared_examples_for "!azure" do
@@ -74,7 +74,7 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "with azure hint file" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return(hint)
     end
 
@@ -90,32 +90,32 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "without azure hint file or agent or dhcp options" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return(false)
       allow(File).to receive(:exist?).with("/usr/sbin/waagent").and_return(false)
       allow(Dir).to receive(:exist?).with('C:\WindowsAzure').and_return(false)
       allow(File).to receive(:exist?).with("/var/lib/dhcp/dhclient.eth0.leases").and_return(true)
       @double_file = double("/var/lib/dhcp/dhclient.eth0.leases")
-      allow(@double_file).to receive(:each).
-        and_yield("lease {").
-        and_yield('  interface "eth0";').
-        and_yield("  fixed-address 192.168.1.194;").
-        and_yield("  option subnet-mask 255.255.255.0;").
-        and_yield("  option routers 192.168.1.1;").
-        and_yield("  option dhcp-lease-time 86400;").
-        and_yield("  option dhcp-message-type 5;").
-        and_yield("  option domain-name-servers 8.8.8.8;").
-        and_yield("  option dhcp-server-identifier 192.168.1.2;").
-        and_yield("  option interface-mtu 1454;").
-        and_yield("  option dhcp-renewal-time 42071;").
-        and_yield("  option broadcast-address 192.168.1.255;").
-        and_yield("  option dhcp-rebinding-time 74471;").
-        and_yield('  option host-name "host-192-168-1-194";').
-        and_yield('  option domain-name "openstacklocal";').
-        and_yield("  renew 2 2016/03/01 01:49:41;").
-        and_yield("  rebind 2 2016/03/01 13:22:07;").
-        and_yield("  expire 2 2016/03/01 16:40:56;").
-        and_yield("}")
+      allow(@double_file).to receive(:each)
+        .and_yield("lease {")
+        .and_yield('  interface "eth0";')
+        .and_yield("  fixed-address 192.168.1.194;")
+        .and_yield("  option subnet-mask 255.255.255.0;")
+        .and_yield("  option routers 192.168.1.1;")
+        .and_yield("  option dhcp-lease-time 86400;")
+        .and_yield("  option dhcp-message-type 5;")
+        .and_yield("  option domain-name-servers 8.8.8.8;")
+        .and_yield("  option dhcp-server-identifier 192.168.1.2;")
+        .and_yield("  option interface-mtu 1454;")
+        .and_yield("  option dhcp-renewal-time 42071;")
+        .and_yield("  option broadcast-address 192.168.1.255;")
+        .and_yield("  option dhcp-rebinding-time 74471;")
+        .and_yield('  option host-name "host-192-168-1-194";')
+        .and_yield('  option domain-name "openstacklocal";')
+        .and_yield("  renew 2 2016/03/01 01:49:41;")
+        .and_yield("  rebind 2 2016/03/01 13:22:07;")
+        .and_yield("  expire 2 2016/03/01 16:40:56;")
+        .and_yield("}")
       allow(File).to receive(:open).with("/var/lib/dhcp/dhclient.eth0.leases").and_return(@double_file)
     end
 
@@ -123,7 +123,7 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "with rackspace hint file, no agent, and no dhcp lease" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("rackspace").and_return(true)
       allow(plugin).to receive(:hint?).with("azure").and_return(false)
       allow(File).to receive(:exist?).with("/usr/sbin/waagent").and_return(false)
@@ -135,7 +135,7 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "without azure hint file but with agent on linux" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return(false)
       allow(File).to receive(:exist?).with("/usr/sbin/waagent").and_return(true)
       allow(Dir).to receive(:exist?).with('C:\WindowsAzure').and_return(false)
@@ -145,7 +145,7 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "without azure hint file but with agent on windows" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return(false)
       allow(File).to receive(:exist?).with("/usr/sbin/waagent").and_return(false)
       allow(Dir).to receive(:exist?).with('C:\WindowsAzure').and_return(true)
@@ -155,32 +155,32 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "without azure hint or agent but with dhcp option" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return(false)
       allow(File).to receive(:exist?).with("/usr/sbin/waagent").and_return(false)
       allow(Dir).to receive(:exist?).with('C:\WindowsAzure').and_return(false)
       allow(File).to receive(:exist?).with("/var/lib/dhcp/dhclient.eth0.leases").and_return(true)
       @double_file = double("/var/lib/dhcp/dhclient.eth0.leases")
-      allow(@double_file).to receive(:each).
-        and_yield("lease {").
-        and_yield('  interface "eth0";').
-        and_yield("  fixed-address 10.1.0.5;").
-        and_yield('  server-name "RD24BE05C6F140";').
-        and_yield("  option subnet-mask 255.255.255.0;").
-        and_yield("  option dhcp-lease-time 4294967295;").
-        and_yield("  option routers 10.1.0.1;").
-        and_yield("  option dhcp-message-type 5;").
-        and_yield("  option dhcp-server-identifier 168.63.129.16;").
-        and_yield("  option domain-name-servers 168.63.129.16;").
-        and_yield("  option dhcp-renewal-time 4294967295;").
-        and_yield("  option rfc3442-classless-static-routes 0,10,1,0,1,32,168,63,129,16,10,1,0,1;").
-        and_yield("  option unknown-245 a8:3f:81:10;").
-        and_yield("  option dhcp-rebinding-time 4294967295;").
-        and_yield('  option domain-name "v4wvfurds4relghweduc4zqjmd.dx.internal.cloudapp.net";').
-        and_yield("  renew 5 2152/03/10 09:03:39;").
-        and_yield("  rebind 5 2152/03/10 09:03:39;").
-        and_yield("  expire 5 2152/03/10 09:03:39;").
-        and_yield("}")
+      allow(@double_file).to receive(:each)
+        .and_yield("lease {")
+        .and_yield('  interface "eth0";')
+        .and_yield("  fixed-address 10.1.0.5;")
+        .and_yield('  server-name "RD24BE05C6F140";')
+        .and_yield("  option subnet-mask 255.255.255.0;")
+        .and_yield("  option dhcp-lease-time 4294967295;")
+        .and_yield("  option routers 10.1.0.1;")
+        .and_yield("  option dhcp-message-type 5;")
+        .and_yield("  option dhcp-server-identifier 168.63.129.16;")
+        .and_yield("  option domain-name-servers 168.63.129.16;")
+        .and_yield("  option dhcp-renewal-time 4294967295;")
+        .and_yield("  option rfc3442-classless-static-routes 0,10,1,0,1,32,168,63,129,16,10,1,0,1;")
+        .and_yield("  option unknown-245 a8:3f:81:10;")
+        .and_yield("  option dhcp-rebinding-time 4294967295;")
+        .and_yield('  option domain-name "v4wvfurds4relghweduc4zqjmd.dx.internal.cloudapp.net";')
+        .and_yield("  renew 5 2152/03/10 09:03:39;")
+        .and_yield("  rebind 5 2152/03/10 09:03:39;")
+        .and_yield("  expire 5 2152/03/10 09:03:39;")
+        .and_yield("}")
       allow(File).to receive(:open).with("/var/lib/dhcp/dhclient.eth0.leases").and_return(@double_file)
     end
 
@@ -188,14 +188,14 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "with non-responsive metadata endpoint" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return({})
     end
 
     it "does not return metadata information" do
-      allow(plugin).to receive(:can_socket_connect?).
-        with(Ohai::Mixin::AzureMetadata::AZURE_METADATA_ADDR, 80).
-        and_return(true)
+      allow(plugin).to receive(:can_socket_connect?)
+        .with(Ohai::Mixin::AzureMetadata::AZURE_METADATA_ADDR, 80)
+        .and_return(true)
       allow(plugin).to receive(:fetch_metadata).and_return(nil)
 
       plugin.run
@@ -205,11 +205,11 @@ describe Ohai::System, "plugin azure" do
   end
 
   describe "with responsive metadata endpoint" do
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("azure").and_return({})
-      allow(plugin).to receive(:can_socket_connect?).
-        with(Ohai::Mixin::AzureMetadata::AZURE_METADATA_ADDR, 80).
-        and_return(true)
+      allow(plugin).to receive(:can_socket_connect?)
+        .with(Ohai::Mixin::AzureMetadata::AZURE_METADATA_ADDR, 80)
+        .and_return(true)
       allow(plugin).to receive(:fetch_metadata).and_return(response_data)
       plugin.run
     end
