@@ -19,26 +19,26 @@
 #
 
 begin
-  require_relative "../../spec_helper.rb"
+  require "spec_helper"
   require "chef/version"
 
   describe Ohai::System, "plugin chef" do
-    before(:each) do
+    before do
       @plugin = get_plugin("chef")
     end
 
-    it "should set [:chef_packages][:chef][:version] to the current chef version", :if => defined?(Chef) do
+    it "sets [:chef_packages][:chef][:version] to the current chef version", if: defined?(Chef) do
       @plugin.run
       expect(@plugin[:chef_packages][:chef][:version]).to eq(Chef::VERSION)
     end
 
-    pending "would set [:chef_packages][:chef][:version] if chef was available", :unless => defined?(Chef)
+    pending "would set [:chef_packages][:chef][:version] if chef was available", unless: defined?(Chef)
   end
 
 rescue LoadError
   # the chef module is not available, ignoring.
 
   describe Ohai::System, "plugin chef" do
-    pending "would set [:chef_packages][:chef][:version] if chef was available", :unless => defined?(Chef)
+    pending "would set [:chef_packages][:chef][:version] if chef was available", unless: defined?(Chef)
   end
 end
