@@ -16,27 +16,27 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "Darwin Memory Plugin" do
-  before(:each) do
-    darwin_memsize = <<-DARWIN_MEMSIZE
-17179869184
+  before do
+    darwin_memsize = <<~DARWIN_MEMSIZE
+      17179869184
     DARWIN_MEMSIZE
-    darwin_vm_stat = <<-DARWIN_VM_STAT
-Mach Virtual Memory Statistics: (page size of 4096 bytes)
-Pages free:                        2155305.
-Pages active:                       924164.
-Pages inactive:                     189127.
-Pages speculative:                  531321.
-Pages wired down:                   391749.
-"Translation faults":             14107520.
-Pages copy-on-write:                810071.
-Pages zero filled:                 6981505.
-Pages reactivated:                    1397.
-Pageins:                            630064.
-Pageouts:                                0.
-Object cache: 12 hits of 139872 lookups (0% hit rate)
+    darwin_vm_stat = <<~DARWIN_VM_STAT
+      Mach Virtual Memory Statistics: (page size of 4096 bytes)
+      Pages free:                        2155305.
+      Pages active:                       924164.
+      Pages inactive:                     189127.
+      Pages speculative:                  531321.
+      Pages wired down:                   391749.
+      "Translation faults":             14107520.
+      Pages copy-on-write:                810071.
+      Pages zero filled:                 6981505.
+      Pages reactivated:                    1397.
+      Pageins:                            630064.
+      Pageouts:                                0.
+      Object cache: 12 hits of 139872 lookups (0% hit rate)
     DARWIN_VM_STAT
 
     @plugin = get_plugin("darwin/memory")
@@ -46,19 +46,19 @@ Object cache: 12 hits of 139872 lookups (0% hit rate)
     @plugin.run
   end
 
-  it "should set memory[:total] to 16384MB" do
+  it "sets memory[:total] to 16384MB" do
     expect(@plugin[:memory][:total]).to eq("16384MB")
   end
 
-  it "should set memory[:active] to 5140MB" do
+  it "sets memory[:active] to 5140MB" do
     expect(@plugin[:memory][:active]).to eq("5140MB")
   end
 
-  it "should set memory[:inactive] to 738MB" do
+  it "sets memory[:inactive] to 738MB" do
     expect(@plugin[:memory][:inactive]).to eq("738MB")
   end
 
-  it "should set memory[:free] to 10504MB" do
+  it "sets memory[:free] to 10504MB" do
     expect(@plugin[:memory][:free]).to eq("10504MB")
   end
 end
