@@ -17,7 +17,7 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 require "open-uri"
 
 describe Ohai::System, "plugin eucalyptus" do
@@ -31,28 +31,28 @@ describe Ohai::System, "plugin eucalyptus" do
   end
 
   shared_examples_for "eucalyptus" do
-    before(:each) do
+    before do
       @http_client = double("Net::HTTP client")
       allow(plugin).to receive(:http_client).and_return(@http_client)
 
-      expect(@http_client).to receive(:get).
-        with("/").
-        and_return(double("Net::HTTP Response", :body => "2012-01-12", :code => "200"))
-      expect(@http_client).to receive(:get).
-        with("/2012-01-12/meta-data/").
-        and_return(double("Net::HTTP Response", :body => "instance_type\nami_id\nsecurity-groups", :code => "200"))
-      expect(@http_client).to receive(:get).
-        with("/2012-01-12/meta-data/instance_type").
-        and_return(double("Net::HTTP Response", :body => "c1.medium", :code => "200"))
-      expect(@http_client).to receive(:get).
-        with("/2012-01-12/meta-data/ami_id").
-        and_return(double("Net::HTTP Response", :body => "ami-5d2dc934", :code => "200"))
-      expect(@http_client).to receive(:get).
-        with("/2012-01-12/meta-data/security-groups").
-        and_return(double("Net::HTTP Response", :body => "group1\ngroup2", :code => "200"))
-      expect(@http_client).to receive(:get).
-        with("/2012-01-12/user-data/").
-        and_return(double("Net::HTTP Response", :body => "By the pricking of my thumb...", :code => "200"))
+      expect(@http_client).to receive(:get)
+        .with("/")
+        .and_return(double("Net::HTTP Response", body: "2012-01-12", code: "200"))
+      expect(@http_client).to receive(:get)
+        .with("/2012-01-12/meta-data/")
+        .and_return(double("Net::HTTP Response", body: "instance_type\nami_id\nsecurity-groups", code: "200"))
+      expect(@http_client).to receive(:get)
+        .with("/2012-01-12/meta-data/instance_type")
+        .and_return(double("Net::HTTP Response", body: "c1.medium", code: "200"))
+      expect(@http_client).to receive(:get)
+        .with("/2012-01-12/meta-data/ami_id")
+        .and_return(double("Net::HTTP Response", body: "ami-5d2dc934", code: "200"))
+      expect(@http_client).to receive(:get)
+        .with("/2012-01-12/meta-data/security-groups")
+        .and_return(double("Net::HTTP Response", body: "group1\ngroup2", code: "200"))
+      expect(@http_client).to receive(:get)
+        .with("/2012-01-12/user-data/")
+        .and_return(double("Net::HTTP Response", body: "By the pricking of my thumb...", code: "200"))
     end
 
     it "recursively fetches all the eucalyptus metadata" do
@@ -69,37 +69,41 @@ describe Ohai::System, "plugin eucalyptus" do
   end
 
   describe "with eucalyptus mac and metadata address connected" do
-    it_behaves_like "eucalyptus"
-
-    before(:each) do
+    before do
       allow(IO).to receive(:select).and_return([[], [1], []])
       plugin[:network] = { "interfaces" => { "eth0" => { "addresses" => { "d0:0d:95:47:6E:ED" => { "family" => "lladdr" } } } } }
     end
+
+    it_behaves_like "eucalyptus"
+
   end
 
   describe "without eucalyptus mac and metadata address connected" do
-    it_behaves_like "!eucalyptus"
-
-    before(:each) do
+    before do
       plugin[:network] = { "interfaces" => { "eth0" => { "addresses" => { "ff:ff:95:47:6E:ED" => { "family" => "lladdr" } } } } }
     end
+
+    it_behaves_like "!eucalyptus"
+
   end
 
   describe "with eucalyptus hint file" do
-    it_behaves_like "eucalyptus"
-
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("eucalyptus").and_return(true)
     end
+
+    it_behaves_like "eucalyptus"
+
   end
 
   describe "without hint file" do
-    it_behaves_like "!eucalyptus"
-
-    before(:each) do
-      plugin[:network] = { :interfaces => {} }
+    before do
+      plugin[:network] = { interfaces: {} }
       allow(plugin).to receive(:hint?).with("eucalyptus").and_return(false)
     end
+
+    it_behaves_like "!eucalyptus"
+
   end
 
 end
