@@ -17,214 +17,159 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 tmp = ENV["TMPDIR"] || ENV["TMP"] || ENV["TEMP"] || "/tmp"
 
 shared_examples "a v7 loading failure" do
   before(:all) do
-    begin
-      Dir.mkdir("#{tmp}/plugins")
-    rescue Errno::EEXIST
+
+    Dir.mkdir("#{tmp}/plugins")
+  rescue Errno::EEXIST
       # ignore
-    end
+
   end
 
-  before(:each) do
+  before do
     fail_file = File.open("#{tmp}/plugins/fail.rb", "w+")
     fail_file.write(failstr)
     fail_file.close
   end
 
-  after(:each) do
+  after do
     File.delete("#{tmp}/plugins/fail.rb")
   end
 
   after(:all) do
-    begin
-      Dir.delete("#{tmp}/plugins")
-    rescue
+
+    Dir.delete("#{tmp}/plugins")
+  rescue
       # ignore
-    end
+
   end
 
-  before(:each) do
+  before do
     @ohai = Ohai::System.new
     @loader = Ohai::Loader.new(@ohai)
   end
 
-  it "should not have attribute keys" do
+  it "does not have attribute keys" do
     @loader.load_plugin("#{tmp}/plugins/fail.rb")
-    #@ohai.attributes.should_not have_key("fail")
+    # @ohai.attributes.should_not have_key("fail")
     expect { @ohai.provides_map.find_providers_for(["fail"]) }.to raise_error(Ohai::Exceptions::AttributeNotFound)
   end
 
-  it "should not have source key" do
-    @loader.load_plugin("#{tmp}/plugins/fail.rb")
-    expect(@ohai.v6_dependency_solver).not_to have_key("#{tmp}/plugins/fail.rb")
-  end
-
-  it "should write to Ohai::Log" do
-    expect(Ohai::Log).to receive(:warn).once
+  it "writes to Ohai::Log" do
+    expect(@loader.logger).to receive(:warn).once
     @loader.load_plugin("#{tmp}/plugins/fail.rb")
   end
 end
 
 shared_examples "a v7 loading success" do
   before(:all) do
-    begin
-      Dir.mkdir("#{tmp}/plugins")
-    rescue Errno::EEXIST
+
+    Dir.mkdir("#{tmp}/plugins")
+  rescue Errno::EEXIST
       # ignore
-    end
+
   end
 
-  before(:each) do
+  before do
     fail_file = File.open("#{tmp}/plugins/fail.rb", "w+")
     fail_file.write(failstr)
     fail_file.close
   end
 
-  after(:each) do
+  after do
     File.delete("#{tmp}/plugins/fail.rb")
   end
 
   after(:all) do
-    begin
-      Dir.delete("#{tmp}/plugins")
-    rescue
+
+    Dir.delete("#{tmp}/plugins")
+  rescue
       # ignore
-    end
+
   end
 
-  before(:each) do
+  before do
     @ohai = Ohai::System.new
     @loader = Ohai::Loader.new(@ohai)
   end
 
-  it "should have attribute keys" do
+  it "has attribute keys" do
     @loader.load_plugin("#{tmp}/plugins/fail.rb")
     expect(@ohai.provides_map).to have_key("fail")
   end
 
-  it "should have source key" do
-    @loader.load_plugin("#{tmp}/plugins/fail.rb")
-    expect(@ohai.v6_dependency_solver).to have_key("#{tmp}/plugins/fail.rb")
-  end
-
-  it "should not write to Ohai::Log" do
-    expect(Ohai::Log).not_to receive(:warn)
+  it "does not write to Ohai::Log" do
+    expect(@loader.logger).not_to receive(:warn)
     @loader.load_plugin("#{tmp}/plugins/fail.rb")
   end
 end
 
 shared_examples "a v7 run failure" do
   before(:all) do
-    begin
-      Dir.mkdir("#{tmp}/plugins")
-    rescue Errno::EEXIST
+
+    Dir.mkdir("#{tmp}/plugins")
+  rescue Errno::EEXIST
       # ignore
-    end
+
   end
 
-  before(:each) do
+  before do
     fail_file = File.open("#{tmp}/plugins/fail.rb", "w+")
     fail_file.write(failstr)
     fail_file.close
   end
 
-  after(:each) do
+  after do
     File.delete("#{tmp}/plugins/fail.rb")
   end
 
   after(:all) do
-    begin
-      Dir.delete("#{tmp}/plugins")
-    rescue
+
+    Dir.delete("#{tmp}/plugins")
+  rescue
       # ignore
-    end
+
   end
 
-  before(:each) do
+  before do
     @ohai = Ohai::System.new
     @loader = Ohai::Loader.new(@ohai)
   end
 
-  it "should not have new attribute keys" do
+  it "does not have new attribute keys" do
     @loader.load_plugin("#{tmp}/plugins/fail.rb").new(@ohai).run
     expect(@ohai.provides_map).not_to have_key("other")
   end
 
-  it "should write to Ohai::Log" do
-    expect(Ohai::Log).to receive(:warn).once
+  it "writes to Ohai::Log" do
+    expect(@loader.logger).to receive(:warn).once
     @loader.load_plugin("#{tmp}/plugins/fail.rb").new(@ohai).run
   end
 end
 
-=begin
-shared_examples "a v6 run failure" do
-  before(:all) do
-    begin
-      Dir.mkdir("#{tmp}/plugins")
-    rescue Errno::EEXIST
-      # ignore
-    end
-  end
-
-  before(:each) do
-    fail_file = File.open("#{tmp}/plugins/fail.rb", "w+")
-    fail_file.write(failstr)
-    fail_file.close
-  end
-
-  after(:each) do
-    File.delete("#{tmp}/plugins/fail.rb")
-  end
-
-  after(:all) do
-    begin
-      Dir.delete("#{tmp}/plugins")
-    rescue
-      # ignore
-    end
-  end
-
-  before(:each) do
-    @ohai = Ohai::System.new
-    @loader = Ohai::Loader.new(@ohai)
-  end
-
-  it "should not add data keys" do
-    @loader.load_plugin("#{tmp}/plugins/fail.rb")
-    @ohai.data.should_not have_key("fail")
-  end
-
-  it "should write to Ohai::Log" do
-    Ohai::Log.should_receive(:warn).once
-    @loader.load_plugin("#{tmp}/plugins/fail.rb").new(@ohai).run
-  end
-end
-=end
-
 describe "when using DSL commands outside Ohai.plugin block" do
-  failstr1 = <<EOF
-provides "fail"
-Ohai.plugin do
-end
-EOF
+  failstr1 = <<~EOF
+    provides "fail"
+    Ohai.plugin do
+    end
+  EOF
 
-  failstr2 = <<EOF
-depends "fail"
-Ohai.plugin do
-end
-EOF
+  failstr2 = <<~EOF
+    depends "fail"
+    Ohai.plugin do
+    end
+  EOF
 
-  failstr3 = <<EOF
-collect_data do
-end
-Ohai.plugin do
-end
-EOF
+  failstr3 = <<~EOF
+    collect_data do
+    end
+    Ohai.plugin do
+    end
+  EOF
 
   it_behaves_like "a v7 loading failure" do
     let(:failstr) { failstr1 }
