@@ -16,10 +16,10 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "FreeBSD hostname plugin" do
-  before(:each) do
+  before do
     @plugin = get_plugin("hostname")
     allow(@plugin).to receive(:collect_os).and_return(:freebsd)
     allow(@plugin).to receive(:shell_out).with("hostname -s").and_return(mock_shell_out(0, "katie", ""))
