@@ -16,19 +16,19 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "FreeBSD kernel plugin" do
-  before(:each) do
+  before do
     @plugin = get_plugin("kernel")
     allow(@plugin).to receive(:collect_os).and_return(:freebsd)
-    allow(@plugin).to receive(:init_kernel).and_return({ :name => "freebsd" })
+    allow(@plugin).to receive(:init_kernel).and_return({ name: "freebsd" })
     allow(@plugin).to receive(:shell_out).with("uname -i").and_return(mock_shell_out(0, "foo\n", ""))
     allow(@plugin).to receive(:shell_out).with("sysctl kern.securelevel").and_return(mock_shell_out(0, "kern.securelevel: 1", ""))
     allow(@plugin).to receive(:shell_out).with( Ohai.abs_path( "/sbin/kldstat" )).and_return(mock_shell_out(0, "  1    7 0xc0400000 97f830   kernel", ""))
   end
 
-  it "should set the kernel_os to the kernel_name value" do
+  it "sets the kernel_os to the kernel_name value" do
     @plugin.run
     expect(@plugin[:kernel][:os]).to eq(@plugin[:kernel][:name])
   end
