@@ -16,22 +16,22 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "FreeBSD plugin platform" do
-  before(:each) do
+  before do
     @plugin = get_plugin("freebsd/platform")
     allow(@plugin).to receive(:shell_out).with("uname -s").and_return(mock_shell_out(0, "FreeBSD\n", ""))
     allow(@plugin).to receive(:shell_out).with("uname -r").and_return(mock_shell_out(0, "7.1\n", ""))
     allow(@plugin).to receive(:collect_os).and_return(:freebsd)
   end
 
-  it "should set platform to lowercased lsb[:id]" do
+  it "sets platform to lowercased lsb[:id]" do
     @plugin.run
     expect(@plugin[:platform]).to eq("freebsd")
   end
 
-  it "should set platform_version to lsb[:release]" do
+  it "sets platform_version to lsb[:release]" do
     @plugin.run
     expect(@plugin[:platform_version]).to eq("7.1")
   end
