@@ -17,12 +17,12 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin java (Java5 Client VM)" do
   let(:plugin) { get_plugin("java") }
 
-  before(:each) do
+  before do
     plugin[:languages] = Mash.new
   end
 
@@ -78,7 +78,7 @@ describe Ohai::System, "plugin java (Java5 Client VM)" do
 
   shared_examples_for "when the Server JRE is installed" do
 
-    before(:each) do
+    before do
       stderr = "java version \"1.6.0_22\"\nJava(TM) 2 Runtime Environment (build 1.6.0_22-b04)\nJava HotSpot(TM) Server VM (build 17.1-b03, mixed mode)"
       allow(plugin).to receive(:shell_out).with("java -mx64m -version").and_return(mock_shell_out(0, "", stderr))
     end
@@ -123,7 +123,7 @@ describe Ohai::System, "plugin java (Java5 Client VM)" do
 
   shared_examples_for "when the openjdk 1.8 is installed" do
 
-    before(:each) do
+    before do
       stderr = "openjdk version \"1.8.0_71\"\nOpenJDK Runtime Environment (build 1.8.0_71-b15)\nOpenJDK 64-Bit Server VM (build 25.71-b15, mixed mode)"
       allow(plugin).to receive(:shell_out).with("java -mx64m -version").and_return(mock_shell_out(0, "", stderr))
     end
@@ -174,9 +174,11 @@ describe Ohai::System, "plugin java (Java5 Client VM)" do
     context "and the client JRE is installed" do
       include_examples "when the JRE is installed"
     end
+
     context "and the server JRE is installed" do
       include_examples "when the Server JRE is installed"
     end
+
     context "and the openjdk 1.8 is installed" do
       include_examples "when the openjdk 1.8 is installed"
     end
@@ -193,17 +195,19 @@ describe Ohai::System, "plugin java (Java5 Client VM)" do
 
     context "and real Java is installed" do
       before do
-        java_home_status = double(Process::Status, :success? => true)
-        java_home_cmd = double(Mixlib::ShellOut, :status => java_home_status)
+        java_home_status = double(Process::Status, success?: true)
+        java_home_cmd = double(Mixlib::ShellOut, status: java_home_status)
         expect(plugin).to receive(:shell_out).with("/usr/libexec/java_home").and_return(java_home_cmd)
       end
 
       context "and the client JRE is installed" do
         include_examples "when the JRE is installed"
       end
+
       context "and the server JRE is installed" do
         include_examples "when the Server JRE is installed"
       end
+
       context "and the openjdk 1.8 is installed" do
         include_examples "when the openjdk 1.8 is installed"
       end
@@ -211,8 +215,8 @@ describe Ohai::System, "plugin java (Java5 Client VM)" do
 
     context "and the JVM stubs are installed" do
       before do
-        java_home_status = double(Process::Status, :success? => false)
-        java_home_cmd = double(Mixlib::ShellOut, :status => java_home_status)
+        java_home_status = double(Process::Status, success?: false)
+        java_home_cmd = double(Mixlib::ShellOut, status: java_home_status)
         expect(plugin).to receive(:shell_out).with("/usr/libexec/java_home").and_return(java_home_cmd)
       end
 
