@@ -1,6 +1,6 @@
 #
 # Author:: Matt Wrock (<matt@mattwrock.com>)
-# Copyright:: Copyright (c) 2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2016-2018 Chef Software, Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,44 +16,45 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
+require "openssl"
 
 describe Ohai::System, "plugin fips" do
+  subject do
+    plugin.run
+    plugin["fips"]["kernel"]["enabled"]
+  end
+
   let(:enabled) { "0" }
   let(:plugin) { get_plugin("linux/fips") }
-  let(:fips_path) { "/proc/sys/crypto/fips_enabled" }
+  let(:openssl_test_mode) { false }
 
-  before(:each) do
+  before do
     allow(plugin).to receive(:collect_os).and_return(:linux)
-    allow(::File).to receive(:read).with(fips_path).and_return(enabled)
   end
 
-  context "fips file is present and contains 1" do
-    let(:enabled) { "1" }
+  around do |ex|
+
+    $FIPS_TEST_MODE = openssl_test_mode
+    ex.run
+  ensure
+    $FIPS_TEST_MODE = false
+
+  end
+
+  context "with OpenSSL.fips_mode == false" do
+    before { allow(OpenSSL).to receive(:fips_mode).and_return(false) }
+
+    it "does not set fips plugin" do
+      expect(subject).to be(false)
+    end
+  end
+
+  context "with OpenSSL.fips_mode == true" do
+    before { allow(OpenSSL).to receive(:fips_mode).and_return(true) }
 
     it "sets fips plugin" do
-      plugin.run
-      expect(plugin["fips"]["kernel"]["enabled"]).to be(true)
-    end
-  end
-
-  context "fips file does not contain 1" do
-    let(:enabled) { "0" }
-
-    it "does not set fips plugin" do
-      plugin.run
-      expect(plugin["fips"]["kernel"]["enabled"]).to be(false)
-    end
-  end
-
-  context "fips file is not present" do
-    before do
-      allow(::File).to receive(:read).and_raise(Errno::ENOENT, "bibbleboop")
-    end
-
-    it "does not set fips plugin" do
-      plugin.run
-      expect(plugin["fips"]["kernel"]["enabled"]).to be(false)
+      expect(subject).to be(true)
     end
   end
 end
