@@ -16,16 +16,16 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "Linux hostnamectl plugin" do
   let(:plugin) { get_plugin("linux/hostnamectl") }
 
-  before(:each) do
+  before do
     allow(plugin).to receive(:collect_os).and_return(:linux)
   end
 
-  it "should populate hostnamectl if hostnamectl is available" do
+  it "populates hostnamectl if hostnamectl is available" do
     hostnamectl_out = <<-HOSTNAMECTL_OUT
    Static hostname: foo
          Icon name: computer-laptop
@@ -35,7 +35,7 @@ describe Ohai::System, "Linux hostnamectl plugin" do
   Operating System: Debian GNU/Linux 8 (jessie)
             Kernel: Linux 4.3.0-0.bpo.1-amd64
       Architecture: x86-64
-HOSTNAMECTL_OUT
+    HOSTNAMECTL_OUT
 
     allow(plugin).to receive(:which).with("hostnamectl").and_return("/bin/hostnamectl")
     allow(plugin).to receive(:shell_out).with("/bin/hostnamectl").and_return(mock_shell_out(0, hostnamectl_out, ""))
@@ -52,7 +52,7 @@ HOSTNAMECTL_OUT
     })
   end
 
-  it "should not populate hostnamectl if hostnamectl is not available" do
+  it "does not populate hostnamectl if hostnamectl is not available" do
     allow(plugin).to receive(:which).with("hostnamectl").and_return(false)
     expect(plugin[:hostnamectl]).to eq(nil)
   end
