@@ -17,20 +17,20 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "Linux kernel plugin" do
-  before(:each) do
-    @env_lsmod = <<-ENV_LSMOD
-Module                  Size  Used by
-dm_crypt               22321  0
-psmouse                81038  0
-acpiphp                23314  0
-microcode              18286  0
-serio_raw              13031  0
-virtio_balloon         13168  0
-floppy                 55441  0
-ENV_LSMOD
+  before do
+    @env_lsmod = <<~ENV_LSMOD
+      Module                  Size  Used by
+      dm_crypt               22321  0
+      psmouse                81038  0
+      acpiphp                23314  0
+      microcode              18286  0
+      serio_raw              13031  0
+      virtio_balloon         13168  0
+      floppy                 55441  0
+    ENV_LSMOD
     @version_module = {
       dm_crypt: "",
       psmouse: "",
@@ -42,13 +42,13 @@ ENV_LSMOD
     }
 
     @expected_result = {
-      "dm_crypt"       => { "size" => "22321", "refcount" => "0" },
-      "psmouse"        => { "size" => "81038", "refcount" => "0" },
-      "acpiphp"        => { "size" => "23314", "refcount" => "0" },
-      "microcode"      => { "size" => "18286", "refcount" => "0", "version" => "1.2.3" },
-      "serio_raw"      => { "size" => "13031", "refcount" => "0" },
+      "dm_crypt" => { "size" => "22321", "refcount" => "0" },
+      "psmouse" => { "size" => "81038", "refcount" => "0" },
+      "acpiphp" => { "size" => "23314", "refcount" => "0" },
+      "microcode" => { "size" => "18286", "refcount" => "0", "version" => "1.2.3" },
+      "serio_raw" => { "size" => "13031", "refcount" => "0" },
       "virtio_balloon" => { "size" => "13168", "refcount" => "0" },
-      "floppy"         => { "size" => "55441", "refcount" => "0" },
+      "floppy" => { "size" => "55441", "refcount" => "0" },
     }
     @plugin = get_plugin("kernel")
     allow(@plugin).to receive(:collect_os).and_return(:linux)
@@ -59,7 +59,7 @@ ENV_LSMOD
       allow(File).to receive(:exist?).with("/sys/module/#{mod}/version").and_return(true)
       allow(File).to receive(:read).with("/sys/module/#{mod}/version").and_return(vers)
     end
-    expect(@plugin).to receive(:shell_out).with("env lsmod").at_least(1).times
+    expect(@plugin).to receive(:shell_out).with("env lsmod").at_least(:once)
     @plugin.run
   end
 
