@@ -16,30 +16,30 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "Machine id plugin" do
   let(:plugin) { get_plugin("linux/machineid") }
 
-  before(:each) do
+  before do
     allow(plugin).to receive(:collect_os).and_return(:linux)
   end
 
-  it "should read /etc/machine-id if available" do
+  it "reads /etc/machine-id if available" do
     machine_id = "6f702523e2fc7499eb1dc68e5314dacf"
 
-    allow(File).to receive(:exists?).with("/etc/machine-id").and_return(true)
-    allow(File).to receive(:read).with("/etc/machine-id").and_return(machine_id)
+    allow(::File).to receive(:exist?).with("/etc/machine-id").and_return(true)
+    allow(::File).to receive(:read).with("/etc/machine-id").and_return(machine_id)
     plugin.run
     expect(plugin[:machine_id]).to eq(machine_id)
   end
 
-  it "should read /var/lib/dbus/machine-id if available" do
+  it "reads /var/lib/dbus/machine-id if available" do
     machine_id = "6f702523e2fc7499eb1dc68e5314dacf"
 
-    allow(File).to receive(:exists?).with("/etc/machine-id").and_return(false)
-    allow(File).to receive(:exists?).with("/var/lib/dbus/machine-id").and_return(true)
-    allow(File).to receive(:read).with("/var/lib/dbus/machine-id").and_return(machine_id)
+    allow(::File).to receive(:exist?).with("/etc/machine-id").and_return(false)
+    allow(::File).to receive(:exist?).with("/var/lib/dbus/machine-id").and_return(true)
+    allow(::File).to receive(:read).with("/var/lib/dbus/machine-id").and_return(machine_id)
     plugin.run
     expect(plugin[:machine_id]).to eq(machine_id)
   end
