@@ -16,22 +16,22 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "Linux sessions plugin" do
   let(:plugin) { get_plugin("linux/sessions") }
 
-  before(:each) do
+  before do
     allow(plugin).to receive(:collect_os).and_return(:linux)
   end
 
-  it "should populate sessions if loginctl is found" do
+  it "populates sessions if loginctl is found" do
     loginctl_out = <<-LOGINCTL_OUT
         c1        118 Debian-gdm       seat0
        318          0 root
         46          0 root
        306       1000 joe
-LOGINCTL_OUT
+    LOGINCTL_OUT
     allow(plugin).to receive(:which).with("loginctl").and_return("/bin/loginctl")
     allow(plugin).to receive(:shell_out).with("/bin/loginctl --no-pager --no-legend --no-ask-password list-sessions").and_return(mock_shell_out(0, loginctl_out, ""))
     plugin.run
@@ -90,7 +90,7 @@ LOGINCTL_OUT
     })
   end
 
-  it "should not populate sessions if loginctl is not found" do
+  it "does not populate sessions if loginctl is not found" do
     allow(plugin).to receive(:which).with("loginctl").and_return(false)
     plugin.run
     expect(plugin[:sessions]).to be(nil)
