@@ -18,13 +18,13 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin lua" do
 
   let(:plugin) { get_plugin("lua") }
 
-  before(:each) do
+  before do
     plugin[:languages] = Mash.new
     @message = "Lua 5.1.2  Copyright (C) 1994-2008 Lua.org, PUC-Rio\n"
     allow(plugin).to receive(:shell_out).with("lua -v").and_return(mock_shell_out(0, "", @message))
