@@ -16,22 +16,22 @@
 # limitations under the License.
 #
 
-require File.expand_path(File.dirname(__FILE__) + "/../../../spec_helper.rb")
+require "spec_helper"
 
 describe Ohai::System, "NetBSD plugin platform" do
-  before(:each) do
+  before do
     @plugin = get_plugin("netbsd/platform")
     allow(@plugin).to receive(:shell_out).with("uname -s").and_return(mock_shell_out(0, "NetBSD\n", ""))
     allow(@plugin).to receive(:shell_out).with("uname -r").and_return(mock_shell_out(0, "4.5\n", ""))
     allow(@plugin).to receive(:collect_os).and_return(:netbsd)
   end
 
-  it "should set platform to lowercased lsb[:id]" do
+  it "sets platform to lowercased lsb[:id]" do
     @plugin.run
     expect(@plugin[:platform]).to eq("netbsd")
   end
 
-  it "should set platform_version to lsb[:release]" do
+  it "sets platform_version to lsb[:release]" do
     @plugin.run
     expect(@plugin[:platform_version]).to eq("4.5")
   end
