@@ -16,12 +16,12 @@
 #  limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 def it_doesnt_fail
   it "doesnt fail" do
-    allow(Ohai::Log).to receive(:warn)
-    expect(Ohai::Log).not_to receive(:debug).with(/^Plugin network threw exception/)
+    allow(@plugin.logger).to receive(:warn)
+    expect(@plugin.logger).not_to receive(:trace).with(/^Plugin network threw exception/)
     @plugin.run
   end
 end
@@ -31,17 +31,17 @@ def it_populates_ipaddress_attributes
   source = caller[0]
 
   it "populates ipaddress, macaddress and ip6address" do
-    begin
-      allow(Ohai::Log).to receive(:warn)
-      expect(Ohai::Log).not_to receive(:debug).with(/^Plugin network threw exception/)
-      @plugin.run
-      %w{ ipaddress macaddress ip6address }.each do |attribute|
-        expect(@plugin).to have_key(attribute)
-      end
-    rescue Exception
-      puts "RSpec context: #{source}"
-      raise
+
+    allow(@plugin.logger).to receive(:warn)
+    expect(@plugin.logger).not_to receive(:trace).with(/^Plugin network threw exception/)
+    @plugin.run
+    %w{ ipaddress macaddress ip6address }.each do |attribute|
+      expect(@plugin).to have_key(attribute)
     end
+  rescue Exception
+    puts "RSpec context: #{source}"
+    raise
+
   end
 end
 
@@ -329,7 +329,7 @@ describe Ohai::System, "Network Plugin" do
   }
 
   describe "on linux" do
-    before(:each) do
+    before do
       @plugin = get_plugin("network")
       @plugin["network"] = basic_data["linux"]["network"]
     end
@@ -367,8 +367,8 @@ describe Ohai::System, "Network Plugin" do
           end
 
           it "informs about this setup" do
-            expect(Ohai::Log).to receive(:debug).with(/ipaddress and ip6address are set from different interfaces/)
-            allow(Ohai::Log).to receive(:debug)
+            expect(@plugin.logger).to receive(:trace).with(/ipaddress and ip6address are set from different interfaces/)
+            allow(@plugin.logger).to receive(:trace)
             @plugin.run
           end
         end
@@ -396,8 +396,8 @@ describe Ohai::System, "Network Plugin" do
           end
 
           it "informs about this setup" do
-            expect(Ohai::Log).to receive(:debug).with(/ipaddress and ip6address are set from different interfaces/)
-            allow(Ohai::Log).to receive(:debug)
+            expect(@plugin.logger).to receive(:trace).with(/ipaddress and ip6address are set from different interfaces/)
+            allow(@plugin.logger).to receive(:trace)
             @plugin.run
           end
         end
@@ -413,7 +413,7 @@ describe Ohai::System, "Network Plugin" do
           it_populates_ipaddress_attributes
 
           it "picks {ip,ip6,mac}address" do
-            allow(Ohai::Log).to receive(:warn)
+            allow(@plugin.logger).to receive(:warn)
             @plugin.run
             expect(@plugin["ipaddress"]).to eq("192.168.99.11")
             expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:80")
@@ -421,9 +421,9 @@ describe Ohai::System, "Network Plugin" do
           end
 
           it "warns about this conflict" do
-            expect(Ohai::Log).to receive(:debug).with(/\[inet\] no ipaddress\/mask on eth1/).once
-            expect(Ohai::Log).to receive(:debug).with(/\[inet6\] no ipaddress\/mask on eth1/).once
-            allow(Ohai::Log).to receive(:debug)
+            expect(@plugin.logger).to receive(:trace).with(%r{\[inet\] no ipaddress/mask on eth1}).once
+            expect(@plugin.logger).to receive(:trace).with(%r{\[inet6\] no ipaddress/mask on eth1}).once
+            allow(@plugin.logger).to receive(:trace)
             @plugin.run
           end
         end
@@ -435,7 +435,7 @@ describe Ohai::System, "Network Plugin" do
           end
 
           it "picks {ip,ip6,mac}address" do
-            allow(Ohai::Log).to receive(:warn)
+            allow(@plugin.logger).to receive(:warn)
             @plugin.run
             expect(@plugin["ipaddress"]).to eq("192.168.66.33")
             expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:79")
@@ -452,7 +452,7 @@ describe Ohai::System, "Network Plugin" do
           it_doesnt_fail
 
           it "doesn't detect {ip,ip6,mac}address" do
-            allow(Ohai::Log).to receive(:warn)
+            allow(@plugin.logger).to receive(:warn)
             @plugin.run
             expect(@plugin["ipaddress"]).to be_nil
             expect(@plugin["macaddress"]).to be_nil
@@ -460,11 +460,11 @@ describe Ohai::System, "Network Plugin" do
           end
 
           it "warns about this conflict" do
-            expect(Ohai::Log).to receive(:warn).with(/unable to detect ipaddress/).once
-            expect(Ohai::Log).to receive(:warn).with(/\[inet\] no ip address on eth0/).once
-            expect(Ohai::Log).to receive(:debug).with(/unable to detect ip6address/).once
-            expect(Ohai::Log).to receive(:debug).with(/unable to detect macaddress/).twice # for each family
-            expect(Ohai::Log).to receive(:warn).with(/\[inet6\] no ip address on eth0/).once
+            expect(@plugin.logger).to receive(:warn).with(/unable to detect ipaddress/).once
+            expect(@plugin.logger).to receive(:warn).with(/\[inet\] no ip address on eth0/).once
+            expect(@plugin.logger).to receive(:trace).with(/unable to detect ip6address/).once
+            expect(@plugin.logger).to receive(:trace).with(/unable to detect macaddress/).twice # for each family
+            expect(@plugin.logger).to receive(:warn).with(/\[inet6\] no ip address on eth0/).once
             @plugin.run
           end
         end
@@ -475,25 +475,25 @@ describe Ohai::System, "Network Plugin" do
             @plugin["network"]["default_interface"] = nil
             @plugin["network"]["default_inet6_gateway"] = nil
             @plugin["network"]["default_inet6_interface"] = nil
-            @plugin["network"]["interfaces"].each do |i, iv|
-              iv["addresses"].delete_if { |k, kv| %w{inet inet6}.include? kv["family"] }
+            @plugin["network"]["interfaces"].each_value do |val|
+              val["addresses"].delete_if { |k, kv| %w{inet inet6}.include? kv["family"] }
             end
           end
 
           it_doesnt_fail
 
           it "doesn't detect {ip,ip6,mac}address" do
-            allow(Ohai::Log).to receive(:warn)
+            allow(@plugin.logger).to receive(:warn)
             @plugin.run
             expect(@plugin["ipaddress"]).to be_nil
             expect(@plugin["macaddress"]).to be_nil
             expect(@plugin["ip6address"]).to be_nil
           end
 
-          it "should warn about it" do
-            expect(Ohai::Log).to receive(:warn).with(/unable to detect ipaddress/).once
-            expect(Ohai::Log).to receive(:debug).with(/unable to detect macaddress/).twice # for each family
-            expect(Ohai::Log).to receive(:debug).with(/unable to detect ip6address/).once
+          it "warns about it" do
+            expect(@plugin.logger).to receive(:warn).with(/unable to detect ipaddress/).once
+            expect(@plugin.logger).to receive(:trace).with(/unable to detect macaddress/).twice # for each family
+            expect(@plugin.logger).to receive(:trace).with(/unable to detect ip6address/).once
             @plugin.run
           end
         end
@@ -643,9 +643,9 @@ describe Ohai::System, "Network Plugin" do
           it_populates_ipaddress_attributes
 
           it "picks {ip,mac,ip6}address from the first interface" do
-            expect(Ohai::Log).to receive(:debug).with(/\[inet\] no default interface/).once
-            expect(Ohai::Log).to receive(:debug).with(/\[inet6\] no default interface/).once
-            allow(Ohai::Log).to receive(:debug)
+            expect(@plugin.logger).to receive(:trace).with(/\[inet\] no default interface/).once
+            expect(@plugin.logger).to receive(:trace).with(/\[inet6\] no default interface/).once
+            allow(@plugin.logger).to receive(:trace)
             @plugin.run
             expect(@plugin["ipaddress"]).to eq("192.168.99.11")
             expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:80")
@@ -660,15 +660,15 @@ describe Ohai::System, "Network Plugin" do
             @plugin["network"]["default_inet6_gateway"] = nil
             @plugin["network"]["default_inet6_interface"] = nil
             # just changing scopes to lInK for eth0 addresses
-            @plugin["network"]["interfaces"]["eth0"]["addresses"].each { |k, v| v[:scope] = "lInK" if %w{inet inet6}.include? v["family"] }
+            @plugin["network"]["interfaces"]["eth0"]["addresses"].each_value { |v| v[:scope] = "lInK" if %w{inet inet6}.include? v["family"] }
           end
 
           it_populates_ipaddress_attributes
 
           it "prefers global scope addressses to set {ip,mac,ip6}address" do
-            expect(Ohai::Log).to receive(:debug).with(/\[inet\] no default interface/).once
-            expect(Ohai::Log).to receive(:debug).with(/\[inet6\] no default interface/).once
-            allow(Ohai::Log).to receive(:debug)
+            expect(@plugin.logger).to receive(:trace).with(/\[inet\] no default interface/).once
+            expect(@plugin.logger).to receive(:trace).with(/\[inet6\] no default interface/).once
+            allow(@plugin.logger).to receive(:trace)
             @plugin.run
             expect(@plugin["ipaddress"]).to eq("192.168.99.11")
             expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:80")
@@ -781,37 +781,37 @@ describe Ohai::System, "Network Plugin" do
         before do
           @plugin["network"]["default_gateway"] = nil
           @plugin["network"]["default_interface"] = nil
-          @plugin["network"]["interfaces"].each do |i, iv|
-            iv["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
+          @plugin["network"]["interfaces"].each_value do |val|
+            val["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
           end
         end
 
         it_doesnt_fail
 
         it "can't detect ipaddress" do
-          allow(Ohai::Log).to receive(:warn)
+          allow(@plugin.logger).to receive(:warn)
           @plugin.run
           expect(@plugin["ipaddress"]).to be_nil
         end
 
         it "warns about not being able to set {ip,mac}address (ipv4)" do
-          expect(Ohai::Log).to receive(:warn).with(/unable to detect ipaddress/).once
-          expect(Ohai::Log).to receive(:debug).with(/unable to detect macaddress/) # for ipv4
-          expect(Ohai::Log).to receive(:debug).with(/setting macaddress to/) # for ipv6
-          expect(Ohai::Log).to receive(:debug).with(/\[inet6\] Using default interface eth0 and default gateway/) # for ipv6
+          expect(@plugin.logger).to receive(:warn).with(/unable to detect ipaddress/).once
+          expect(@plugin.logger).to receive(:trace).with(/unable to detect macaddress/) # for ipv4
+          expect(@plugin.logger).to receive(:trace).with(/setting macaddress to/) # for ipv6
+          expect(@plugin.logger).to receive(:trace).with(/\[inet6\] Using default interface eth0 and default gateway/) # for ipv6
           @plugin.run
         end
 
         it "sets {ip6,mac}address" do
-          allow(Ohai::Log).to receive(:warn)
+          allow(@plugin.logger).to receive(:warn)
           @plugin.run
           expect(@plugin["ip6address"]).to eq("3ffe:1111:2222::33")
           expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:79")
         end
 
         it "informs about macaddress being set using the ipv6 setup" do
-          expect(Ohai::Log).to receive(:debug).with(/setting macaddress to '00:16:3E:2F:36:79'/)
-          allow(Ohai::Log).to receive(:debug)
+          expect(@plugin.logger).to receive(:trace).with(/setting macaddress to '00:16:3E:2F:36:79'/)
+          allow(@plugin.logger).to receive(:trace)
           @plugin.run
         end
       end
@@ -822,6 +822,7 @@ describe Ohai::System, "Network Plugin" do
           @plugin["network"]["default_interface"] = nil
           @plugin["network"]["interfaces"].each do |i, iv|
             next if i == "lo"
+
             iv["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
           end
         end
@@ -829,21 +830,21 @@ describe Ohai::System, "Network Plugin" do
         it_doesnt_fail
 
         it "can't detect ipaddress" do
-          allow(Ohai::Log).to receive(:warn)
+          allow(@plugin.logger).to receive(:warn)
           @plugin.run
           expect(@plugin["ipaddress"]).to eq("127.0.0.1")
         end
 
         it "sets {ip6,mac}address" do
-          allow(Ohai::Log).to receive(:warn)
+          allow(@plugin.logger).to receive(:warn)
           @plugin.run
           expect(@plugin["ip6address"]).to eq("3ffe:1111:2222::33")
           expect(@plugin["macaddress"]).to eq("00:16:3E:2F:36:79")
         end
 
         it "informs about macaddress being set using the ipv6 setup" do
-          expect(Ohai::Log).to receive(:debug).with(/setting macaddress to '00:16:3E:2F:36:79'/)
-          allow(Ohai::Log).to receive(:debug)
+          expect(@plugin.logger).to receive(:trace).with(/setting macaddress to '00:16:3E:2F:36:79'/)
+          allow(@plugin.logger).to receive(:trace)
           @plugin.run
         end
       end
@@ -852,7 +853,7 @@ describe Ohai::System, "Network Plugin" do
     # specs using network plugin data for each mocked OS (freebsd,linux,windows)
     basic_data.keys.sort.each do |os|
       describe "the #{os}::network has already set some of the {ip,mac,ip6}address attributes" do
-        before(:each) do
+        before do
           @plugin["network"] = basic_data[os]["network"]
         end
 
@@ -928,9 +929,9 @@ describe Ohai::System, "Network Plugin" do
             before do
               @plugin["network"]["default_gateway"] = nil
               @plugin["network"]["default_interface"] = nil
-              @plugin["network"]["interfaces"].each do |i, iv|
-                if iv.has_key? "addresses"
-                  iv["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
+              @plugin["network"]["interfaces"].each_value do |val|
+                if val.key? "addresses"
+                  val["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
                 end
               end
               @plugin["ip6address"] = "3ffe:8888:9999::1"
@@ -950,24 +951,24 @@ describe Ohai::System, "Network Plugin" do
             it_doesnt_fail
 
             it "can't detect ipaddress (ipv4)" do
-              allow(Ohai::Log).to receive(:warn)
+              allow(@plugin.logger).to receive(:warn)
               @plugin.run
               expect(@plugin["ipaddress"]).to be_nil
             end
 
             it "takes the macaddress from ipv6" do
-              allow(Ohai::Log).to receive(:warn)
+              allow(@plugin.logger).to receive(:warn)
               @plugin.run
               expect(@plugin["macaddress"]).to eq(@expected_results[os]["macaddress"])
             end
 
             it "warns about not being able to set ipaddress" do
-              expect(Ohai::Log).to receive(:warn).with(/unable to detect ipaddress/).once
+              expect(@plugin.logger).to receive(:warn).with(/unable to detect ipaddress/).once
               @plugin.run
             end
 
             it "doesn't overwrite ip6address" do
-              allow(Ohai::Log).to receive(:warn)
+              allow(@plugin.logger).to receive(:warn)
               @plugin.run
               expect(@plugin["ip6address"]).to eq("3ffe:8888:9999::1")
             end
@@ -1013,9 +1014,9 @@ describe Ohai::System, "Network Plugin" do
             before do
               @plugin["network"]["default_gateway"] = nil
               @plugin["network"]["default_interface"] = nil
-              @plugin["network"]["interfaces"].each do |i, iv|
-                if iv.has_key? "addresses"
-                  iv["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
+              @plugin["network"]["interfaces"].each_value do |val|
+                if val.key? "addresses"
+                  val["addresses"].delete_if { |k, kv| kv["family"] == "inet" }
                 end
               end
               @plugin["macaddress"] = "00:AA:BB:CC:DD:EE"
@@ -1025,13 +1026,13 @@ describe Ohai::System, "Network Plugin" do
             it_doesnt_fail
 
             it "can't set ipaddress" do
-              allow(Ohai::Log).to receive(:warn)
+              allow(@plugin.logger).to receive(:warn)
               @plugin.run
               expect(@plugin["ipaddress"]).to be_nil
             end
 
             it "doesn't overwrite {ip6,mac}address" do
-              allow(Ohai::Log).to receive(:warn)
+              allow(@plugin.logger).to receive(:warn)
               @plugin.run
               expect(@plugin["ip6address"]).to eq("3ffe:8888:9999::1")
               expect(@plugin["macaddress"]).to eq("00:AA:BB:CC:DD:EE")
