@@ -18,13 +18,13 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin nodejs" do
 
   let(:plugin) { get_plugin("nodejs") }
 
-  before(:each) do
+  before do
     plugin[:languages] = Mash.new
     @stdout = "v0.8.11\n"
     allow(plugin).to receive(:shell_out).with("node -v").and_return(mock_shell_out(0, @stdout, ""))
