@@ -16,10 +16,10 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "OpenBSD kernel plugin" do
-  before(:each) do
+  before do
     @plugin = get_plugin("kernel")
     allow(@plugin).to receive(:collect_os).and_return(:openbsd)
     allow(@plugin).to receive(:init_kernel).and_return({})
@@ -28,7 +28,7 @@ describe Ohai::System, "OpenBSD kernel plugin" do
     allow(@plugin).to receive(:shell_out).with( Ohai.abs_path( "/usr/bin/modstat" )).and_return(mock_shell_out(0, "  1    7 0xc0400000 97f830   kernel", ""))
   end
 
-  it "should set the kernel_os to the kernel_name value" do
+  it "sets the kernel_os to the kernel_name value" do
     @plugin.run
     expect(@plugin[:kernel][:os]).to eq(@plugin[:kernel][:name])
   end
