@@ -16,17 +16,17 @@
 # limitations under the License.
 #
 
-require_relative "../../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "OpenBSD plugin platform" do
-  before(:each) do
+  before do
     @plugin = get_plugin("openbsd/platform")
     allow(@plugin).to receive(:shell_out).with("uname -s").and_return(mock_shell_out(0, "OpenBSD\n", ""))
     allow(@plugin).to receive(:shell_out).with("uname -r").and_return(mock_shell_out(0, "4.5\n", ""))
     allow(@plugin).to receive(:collect_os).and_return(:openbsd)
   end
 
-  it "should set platform_version to lsb[:release]" do
+  it "sets platform_version to lsb[:release]" do
     @plugin.run
     expect(@plugin[:platform_version]).to eq("4.5")
   end
