@@ -17,12 +17,12 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin perl" do
   let(:plugin) { get_plugin("perl") }
 
-  before(:each) do
+  before do
     plugin[:languages] = Mash.new
     @stdout = "version='5.8.8';#{$/}archname='darwin-thread-multi-2level';"
     allow(plugin).to receive(:shell_out).with("perl -V:version -V:archname").and_return(mock_shell_out(0, @stdout, ""))
