@@ -16,19 +16,19 @@
 #
 
 require "resolv"
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin rackspace" do
   let(:plugin) { get_plugin("rackspace") }
 
-  before(:each) do
+  before do
     allow(Resolv).to receive(:getname).and_return("1.2.3.4")
 
     plugin[:hostname] = "katie"
 
     plugin[:network] = {
-      :interfaces => {
-        :eth0 => {
+      interfaces: {
+        eth0: {
           "addresses" => {
             "1.2.3.4" => {
               "broadcast" => "67.23.20.255",
@@ -54,7 +54,7 @@ describe Ohai::System, "plugin rackspace" do
     }
 
     plugin[:network][:interfaces][:eth1] = {
-      :addresses => {
+      addresses: {
         "fe80::4240:f5ff:feab:2836" => {
           "scope" => "Link",
           "prefixlen" => "64",
@@ -73,7 +73,7 @@ describe Ohai::System, "plugin rackspace" do
 
     # In olden days we could detect rackspace by a -rscloud suffix on the kernel
     # This is here to make #has_rackspace_kernel? fail until we remove that check
-    plugin[:kernel] = { :release => "1.2.13-not-rackspace" }
+    plugin[:kernel] = { release: "1.2.13-not-rackspace" }
 
     # We need a generic stub here for the later stubs with arguments to work
     # Because, magic.
@@ -131,27 +131,27 @@ describe Ohai::System, "plugin rackspace" do
     end
 
     it "captures region information" do
-      provider_data = <<-OUT
-provider = "Rackspace"
-service_type = "cloudServers"
-server_id = "21301000"
-created_at = "2012-12-06T22:08:16Z"
-region = "dfw"
-OUT
+      provider_data = <<~OUT
+        provider = "Rackspace"
+        service_type = "cloudServers"
+        server_id = "21301000"
+        created_at = "2012-12-06T22:08:16Z"
+        region = "dfw"
+      OUT
       allow(plugin).to receive(:shell_out).with("xenstore-ls vm-data/provider_data").and_return(mock_shell_out(0, provider_data, ""))
       plugin.run
       expect(plugin[:rackspace][:region]).to eq("dfw")
     end
 
     it "logs a debug message when region info cannot be collected" do
-      expect(plugin).
-        to receive(:shell_out).
-        with("xenstore-ls vm-data/provider_data").
-        and_raise(Ohai::Exceptions::Exec)
+      expect(plugin)
+        .to receive(:shell_out)
+        .with("xenstore-ls vm-data/provider_data")
+        .and_raise(Ohai::Exceptions::Exec)
 
-      expect(Ohai::Log).
-        to receive(:debug).
-        with("Plugin Rackspace: Unable to find xenstore-ls, cannot capture " \
+      expect(plugin.logger)
+        .to receive(:trace)
+        .with("Plugin Rackspace: Unable to find xenstore-ls, cannot capture " \
              "region information for Rackspace cloud")
 
       plugin.run
@@ -167,14 +167,14 @@ OUT
     end
 
     it "logs error if instance id cannot be found" do
-      expect(plugin).
-        to receive(:shell_out).
-        with("xenstore-read name").
-        and_raise(Ohai::Exceptions::Exec)
+      expect(plugin)
+        .to receive(:shell_out)
+        .with("xenstore-read name")
+        .and_raise(Ohai::Exceptions::Exec)
 
-      expect(Ohai::Log).
-        to receive(:debug).
-        with("Plugin Rackspace: Unable to find xenstore-read, cannot capture " \
+      expect(plugin.logger)
+        .to receive(:trace)
+        .with("Plugin Rackspace: Unable to find xenstore-read, cannot capture " \
              "instance ID information for Rackspace cloud")
 
       plugin.run
@@ -184,15 +184,15 @@ OUT
   end
 
   describe "with rackspace hint file" do
-    it_behaves_like "rackspace"
-
-    before(:each) do
+    before do
       allow(Resolv).to receive(:getname).and_raise(Resolv::ResolvError)
       allow(File).to receive(:exist?).with("/etc/resolv.conf").and_return(true)
       allow(File).to receive(:read).with("/etc/resolv.conf").and_return("")
       allow(plugin).to receive(:hint?).with("rackspace").and_return(true)
     end
 
+    it_behaves_like "rackspace"
+
     describe "with no public interfaces (empty eth0)" do
       before do
         # unset public (eth0) addresses
@@ -216,69 +216,74 @@ OUT
   end
 
   describe "without hint file" do
-    it_behaves_like "!rackspace"
-
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
     end
+
+    it_behaves_like "!rackspace"
+
   end
 
   describe "with Rackspace windows manufacturer data" do
+    before do
+      allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
+      allow(plugin).to receive(:has_rackspace_manufacturer?).and_return(true)
+    end
+
     it "has rackspace attribute" do
       plugin.run
       expect(plugin[:rackspace]).not_to be_nil
     end
 
-    before(:each) do
-      allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
-      allow(plugin).to receive(:has_rackspace_manufacturer?).and_return(true)
-    end
   end
 
   describe "xenstore provider returns rackspace" do
-    it_behaves_like "rackspace"
-
-    before(:each) do
+    before do
       stdout = "Rackspace\n"
       allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
       allow(plugin).to receive(:shell_out).with("xenstore-read vm-data/provider_data/provider").and_return(mock_shell_out(0, stdout, "" ))
     end
+
+    it_behaves_like "rackspace"
+
   end
 
   describe "xenstore provider does not return rackspace" do
-    it_behaves_like "!rackspace"
-
-    before(:each) do
+    before do
       allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
       stdout = "cumulonimbus\n"
       allow(plugin).to receive(:shell_out).with("xenstore-read vm-data/provider_data/provider").and_return(mock_shell_out(0, stdout, "" ))
     end
+
+    it_behaves_like "!rackspace"
+
   end
 
   describe "xenstore provider does not exist" do
+    before do
+      allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
+      allow(plugin)
+        .to receive(:shell_out)
+        .with("xenstore-read vm-data/provider_data/provider")
+        .and_raise(Ohai::Exceptions::Exec)
+    end
+
     it_behaves_like "!rackspace"
 
-    before(:each) do
-      allow(plugin).to receive(:hint?).with("rackspace").and_return(false)
-      allow(plugin).
-        to receive(:shell_out).
-        with("xenstore-read vm-data/provider_data/provider").
-        and_raise(Ohai::Exceptions::Exec)
-    end
   end
 
   describe "when private networks shell out fails" do
     it "logs an error and does not collect private_networks" do
       allow(plugin).to receive(:hint?).with("rackspace").and_return(true)
 
-      expect(plugin).
-        to receive(:shell_out).
-        with("xenstore-ls vm-data/networking").
-        and_raise(Ohai::Exceptions::Exec)
+      expect(plugin)
+        .to receive(:shell_out)
+        .with("xenstore-ls vm-data/networking")
+        .and_raise(Ohai::Exceptions::Exec)
 
-      expect(Ohai::Log).
-        to receive(:debug).
-        with("Plugin Rackspace: Unable to capture custom private networking " \
+      expect(plugin.logger)
+        .to receive(:trace)
+        .with("Plugin Rackspace: Unable to capture custom private networking " \
              "information for Rackspace cloud")
 
       plugin.run
@@ -305,7 +310,7 @@ OUT
   describe "has private networks" do
     before do
       plugin[:network][:interfaces][:eth2] = {
-        :addresses => {
+        addresses: {
           "fe80::be76:4eff:fe20:422b" => {
             "scope" => "Link",
             "prefixlen" => "64",
