@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 ruby_bin = File.join(::RbConfig::CONFIG["bindir"], ::RbConfig::CONFIG["ruby_install_name"])
 
@@ -30,29 +30,29 @@ describe Ohai::System, "plugin ruby" do
     @ruby_ohai_data_pristine = @plugin[:languages][:ruby]
   end
 
-  before(:each) do
+  before do
     @ruby_ohai_data = @ruby_ohai_data_pristine.dup
   end
 
   {
-    :platform => RUBY_PLATFORM,
-    :version => RUBY_VERSION,
-    :release_date => RUBY_RELEASE_DATE,
-    :target => ::RbConfig::CONFIG["target"],
-    :target_cpu => ::RbConfig::CONFIG["target_cpu"],
-    :target_vendor => ::RbConfig::CONFIG["target_vendor"],
-    :target_os => ::RbConfig::CONFIG["target_os"],
-    :host => ::RbConfig::CONFIG["host"],
-    :host_cpu => ::RbConfig::CONFIG["host_cpu"],
-    :host_os => ::RbConfig::CONFIG["host_os"],
-    :host_vendor => ::RbConfig::CONFIG["host_vendor"],
-    :gems_dir => `#{ruby_bin} #{::RbConfig::CONFIG["bindir"]}/gem env gemdir`.chomp,
-    :gem_bin => [ ::Gem.default_exec_format % "gem", "gem" ].map do |bin|
-      "#{::RbConfig::CONFIG['bindir']}/#{bin}"
-    end.find { |bin| ::File.exists? bin },
-    :ruby_bin => ruby_bin,
+    platform: RUBY_PLATFORM,
+    version: RUBY_VERSION,
+    release_date: RUBY_RELEASE_DATE,
+    target: ::RbConfig::CONFIG["target"],
+    target_cpu: ::RbConfig::CONFIG["target_cpu"],
+    target_vendor: ::RbConfig::CONFIG["target_vendor"],
+    target_os: ::RbConfig::CONFIG["target_os"],
+    host: ::RbConfig::CONFIG["host"],
+    host_cpu: ::RbConfig::CONFIG["host_cpu"],
+    host_os: ::RbConfig::CONFIG["host_os"],
+    host_vendor: ::RbConfig::CONFIG["host_vendor"],
+    gems_dir: `#{ruby_bin} #{::RbConfig::CONFIG["bindir"]}/gem env gemdir`.chomp,
+    gem_bin: [ ::Gem.default_exec_format % "gem", "gem" ].map do |bin|
+      "#{::RbConfig::CONFIG["bindir"]}/#{bin}"
+    end.find { |bin| ::File.exist? bin },
+    ruby_bin: ruby_bin,
   }.each do |attribute, value|
-    it "should have #{attribute} set to #{value.inspect}" do
+    it "has #{attribute} set to #{value.inspect}" do
       expect(@ruby_ohai_data[attribute]).to eql(value)
     end
   end
