@@ -15,12 +15,12 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin scala" do
 
   let(:plugin) do
-    plugin = get_plugin("scala").tap do |plugin|
+    get_plugin("scala").tap do |plugin|
       plugin[:languages] = Mash.new
     end
   end
@@ -33,8 +33,8 @@ describe Ohai::System, "plugin scala" do
       .and_return(mock_shell_out(0, "", scala_out))
   end
 
-  context "if scala is installed" do
-    before(:each) do
+  context "when scala is installed" do
+    before do
       setup_plugin
       plugin.run
     end
@@ -44,8 +44,8 @@ describe Ohai::System, "plugin scala" do
     end
   end
 
-  context "if scala is not installed" do
-    before(:each) do
+  context "when scala is not installed" do
+    before do
       allow(plugin).to receive(:shell_out)
         .and_raise( Ohai::Exceptions::Exec )
       plugin.run
