@@ -15,7 +15,7 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "plugin shells" do
   let(:plugin) { get_plugin("shells") }
