@@ -16,21 +16,21 @@
 # limitations under the License.
 #
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::System, "ssh_host_key plugin" do
 
-  before(:each) do
+  before do
     @plugin = get_plugin("ssh_host_key")
     @plugin[:keys] = Mash.new
 
-    allow(File).to receive(:exists?).with("/etc/ssh/sshd_config").and_return(true)
+    allow(File).to receive(:exist?).with("/etc/ssh/sshd_config").and_return(true)
     allow(File).to receive(:open).with("/etc/ssh/sshd_config").and_yield(sshd_config_file)
-    allow(File).to receive(:exists?).and_return(true)
-    allow(File).to receive(:exists?).with("/etc/ssh/ssh_host_dsa_key.pub").and_return(true)
-    allow(File).to receive(:exists?).with("/etc/ssh/ssh_host_rsa_key.pub").and_return(true)
-    allow(File).to receive(:exists?).with("/etc/ssh/ssh_host_ecdsa_key.pub").and_return(true)
-    allow(File).to receive(:exists?).with("/etc/ssh/ssh_host_ed25519_key.pub").and_return(true)
+    allow(File).to receive(:exist?).and_return(true)
+    allow(File).to receive(:exist?).with("/etc/ssh/ssh_host_dsa_key.pub").and_return(true)
+    allow(File).to receive(:exist?).with("/etc/ssh/ssh_host_rsa_key.pub").and_return(true)
+    allow(File).to receive(:exist?).with("/etc/ssh/ssh_host_ecdsa_key.pub").and_return(true)
+    allow(File).to receive(:exist?).with("/etc/ssh/ssh_host_ed25519_key.pub").and_return(true)
 
     # Ensure we can still use IO.read
     io_read = IO.method(:read)
@@ -75,27 +75,29 @@ describe Ohai::System, "ssh_host_key plugin" do
 
   context "when an sshd_config exists" do
     let :sshd_config_file do
-      <<EOS
-# HostKeys for protocol version 2
-HostKey /etc/ssh/ssh_host_rsa_key
-HostKey /etc/ssh/ssh_host_dsa_key
-HostKey /etc/ssh/ssh_host_ecdsa_key
-HostKey /etc/ssh/ssh_host_ed25519_key
-EOS
+      <<~EOS
+        # HostKeys for protocol version 2
+        HostKey /etc/ssh/ssh_host_rsa_key
+        HostKey /etc/ssh/ssh_host_dsa_key
+        HostKey /etc/ssh/ssh_host_ecdsa_key
+        HostKey /etc/ssh/ssh_host_ed25519_key
+      EOS
     end
+
     it_behaves_like "loads keys"
   end
 
   context "when an sshd_config exists with commented entries" do
     let :sshd_config_file do
-      <<EOS
-# HostKeys for protocol version 2
-#HostKey /etc/ssh/ssh_host_rsa_key
-#HostKey /etc/ssh/ssh_host_dsa_key
-#HostKey /etc/ssh/ssh_host_ecdsa_key
-#HostKey /etc/ssh/ssh_host_ed25519_key
-EOS
+      <<~EOS
+        # HostKeys for protocol version 2
+        #HostKey /etc/ssh/ssh_host_rsa_key
+        #HostKey /etc/ssh/ssh_host_dsa_key
+        #HostKey /etc/ssh/ssh_host_ecdsa_key
+        #HostKey /etc/ssh/ssh_host_ed25519_key
+      EOS
     end
+
     it_behaves_like "loads keys"
   end
 
@@ -103,9 +105,10 @@ EOS
     let :sshd_config_file do
       nil
     end
+
     before do
-      allow(File).to receive(:exists?).with("/etc/ssh/sshd_config").and_return(false)
-      allow(File).to receive(:exists?).with("/etc/sshd_config").and_return(false)
+      allow(File).to receive(:exist?).with("/etc/ssh/sshd_config").and_return(false)
+      allow(File).to receive(:exist?).with("/etc/sshd_config").and_return(false)
     end
 
     it_behaves_like "loads keys"
