@@ -1,6 +1,6 @@
 #
 # Author:: Claire McQuin (<claire@chef.io>)
-# Copyright:: Copyright (c) 2013-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) 2013-2019, Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you
@@ -17,29 +17,29 @@
 # limitations under the License
 #
 
-require_relative "../spec_helper.rb"
+require "spec_helper"
 
 describe Ohai::Runner, "run_plugin" do
   let(:safe_run) { true }
 
-  before(:each) do
+  before do
     @ohai = Ohai::System.new
-    @runner = Ohai::Runner.new(@ohai, safe_run)
+    @runner = described_class.new(@ohai, safe_run)
   end
 
   describe "when running an invalid plugin" do
-    it "should raise error" do
+    it "raises error" do
       expect { @runner.run_plugin(double("Ohai::NotPlugin")) }.to raise_error(Ohai::Exceptions::InvalidPlugin)
     end
   end
 
   describe "when running a plugin" do
-    let(:plugin) { double("Ohai::DSL::Plugin", :kind_of? => true, :version => version, :name => :Test, :has_run? => has_run, :dependencies => [ ]) }
+    let(:plugin) { double("Ohai::DSL::Plugin", is_a?: true, version: version, name: :Test, has_run?: has_run, dependencies: [ ]) }
     let(:version) { :version7 }
     let(:has_run) { false }
 
     describe "version 7" do
-      it "should call run_v7_plugin" do
+      it "calls run_v7_plugin" do
         expect(@runner).to receive(:run_v7_plugin)
         @runner.run_plugin(plugin)
       end
@@ -47,54 +47,17 @@ describe Ohai::Runner, "run_plugin" do
       describe "if the plugin has run before" do
         let(:has_run) { true }
 
-        it "should not run the plugin" do
+        it "does not run the plugin" do
           expect(plugin).not_to receive(:safe_run)
           @runner.run_plugin(plugin)
         end
       end
     end
 
-    describe "version 6" do
-      let(:version) { :version6 }
-
-      it "should call run_v6_plugin" do
-        expect(@runner).to receive(:run_v6_plugin)
-        @runner.run_plugin(plugin)
-      end
-
-      describe "if the plugin has not run before" do
-        describe "if safe_run is not set" do
-          it "safe_run should be called" do
-            expect(plugin).to receive(:safe_run)
-            @runner.run_plugin(plugin)
-          end
-        end
-
-        describe "if safe_run is set" do
-          let(:safe_run) { false }
-
-          it "run should be called" do
-            expect(plugin).to receive(:run)
-            @runner.run_plugin(plugin)
-          end
-        end
-      end
-
-      describe "if the plugin has run before" do
-        let(:has_run) { true }
-
-        it "should not run" do
-          expect(plugin).not_to receive(:safe_run)
-          @runner.run_plugin(plugin)
-        end
-
-      end
-    end
-
     describe "invalid version" do
       let(:version) { :versionBla }
 
-      it "should raise error" do
+      it "raises error" do
         expect { @runner.run_plugin(plugin) }.to raise_error(Ohai::Exceptions::InvalidPlugin)
       end
     end
@@ -108,15 +71,15 @@ describe Ohai::Runner, "run_plugin" do
           thing(Mash.new)
         end
       end
-      klass.new(@ohai.data)
+      klass.new(@ohai.data, @ohai.logger)
     end
 
-    it "should run the plugin" do
+    it "runs the plugin" do
       @runner.run_plugin(plugin)
       expect(plugin.has_run?).to be true
     end
 
-    it "should add plugin data to Ohai::System.data" do
+    it "adds plugin data to Ohai::System.data" do
       @runner.run_plugin(plugin)
       expect(@ohai.data).to have_key(:thing)
       expect(@ohai.data[:thing]).to eql({})
@@ -125,7 +88,7 @@ describe Ohai::Runner, "run_plugin" do
 
   describe "when running a plugin with one dependency" do
     describe "when the dependency does not exist" do
-      before(:each) do
+      before do
         klass = Ohai.plugin(:Test) do
           provides("thing")
           depends("other_thing")
@@ -133,21 +96,21 @@ describe Ohai::Runner, "run_plugin" do
             thing(other_thing)
           end
         end
-        @plugin = klass.new(@ohai.data)
+        @plugin = klass.new(@ohai.data, @ohai.logger)
       end
 
-      it "should raise Ohai::Excpetions::AttributeNotFound" do
+      it "raises Ohai::Excpetions::AttributeNotFound" do
         expect { @runner.run_plugin(@plugin) }.to raise_error(Ohai::Exceptions::AttributeNotFound)
       end
 
-      it "should not run the plugin" do
+      it "does not run the plugin" do
         expect { @runner.run_plugin(@plugin) }.to raise_error(Ohai::Exceptions::AttributeNotFound)
         expect(@plugin.has_run?).to be false
       end
     end
 
     describe "when the dependency has a single provider" do
-      before(:each) do
+      before do
         klass1 = Ohai.plugin(:Thing) do
           provides("thing")
           collect_data do
@@ -164,14 +127,14 @@ describe Ohai::Runner, "run_plugin" do
 
         @plugins = []
         [klass1, klass2].each do |klass|
-          @plugins << klass.new(@ohai.data)
+          @plugins << klass.new(@ohai.data, @ohai.logger)
         end
         @plugin1, @plugin2 = @plugins
 
         @ohai.provides_map.set_providers_for(@plugin1, ["thing"])
       end
 
-      it "should run the plugins" do
+      it "runs the plugins" do
         @runner.run_plugin(@plugin2)
         @plugins.each do |plugin|
           expect(plugin.has_run?).to be true
@@ -180,7 +143,7 @@ describe Ohai::Runner, "run_plugin" do
     end
 
     describe "when the dependency has multiple providers" do
-      before(:each) do
+      before do
         klass1 = Ohai.plugin(:Thing) do
           provides("thing")
           collect_data do
@@ -197,7 +160,7 @@ describe Ohai::Runner, "run_plugin" do
 
         @plugins = []
         [klass1, klass1, klass2].each do |klass|
-          @plugins << klass.new(@ohai.data)
+          @plugins << klass.new(@ohai.data, @ohai.logger)
         end
         @plugin1, @plugin2, @plugin3 = @plugins
 
@@ -205,7 +168,7 @@ describe Ohai::Runner, "run_plugin" do
         @ohai.provides_map.set_providers_for(@plugin2, ["thing"])
       end
 
-      it "should run the plugins" do
+      it "runs the plugins" do
         @runner.run_plugin(@plugin3)
         @plugins.each do |plugin|
           expect(plugin.has_run?).to be true
@@ -215,9 +178,9 @@ describe Ohai::Runner, "run_plugin" do
   end
 
   describe "when running a plugin with many dependencies" do
-    before(:each) do
+    before do
       @ohai = Ohai::System.new
-      @runner = Ohai::Runner.new(@ohai, true)
+      @runner = described_class.new(@ohai, true)
 
       klass1 = Ohai.plugin(:One) do
         provides("one")
@@ -241,14 +204,14 @@ describe Ohai::Runner, "run_plugin" do
 
       @plugins = []
       [klass1, klass2, klass3].each do |klass|
-        @plugins << klass.new(@ohai.data)
+        @plugins << klass.new(@ohai.data, @ohai.logger)
       end
       @plugin1, @plugin2, @plugin3 = @plugins
       @ohai.provides_map.set_providers_for(@plugin1, %w{one two})
       @ohai.provides_map.set_providers_for(@plugin2, %w{one two})
     end
 
-    it "should run the plugins" do
+    it "runs the plugins" do
       @runner.run_plugin(@plugin3)
       @plugins.each do |plugin|
         expect(plugin.has_run?).to be true
@@ -257,11 +220,11 @@ describe Ohai::Runner, "run_plugin" do
   end
 
   describe "when a cycle is detected" do
-    let(:runner) { Ohai::Runner.new(@ohai, true) }
+    let(:runner) { described_class.new(@ohai, true) }
 
     context "when there are no edges in the cycle (A->A)" do
       let(:plugin_class) do
-        klass1 = Ohai.plugin(:Thing) do
+        Ohai.plugin(:Thing) do
           provides("thing")
           depends("thing")
           collect_data do
@@ -269,20 +232,18 @@ describe Ohai::Runner, "run_plugin" do
           end
         end
       end
-      let(:plugin) { plugin_class.new(@ohai.data) }
+      let(:plugin) { plugin_class.new(@ohai.data, @ohai.logger) }
 
       it "ignores the cycle" do
         @ohai.provides_map.set_providers_for(plugin, ["thing"])
-
-        expected_error_string = "Dependency cycle detected. Please refer to the following plugins: Thing, Other"
         runner.run_plugin(plugin) # should not raise
       end
 
     end
 
     context "when there is one edge in the cycle (A->B and B->A)" do
-      before(:each) do
-        klass1 = Ohai.plugin(:Thing) do
+      before do
+        klass1 = Ohai.plugin(:Thing) do # rubocop disable Lint/UselessAssignment
           provides("thing")
           depends("other")
           collect_data do
@@ -299,13 +260,13 @@ describe Ohai::Runner, "run_plugin" do
 
         @plugins = []
         [klass1, klass2].each_with_index do |klass, idx|
-          @plugins << klass.new(@ohai.data)
+          @plugins << klass.new(@ohai.data, @ohai.logger)
         end
 
         @plugin1, @plugin2 = @plugins
       end
 
-      it "should raise Ohai::Exceptions::DependencyCycle" do
+      it "raises Ohai::Exceptions::DependencyCycle" do
         allow(runner).to receive(:fetch_plugins).with(["thing"]).and_return([@plugin1])
         allow(runner).to receive(:fetch_plugins).with(["other"]).and_return([@plugin2])
         expected_error_string = "Dependency cycle detected. Please refer to the following plugins: Thing, Other"
@@ -315,9 +276,9 @@ describe Ohai::Runner, "run_plugin" do
   end
 
   describe "when A depends on B and C, and B depends on C" do
-    before(:each) do
+    before do
       @ohai = Ohai::System.new
-      @runner = Ohai::Runner.new(@ohai, true)
+      @runner = described_class.new(@ohai, true)
 
       klass_a = Ohai.plugin(:A) do
         provides("A")
@@ -336,12 +297,12 @@ describe Ohai::Runner, "run_plugin" do
 
       @plugins = []
       [klass_a, klass_b, klass_c].each do |klass|
-        @plugins << klass.new(@ohai.data)
+        @plugins << klass.new(@ohai.data, @ohai.logger)
       end
       @plugin_a, @plugin_b, @plugin_c = @plugins
     end
 
-    it "should not detect a cycle when B is the first provider returned" do
+    it "does not detect a cycle when B is the first provider returned" do
       @ohai.provides_map.set_providers_for(@plugin_a, ["A"])
       @ohai.provides_map.set_providers_for(@plugin_b, ["B"])
       @ohai.provides_map.set_providers_for(@plugin_c, ["C"])
@@ -354,7 +315,7 @@ describe Ohai::Runner, "run_plugin" do
       end
     end
 
-    it "should not detect a cycle when C is the first provider returned" do
+    it "does not detect a cycle when C is the first provider returned" do
       @ohai.provides_map.set_providers_for(@plugin_a, ["A"])
       @ohai.provides_map.set_providers_for(@plugin_c, ["C"])
       @ohai.provides_map.set_providers_for(@plugin_b, ["B"])
@@ -370,15 +331,15 @@ describe Ohai::Runner, "run_plugin" do
 end
 
 describe Ohai::Runner, "fetch_plugins" do
-  before(:each) do
+  before do
     @provides_map = Ohai::ProvidesMap.new
     @data = Mash.new
-    @ohai = double("Ohai::System", :data => @data, :provides_map => @provides_map)
-    @runner = Ohai::Runner.new(@ohai, true)
+    @ohai = double("Ohai::System", data: @data, provides_map: @provides_map, logger: Ohai::Log.with_child)
+    @runner = described_class.new(@ohai, true)
   end
 
-  it "should collect the provider" do
-    plugin = Ohai::DSL::Plugin.new(@ohai.data)
+  it "collects the provider" do
+    plugin = Ohai::DSL::Plugin.new(@ohai.data, @ohai.logger)
     @ohai.provides_map.set_providers_for(plugin, ["top/middle/bottom"])
 
     dependency_providers = @runner.fetch_plugins(["top/middle/bottom"])
@@ -387,32 +348,32 @@ describe Ohai::Runner, "fetch_plugins" do
 
   describe "when the attribute is not provided by any plugin" do
     describe "and some parent attribute has providers" do
-      it "should return the providers for the parent" do
-        plugin = Ohai::DSL::Plugin.new(@ohai.data)
+      it "returns the providers for the parent" do
+        plugin = Ohai::DSL::Plugin.new(@ohai.data, @ohai.logger)
         @provides_map.set_providers_for(plugin, ["test/attribute"])
         expect(@runner.fetch_plugins(["test/attribute/too_far"])).to eql([plugin])
       end
     end
 
     describe "and no parent attribute has providers" do
-      it "should raise Ohai::Exceptions::AttributeNotFound exception" do
+      it "raises Ohai::Exceptions::AttributeNotFound exception" do
         # provides map is empty
         expect { @runner.fetch_plugins(["false/attribute"]) }.to raise_error(Ohai::Exceptions::AttributeNotFound, "No such attribute: 'false/attribute'")
       end
     end
   end
 
-  it "should return unique providers" do
-    plugin = Ohai::DSL::Plugin.new(@ohai.data)
+  it "returns unique providers" do
+    plugin = Ohai::DSL::Plugin.new(@ohai.data, @ohai.logger)
     @provides_map.set_providers_for(plugin, ["test", "test/too_far/way_too_far"])
     expect(@runner.fetch_plugins(["test", "test/too_far/way_too_far"])).to eql([plugin])
   end
 end
 
 describe Ohai::Runner, "#get_cycle" do
-  before(:each) do
+  before do
     @ohai = Ohai::System.new
-    @runner = Ohai::Runner.new(@ohai, true)
+    @runner = described_class.new(@ohai, true)
 
     klass1 = Ohai.plugin(:One) do
       provides("one")
@@ -438,12 +399,12 @@ describe Ohai::Runner, "#get_cycle" do
 
     plugins = []
     [klass1, klass2, klass3].each_with_index do |klass, idx|
-      plugins << klass.new(@ohai.data)
+      plugins << klass.new(@ohai.data, @ohai.logger)
     end
     @plugin1, @plugin2, @plugin3 = plugins
   end
 
-  it "should return the sources for the plugins in the cycle, when given an exact cycle" do
+  it "returns the sources for the plugins in the cycle, when given an exact cycle" do
     cycle = [@plugin1, @plugin2]
     cycle_start = @plugin1
 
@@ -451,7 +412,7 @@ describe Ohai::Runner, "#get_cycle" do
     expect(cycle_names).to eql([@plugin1.name, @plugin2.name])
   end
 
-  it "should return the sources for only the plugins in the cycle, when there are plugins before the cycle begins" do
+  it "returns the sources for only the plugins in the cycle, when there are plugins before the cycle begins" do
     cycle = [@plugin3, @plugin1, @plugin2]
     cycle_start = @plugin1
 
