@@ -16,7 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-require_relative "../../spec_helper.rb"
+require "spec_helper"
 require "ohai/util/file_helper"
 
 class FileHelperMock
@@ -26,8 +26,10 @@ end
 describe "Ohai::Util::FileHelper" do
   let(:file_helper) { FileHelperMock.new }
 
-  before(:each) do
+  before do
     allow(file_helper).to receive(:name).and_return("Fakeclass")
+    logger = instance_double("Mixlib::Log::Child", trace: nil, debug: nil, warn: nil)
+    allow(file_helper).to receive(:logger).and_return(logger)
     allow(File).to receive(:executable?).and_return(false)
   end
 
